/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_M3NGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_M3NGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_M3NGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_M3NGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_M3NGLR::Heavy_WSTD_M3NGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_G6kJ5DnP);
  numBytes += sLine_init(&sLine_rWKxEhfB);
  numBytes += sLine_init(&sLine_b8VW2dOA);
  numBytes += sLine_init(&sLine_Ya9Dn5ZW);
  numBytes += sLine_init(&sLine_Pqzo76Lg);
  numBytes += sBiquad_init(&sBiquad_s_XFrOSmsz);
  numBytes += sLine_init(&sLine_XzosgNlC);
  numBytes += sLine_init(&sLine_M1I2rTgA);
  numBytes += sLine_init(&sLine_RiHHQ1Md);
  numBytes += sLine_init(&sLine_kqqy7VH6);
  numBytes += sLine_init(&sLine_hUk0yMz1);
  numBytes += sBiquad_init(&sBiquad_s_a9JugEwC);
  numBytes += sLine_init(&sLine_rA9zCPq8);
  numBytes += sLine_init(&sLine_KfVxMb66);
  numBytes += sLine_init(&sLine_BbYzWumJ);
  numBytes += sLine_init(&sLine_BEr3sgs7);
  numBytes += sLine_init(&sLine_ljfGrcXn);
  numBytes += sLine_init(&sLine_06FLLY0q);
  numBytes += sBiquad_init(&sBiquad_s_Jl43dUZw);
  numBytes += sLine_init(&sLine_7oqWfbFB);
  numBytes += sLine_init(&sLine_6ja6DLGB);
  numBytes += sLine_init(&sLine_Qn1vCEWR);
  numBytes += sLine_init(&sLine_YmJDT9yK);
  numBytes += sLine_init(&sLine_CmXn1URJ);
  numBytes += sLine_init(&sLine_02OM5bGf);
  numBytes += sBiquad_init(&sBiquad_s_HCaRTbpV);
  numBytes += sLine_init(&sLine_6YZNnS84);
  numBytes += sLine_init(&sLine_o5oEcyxJ);
  numBytes += sLine_init(&sLine_6P2Bccjt);
  numBytes += sLine_init(&sLine_ITnFN1Bt);
  numBytes += sLine_init(&sLine_tR03KMGo);
  numBytes += sBiquad_init(&sBiquad_s_LYOe2IVu);
  numBytes += sLine_init(&sLine_uNyIGWRH);
  numBytes += sLine_init(&sLine_GGl2P8q0);
  numBytes += sLine_init(&sLine_hfK5BTgm);
  numBytes += sLine_init(&sLine_Oalunc8c);
  numBytes += sLine_init(&sLine_g88EbpX3);
  numBytes += sLine_init(&sLine_fPKr2ko1);
  numBytes += sBiquad_init(&sBiquad_s_a35pTx21);
  numBytes += sLine_init(&sLine_MRkwWgNC);
  numBytes += sLine_init(&sLine_MgYClfBv);
  numBytes += sLine_init(&sLine_k5QcbYdf);
  numBytes += sLine_init(&sLine_1duFCYvx);
  numBytes += sLine_init(&sLine_jIC9Pqu1);
  numBytes += sLine_init(&sLine_M5W5fIjK);
  numBytes += sLine_init(&sLine_NbQGWOIy);
  numBytes += sLine_init(&sLine_T6iqH1Dj);
  numBytes += sLine_init(&sLine_jyOmKENv);
  numBytes += sLine_init(&sLine_6mDp8joA);
  numBytes += sLine_init(&sLine_CkaVCiCz);
  numBytes += sLine_init(&sLine_g1PHdxfQ);
  numBytes += sLine_init(&sLine_P4DxNeie);
  numBytes += sLine_init(&sLine_JRFySmqY);
  numBytes += sLine_init(&sLine_73ao6fc2);
  numBytes += sEnv_init(&sEnv_5qKe5h8N, 512, 256);
  numBytes += sEnv_init(&sEnv_xxgWipqJ, 512, 256);
  numBytes += sLine_init(&sLine_SNYQFNYb);
  numBytes += sLine_init(&sLine_zVg5tvTx);
  numBytes += sLine_init(&sLine_DwBPjfyo);
  numBytes += sLine_init(&sLine_VL1XDnDV);
  numBytes += sLine_init(&sLine_DufrcJW8);
  numBytes += sLine_init(&sLine_FZaJMQYo);
  numBytes += sLine_init(&sLine_jDRStYAR);
  numBytes += sLine_init(&sLine_LlIvTlov);
  numBytes += sLine_init(&sLine_r8lpIm0g);
  numBytes += sLine_init(&sLine_pKleR778);
  numBytes += sLine_init(&sLine_61CQDJRQ);
  numBytes += sLine_init(&sLine_nMoDIXtv);
  numBytes += sLine_init(&sLine_yU6rar4v);
  numBytes += sLine_init(&sLine_Ve6czca2);
  numBytes += sLine_init(&sLine_xkO4WGPp);
  numBytes += sLine_init(&sLine_e5AhCPL1);
  numBytes += sLine_init(&sLine_lIAr0GaR);
  numBytes += sLine_init(&sLine_Y0q5Nles);
  numBytes += sEnv_init(&sEnv_RzaS4zhU, 512, 256);
  numBytes += sEnv_init(&sEnv_dqvPljUk, 512, 256);
  numBytes += sLine_init(&sLine_ohrFgE5d);
  numBytes += sLine_init(&sLine_Bi8R9FFN);
  numBytes += sLine_init(&sLine_7BNmHqdj);
  numBytes += sLine_init(&sLine_JJiGPZGw);
  numBytes += sLine_init(&sLine_vKrXbYc9);
  numBytes += sLine_init(&sLine_cgDhbUkZ);
  numBytes += sLine_init(&sLine_f5jL3IbU);
  numBytes += sLine_init(&sLine_EpIjTFRv);
  numBytes += sLine_init(&sLine_xy9GuJlN);
  numBytes += sLine_init(&sLine_lCQXAjsh);
  numBytes += sLine_init(&sLine_uB1UgHEo);
  numBytes += sLine_init(&sLine_B4NZkZei);
  numBytes += sLine_init(&sLine_kJfc9N4s);
  numBytes += sLine_init(&sLine_RN25Zkbz);
  numBytes += sLine_init(&sLine_F60gITTo);
  numBytes += sLine_init(&sLine_BGvyY5H4);
  numBytes += sLine_init(&sLine_2WIlVDv2);
  numBytes += sLine_init(&sLine_8qCq5oOW);
  numBytes += sLine_init(&sLine_hTFqpdxE);
  numBytes += sLine_init(&sLine_q8eu8BwN);
  numBytes += sEnv_init(&sEnv_L5B6lpDQ, 512, 256);
  numBytes += sEnv_init(&sEnv_YIhbZgr6, 512, 256);
  numBytes += sLine_init(&sLine_y9XjP1JQ);
  numBytes += sLine_init(&sLine_v6RFhU6r);
  numBytes += sLine_init(&sLine_qRiFl8KR);
  numBytes += sLine_init(&sLine_UhINNUs7);
  numBytes += sLine_init(&sLine_E7uvkJFq);
  numBytes += sLine_init(&sLine_m7WYll2C);
  numBytes += sLine_init(&sLine_mwSs0Ge4);
  numBytes += sLine_init(&sLine_j8U4XpLX);
  numBytes += sLine_init(&sLine_kR7Mcgkk);
  numBytes += sLine_init(&sLine_50TJhMQ1);
  numBytes += sLine_init(&sLine_2VjIK8O9);
  numBytes += sLine_init(&sLine_UEIBAxyN);
  numBytes += sLine_init(&sLine_mttfoG52);
  numBytes += sLine_init(&sLine_Z3DQkpzP);
  numBytes += sLine_init(&sLine_4daaTl5n);
  numBytes += sLine_init(&sLine_ufOR8jSe);
  numBytes += sLine_init(&sLine_J5uyPvYh);
  numBytes += sLine_init(&sLine_0glMcTB4);
  numBytes += sEnv_init(&sEnv_rnRfn47V, 512, 256);
  numBytes += sEnv_init(&sEnv_wyvist55, 512, 256);
  numBytes += sLine_init(&sLine_9HEtgyT2);
  numBytes += sLine_init(&sLine_DYD3oFkr);
  numBytes += sLine_init(&sLine_XlN8478S);
  numBytes += sLine_init(&sLine_0cTdnOr6);
  numBytes += sLine_init(&sLine_ZCxOQ1Fz);
  numBytes += sLine_init(&sLine_zmiK1Gvb);
  numBytes += sLine_init(&sLine_eJA8JcFk);
  numBytes += sLine_init(&sLine_9AC0HQLq);
  numBytes += sLine_init(&sLine_wGKFAbvM);
  numBytes += sLine_init(&sLine_ZMFtYear);
  numBytes += sLine_init(&sLine_9PbNWfXs);
  numBytes += sLine_init(&sLine_TadTAmQx);
  numBytes += sLine_init(&sLine_zsVU29qC);
  numBytes += sLine_init(&sLine_ZjU2F2Oq);
  numBytes += sLine_init(&sLine_uh8mTyiv);
  numBytes += sLine_init(&sLine_8LEcWOj7);
  numBytes += sLine_init(&sLine_CQAyyN9W);
  numBytes += sLine_init(&sLine_4lAFjgeE);
  numBytes += sLine_init(&sLine_jlrC4lBc);
  numBytes += sLine_init(&sLine_avkEH5I6);
  numBytes += sEnv_init(&sEnv_MkNYtrzu, 512, 256);
  numBytes += sEnv_init(&sEnv_ccdQtJRP, 512, 256);
  numBytes += sLine_init(&sLine_y8vhNhW8);
  numBytes += sLine_init(&sLine_W7qaelao);
  numBytes += sLine_init(&sLine_kQHOZqfc);
  numBytes += sLine_init(&sLine_9pYR8xkk);
  numBytes += sLine_init(&sLine_3G0VnOCE);
  numBytes += sLine_init(&sLine_0o76B904);
  numBytes += sLine_init(&sLine_mgDLNC5N);
  numBytes += sLine_init(&sLine_UqVYeDfp);
  numBytes += sLine_init(&sLine_auDZnzx9);
  numBytes += sLine_init(&sLine_Vc1TQR6O);
  numBytes += sLine_init(&sLine_2nNyH92V);
  numBytes += sLine_init(&sLine_EtUrVCZB);
  numBytes += sLine_init(&sLine_oVb1uorp);
  numBytes += sLine_init(&sLine_zAbd9Zup);
  numBytes += sLine_init(&sLine_z0RMZ0hW);
  numBytes += sLine_init(&sLine_2WuHKoFb);
  numBytes += sLine_init(&sLine_L8ddu7d1);
  numBytes += sLine_init(&sLine_7P6gwSX8);
  numBytes += sEnv_init(&sEnv_8f1avqgT, 512, 256);
  numBytes += sEnv_init(&sEnv_3yVDvi4X, 512, 256);
  numBytes += sLine_init(&sLine_og82AA46);
  numBytes += sLine_init(&sLine_taIMuE9M);
  numBytes += sLine_init(&sLine_5VbNkyxm);
  numBytes += sLine_init(&sLine_vdvYze1w);
  numBytes += sLine_init(&sLine_mnjDtk55);
  numBytes += sLine_init(&sLine_RVRUWJHD);
  numBytes += cVar_init_f(&cVar_uaOiGexE, 0.0f);
  numBytes += cVar_init_f(&cVar_R8qXHQe8, 0.0f);
  numBytes += cVar_init_f(&cVar_SL6sz9Mq, 0.0f);
  numBytes += cVar_init_f(&cVar_89xigxCj, 0.0f);
  numBytes += cVar_init_f(&cVar_xaCnMqpF, 0.0f);
  numBytes += cVar_init_f(&cVar_7BAcLdpS, 1.0f);
  numBytes += cVar_init_f(&cVar_M9v6ODGO, 0.0f);
  numBytes += cVar_init_f(&cVar_Ny9HVUUZ, 0.0f);
  numBytes += cVar_init_f(&cVar_RU4YGpXb, 0.0f);
  numBytes += cVar_init_f(&cVar_wdDAUY0w, 0.0f);
  numBytes += cSlice_init(&cSlice_6lTYbd80, 1, -1);
  numBytes += cVar_init_f(&cVar_SvEk1LI5, 1337.0f);
  numBytes += cVar_init_f(&cVar_jPUxejQv, 0.0f);
  numBytes += cIf_init(&cIf_QwRtHK6R, false);
  numBytes += cIf_init(&cIf_7qzbxYbC, false);
  numBytes += cBinop_init(&cBinop_AS0BOQnJ, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Nq1b05pU, false);
  numBytes += cBinop_init(&cBinop_59lCgc88, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_jTwGogxr, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_kDbbFr4f, 0.0f);
  numBytes += cIf_init(&cIf_eA1Tv9F7, false);
  numBytes += cIf_init(&cIf_hKkJN7T1, false);
  numBytes += cBinop_init(&cBinop_ZvQ8kmZI, 0.0f); // __pow
  numBytes += cIf_init(&cIf_60U72cxM, false);
  numBytes += cBinop_init(&cBinop_0ShGHzpZ, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_PRQvG5zR, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_5lC35tQS, 0.0f);
  numBytes += cIf_init(&cIf_SJHMNxil, false);
  numBytes += cIf_init(&cIf_qWZDkiOi, false);
  numBytes += cBinop_init(&cBinop_JhnyF3Ck, 0.0f); // __pow
  numBytes += cIf_init(&cIf_tahi8FIC, false);
  numBytes += cBinop_init(&cBinop_xAiFUZMe, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_X6DxpYrC, -15.0f); // __eq
  numBytes += cIf_init(&cIf_K4mTyJx4, false);
  numBytes += cSlice_init(&cSlice_2EUg6OpV, 1, -1);
  numBytes += cVar_init_f(&cVar_GC8oryyf, 0.0f);
  numBytes += cSlice_init(&cSlice_lOxXKv8A, 1, -1);
  numBytes += cVar_init_f(&cVar_K8UkPzvz, 0.0f);
  numBytes += cSlice_init(&cSlice_izFWGSqo, 1, -1);
  numBytes += cVar_init_f(&cVar_43rYHGgW, 0.0f);
  numBytes += cSlice_init(&cSlice_dBpJBysl, 1, -1);
  numBytes += cVar_init_f(&cVar_PLm8e3DC, 0.313f);
  numBytes += cBinop_init(&cBinop_8bFirYD2, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_oZenSymL, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_aM8yl7Br, 0.0f);
  numBytes += cVar_init_f(&cVar_z2GjQlOk, 1337.0f);
  numBytes += cVar_init_f(&cVar_nTfM5W25, 0.3f);
  numBytes += cBinop_init(&cBinop_IxAKYdhD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lDwdlVJC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dIT9FY3Z, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5NnDDbjv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BsuTWA6V, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tUUyQYsr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AwGyy6zd, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_hhuckUgu, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_1BSuzLVa, 0.0f);
  numBytes += cVar_init_f(&cVar_kNDIs2Z0, 1337.0f);
  numBytes += cVar_init_f(&cVar_Xgir8xkJ, 0.313f);
  numBytes += cBinop_init(&cBinop_ANGlnnqo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nSDZzA8P, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vY1wldzi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rLBwWd2p, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9ZkEzTEL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gdwUFMb5, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_zW3qfOLw, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_j9NDC8Qg, 0.0f);
  numBytes += cVar_init_f(&cVar_5ekJyMZj, 1037.0f);
  numBytes += cVar_init_f(&cVar_RZjI37Rj, 0.4f);
  numBytes += cBinop_init(&cBinop_0QtCAJKD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_viBqE1Nh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_twI8klXb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iwTDhXZj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XIcRsxs8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zcVUiF7L, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_XtWUc3tO, 1, -1);
  numBytes += cVar_init_f(&cVar_gmf0TLna, 1337.0f);
  numBytes += cVar_init_f(&cVar_9WzftSxC, 0.0f);
  numBytes += cIf_init(&cIf_qIQqyknP, false);
  numBytes += cIf_init(&cIf_MqNoX3t9, false);
  numBytes += cBinop_init(&cBinop_O9FutILy, 0.0f); // __pow
  numBytes += cIf_init(&cIf_AD4SY0W9, false);
  numBytes += cBinop_init(&cBinop_N33olJAk, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_GGYTReUF, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_5jMJRe0K, 0.0f);
  numBytes += cIf_init(&cIf_JTbc6xU7, false);
  numBytes += cIf_init(&cIf_k9qGzcI6, false);
  numBytes += cBinop_init(&cBinop_mTZzkdG1, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Ql2b5qFK, false);
  numBytes += cBinop_init(&cBinop_UbjpcGky, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_4m6s1JtP, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_EwoexLan, 0.0f);
  numBytes += cIf_init(&cIf_Df3GEOYD, false);
  numBytes += cIf_init(&cIf_IafgxDPr, false);
  numBytes += cBinop_init(&cBinop_680ckwzX, 0.0f); // __pow
  numBytes += cIf_init(&cIf_y01dwNJk, false);
  numBytes += cBinop_init(&cBinop_zvI0Bpry, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_nKzutRp8, -15.0f); // __eq
  numBytes += cIf_init(&cIf_OxXbHx7L, false);
  numBytes += cSlice_init(&cSlice_KzVzxeao, 1, -1);
  numBytes += cVar_init_f(&cVar_SlVLMLcm, 0.0f);
  numBytes += cSlice_init(&cSlice_gvq9mHFR, 1, -1);
  numBytes += cVar_init_f(&cVar_qvA2Ym9i, 0.0f);
  numBytes += cSlice_init(&cSlice_ksaBQjWy, 1, -1);
  numBytes += cVar_init_f(&cVar_BmlEsJW6, 0.0f);
  numBytes += cSlice_init(&cSlice_jrvpXUKA, 1, -1);
  numBytes += cVar_init_f(&cVar_PKmnfQe6, 0.313f);
  numBytes += cBinop_init(&cBinop_Z8KQFyL7, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_cRDWQ3Ma, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_4U4npUX8, 0.0f);
  numBytes += cVar_init_f(&cVar_m5QIIEOT, 1337.0f);
  numBytes += cVar_init_f(&cVar_zBTNzEic, 0.3f);
  numBytes += cBinop_init(&cBinop_muUSatnB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sNhXUxp1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_F8T2gz5T, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nAxvQTLA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9rEzxXHe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ni8hN35s, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_h3HVXElf, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_g7oaDfvA, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_xl6sSUFY, 0.0f);
  numBytes += cVar_init_f(&cVar_OQt5KIut, 1337.0f);
  numBytes += cVar_init_f(&cVar_8YHQRdBI, 0.313f);
  numBytes += cBinop_init(&cBinop_x5o92xjZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3DQVrbOV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_pv9xGmF0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5IrYkhep, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_CI3HfR02, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_aqGONUBY, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_gOUhQ4pE, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_OPaZhprN, 0.0f);
  numBytes += cVar_init_f(&cVar_TfvSA2ap, 1037.0f);
  numBytes += cVar_init_f(&cVar_UZt4n5Z2, 0.4f);
  numBytes += cBinop_init(&cBinop_ZxPdzIqD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nWh7xA5o, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wHGkr394, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fJaPbODD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ywmgHDsC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BFfqv4jA, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_VDdPEQQk, 5705.6f);
  numBytes += cVar_init_f(&cVar_UxScprUQ, 313.3f);
  numBytes += cBinop_init(&cBinop_MD5r5gKB, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_sHJRfABv, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_GhjNfAK4, 0.0f); // __div
  numBytes += cSlice_init(&cSlice_bLoxbD1j, 1, -1);
  numBytes += cVar_init_f(&cVar_MHIXNa7B, 0.5f);
  numBytes += cVar_init_f(&cVar_wf3A4o9W, 0.0f);
  numBytes += cVar_init_f(&cVar_627egroc, 0.0f);
  numBytes += cIf_init(&cIf_aZ1Y7RBB, false);
  numBytes += cIf_init(&cIf_eS00Fhb1, false);
  numBytes += cDelay_init(this, &cDelay_YP3JaPjp, 10.0f);
  numBytes += cIf_init(&cIf_eI6Pbdiw, false);
  numBytes += cIf_init(&cIf_2DvDgzrB, false);
  numBytes += cDelay_init(this, &cDelay_eGCQdk2k, 10.0f);
  numBytes += cIf_init(&cIf_psL9jOQt, false);
  numBytes += cIf_init(&cIf_a5dx0HXa, false);
  numBytes += cDelay_init(this, &cDelay_fNpzy9tV, 10.0f);
  numBytes += cIf_init(&cIf_SOphkTLC, false);
  numBytes += cIf_init(&cIf_HwuDwTX3, false);
  numBytes += cDelay_init(this, &cDelay_HsmOyhiY, 10.0f);
  numBytes += cIf_init(&cIf_ELTJrmE7, false);
  numBytes += cIf_init(&cIf_s2vGmILa, false);
  numBytes += cDelay_init(this, &cDelay_2yXO6Ms4, 10.0f);
  numBytes += cIf_init(&cIf_vzE5txfd, false);
  numBytes += cIf_init(&cIf_PqB1toDZ, false);
  numBytes += cDelay_init(this, &cDelay_kPVMyyuR, 10.0f);
  numBytes += cIf_init(&cIf_NoEtlfh6, false);
  numBytes += cIf_init(&cIf_XVzYBq1J, false);
  numBytes += cDelay_init(this, &cDelay_npUTyDxU, 10.0f);
  numBytes += cIf_init(&cIf_yNKjMpNU, false);
  numBytes += cIf_init(&cIf_js3R7EEN, false);
  numBytes += cDelay_init(this, &cDelay_I6fbIWCX, 10.0f);
  numBytes += cIf_init(&cIf_P6ayOtWs, false);
  numBytes += cIf_init(&cIf_ajl1Nlkc, false);
  numBytes += cDelay_init(this, &cDelay_09r7VfXO, 10.0f);
  numBytes += cIf_init(&cIf_R4OPOMVb, false);
  numBytes += cIf_init(&cIf_O1tlWER0, false);
  numBytes += cDelay_init(this, &cDelay_JXKQsoX1, 10.0f);
  numBytes += cIf_init(&cIf_w6r1d1Ww, false);
  numBytes += cIf_init(&cIf_cIh4JIOq, false);
  numBytes += cDelay_init(this, &cDelay_SM8ZEUaX, 10.0f);
  numBytes += cIf_init(&cIf_1YhCyumQ, false);
  numBytes += cIf_init(&cIf_kilbiFR8, false);
  numBytes += cDelay_init(this, &cDelay_ljmybEtc, 10.0f);
  numBytes += sVarf_init(&sVarf_48VspDVH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_79Uqnye2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TOpbGLwh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0UcxhDL8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_40hBbHiH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ec3TIhOB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fKffY5aL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wE4vNsWz, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_sAXos1MU, 0.0f);
  numBytes += cSlice_init(&cSlice_gxLZMGMi, 1, -1);
  numBytes += cVar_init_f(&cVar_6ZkPzM0h, 1.0f);
  numBytes += cSlice_init(&cSlice_S2oATF3d, 1, -1);
  numBytes += cVar_init_f(&cVar_ZQtB3Ew7, 0.0f);
  numBytes += cSlice_init(&cSlice_KyhsQc9n, 1, -1);
  numBytes += cVar_init_f(&cVar_DPTqLjM0, 512.0f);
  numBytes += cSlice_init(&cSlice_5QFUGlLa, 1, -1);
  numBytes += cVar_init_f(&cVar_UJL2xvOS, 1.0f);
  numBytes += cSlice_init(&cSlice_MQcBE8eO, 1, -1);
  numBytes += cVar_init_f(&cVar_3oXlIRtK, 1.0f);
  numBytes += cDelay_init(this, &cDelay_22arNBHm, 20.0f);
  numBytes += cVar_init_f(&cVar_rVhYysNH, 0.0f);
  numBytes += cIf_init(&cIf_zWDitS35, false);
  numBytes += cIf_init(&cIf_MDcNghx6, false);
  numBytes += cBinop_init(&cBinop_jrfgDguZ, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_RqnnLDxM, 1, -1);
  numBytes += cVar_init_f(&cVar_Y2UjyjbT, 0.0f);
  numBytes += sVarf_init(&sVarf_R4AvlNSG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_H9OJQ2uV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bUZrL0dY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hxrERQye, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LjU2oEWJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6yuPbTJU, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_ThAFaZXZ, 0.0f);
  numBytes += cVar_init_f(&cVar_KEKw9CBO, 0.0f);
  numBytes += cIf_init(&cIf_VbXdRhlE, false);
  numBytes += cIf_init(&cIf_wANriSFE, false);
  numBytes += cDelay_init(this, &cDelay_7NNL62HB, 10.0f);
  numBytes += cIf_init(&cIf_cHHMLJDc, false);
  numBytes += cIf_init(&cIf_N44g5f0f, false);
  numBytes += cDelay_init(this, &cDelay_oe6sqvJK, 10.0f);
  numBytes += cIf_init(&cIf_kmHwwCnD, false);
  numBytes += cIf_init(&cIf_eqWvBmFQ, false);
  numBytes += cDelay_init(this, &cDelay_EfhbkZGv, 10.0f);
  numBytes += cIf_init(&cIf_VOl2sMaY, false);
  numBytes += cIf_init(&cIf_tMHyjdCk, false);
  numBytes += cDelay_init(this, &cDelay_zbSFXULQ, 10.0f);
  numBytes += cIf_init(&cIf_Z4ceA888, false);
  numBytes += cIf_init(&cIf_HumXArmL, false);
  numBytes += cDelay_init(this, &cDelay_TQYkGqLF, 10.0f);
  numBytes += cIf_init(&cIf_z7e1Yo0u, false);
  numBytes += cIf_init(&cIf_abVTG13e, false);
  numBytes += cDelay_init(this, &cDelay_SiDu6YqU, 10.0f);
  numBytes += cIf_init(&cIf_Y5nR2sqF, false);
  numBytes += cIf_init(&cIf_YLDnc81g, false);
  numBytes += cDelay_init(this, &cDelay_rR9c9eUP, 10.0f);
  numBytes += cIf_init(&cIf_oTXPy5x2, false);
  numBytes += cIf_init(&cIf_qGuOgWgl, false);
  numBytes += cDelay_init(this, &cDelay_b2jROwIz, 10.0f);
  numBytes += cIf_init(&cIf_R4cSQNDS, false);
  numBytes += cIf_init(&cIf_ESFoZhUc, false);
  numBytes += cDelay_init(this, &cDelay_2PbQq00c, 10.0f);
  numBytes += cIf_init(&cIf_YMiwPZHj, false);
  numBytes += cIf_init(&cIf_MjmUwVdr, false);
  numBytes += cDelay_init(this, &cDelay_CLylOAop, 10.0f);
  numBytes += cIf_init(&cIf_A39vMlI0, false);
  numBytes += cIf_init(&cIf_ngRdW3C3, false);
  numBytes += cDelay_init(this, &cDelay_TaqPYbBs, 10.0f);
  numBytes += cIf_init(&cIf_3am4IXEN, false);
  numBytes += cIf_init(&cIf_phzjNipb, false);
  numBytes += cDelay_init(this, &cDelay_0CE39y4F, 10.0f);
  numBytes += sVarf_init(&sVarf_yW081x8v, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dLxraHRx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ystYRzdd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YzXeD19K, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qPxdR0wV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BP4Dgys3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_voph3RId, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aGVkLjwM, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_R78HaHSf, 0.0f);
  numBytes += cSlice_init(&cSlice_0ib3P2S5, 1, -1);
  numBytes += cVar_init_f(&cVar_b1hWPlHw, 1.0f);
  numBytes += cSlice_init(&cSlice_VDyGpzT7, 1, -1);
  numBytes += cVar_init_f(&cVar_B4txDtRf, 0.0f);
  numBytes += cSlice_init(&cSlice_9YeTjLqg, 1, -1);
  numBytes += cVar_init_f(&cVar_ut6ezehq, 512.0f);
  numBytes += cSlice_init(&cSlice_EqBytbRd, 1, -1);
  numBytes += cVar_init_f(&cVar_GhguSBPK, 1.0f);
  numBytes += cSlice_init(&cSlice_JTNm3ZAV, 1, -1);
  numBytes += cVar_init_f(&cVar_Xw1NMszm, 1.0f);
  numBytes += cDelay_init(this, &cDelay_N4U0ZPhG, 20.0f);
  numBytes += cVar_init_f(&cVar_Iwitw4c6, 0.0f);
  numBytes += cIf_init(&cIf_tD2d1ONE, false);
  numBytes += cIf_init(&cIf_wWhLJcVl, false);
  numBytes += cBinop_init(&cBinop_Al7jTUHJ, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_8gADe7M8, 1, -1);
  numBytes += cVar_init_f(&cVar_mZ0IUyaN, 0.0f);
  numBytes += sVarf_init(&sVarf_21iT8sdT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6GTswFQP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nOS89Tl4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xbqf4jLx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2PNZFZg5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1ot7MoZK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_f6Qq7MpA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kFgHcz6K, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VpmnnU1F, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eBfmncSs, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Buxx3Lq9, 0.0f);
  numBytes += cVar_init_f(&cVar_4vYs3sgm, 0.0f);
  numBytes += cVar_init_f(&cVar_37qgh3tE, 0.0f);
  numBytes += cVar_init_f(&cVar_1b1izjbN, 0.0f);
  numBytes += cVar_init_f(&cVar_CXrLt3K3, 0.0f);
  numBytes += cVar_init_f(&cVar_S1bDL9D9, 1.0f);
  numBytes += cSlice_init(&cSlice_LaAbXmTR, 1, -1);
  numBytes += cVar_init_f(&cVar_uZfWnhLL, 0.5f);
  numBytes += cVar_init_f(&cVar_9vASn72u, 0.0f);
  numBytes += cVar_init_f(&cVar_nUjXsKkO, 0.0f);
  numBytes += cIf_init(&cIf_uLOR7JH5, false);
  numBytes += cIf_init(&cIf_VAxW3z8K, false);
  numBytes += cDelay_init(this, &cDelay_aETcbFV0, 10.0f);
  numBytes += cIf_init(&cIf_Jzb3mSdc, false);
  numBytes += cIf_init(&cIf_b5g0WaIn, false);
  numBytes += cDelay_init(this, &cDelay_RIPQu1wH, 10.0f);
  numBytes += cIf_init(&cIf_GA8Kev4m, false);
  numBytes += cIf_init(&cIf_AmhEHZRx, false);
  numBytes += cDelay_init(this, &cDelay_nKMB1Rq0, 10.0f);
  numBytes += cIf_init(&cIf_NTyhOK8c, false);
  numBytes += cIf_init(&cIf_WBRJcZxL, false);
  numBytes += cDelay_init(this, &cDelay_zPQmqDr3, 10.0f);
  numBytes += cIf_init(&cIf_FarrdO0K, false);
  numBytes += cIf_init(&cIf_sZ6MERKj, false);
  numBytes += cDelay_init(this, &cDelay_URDwlpRP, 10.0f);
  numBytes += cIf_init(&cIf_uuLJ4Ot6, false);
  numBytes += cIf_init(&cIf_aQRtz3ol, false);
  numBytes += cDelay_init(this, &cDelay_dlUOfOjQ, 10.0f);
  numBytes += cIf_init(&cIf_NmGg5SqQ, false);
  numBytes += cIf_init(&cIf_zrX09xtk, false);
  numBytes += cDelay_init(this, &cDelay_uSGXFwFL, 10.0f);
  numBytes += cIf_init(&cIf_pYjKy4UF, false);
  numBytes += cIf_init(&cIf_NbFsNfZy, false);
  numBytes += cDelay_init(this, &cDelay_cA4iE3tb, 10.0f);
  numBytes += cIf_init(&cIf_WdDy2Llk, false);
  numBytes += cIf_init(&cIf_CFZ0VJ6Y, false);
  numBytes += cDelay_init(this, &cDelay_WygRAwzw, 10.0f);
  numBytes += cIf_init(&cIf_LoIcR1nh, false);
  numBytes += cIf_init(&cIf_0VUPH01T, false);
  numBytes += cDelay_init(this, &cDelay_5WBvOaZd, 10.0f);
  numBytes += cIf_init(&cIf_YMbzYu9N, false);
  numBytes += cIf_init(&cIf_aO73SMV6, false);
  numBytes += cDelay_init(this, &cDelay_dUhEH7bi, 10.0f);
  numBytes += cIf_init(&cIf_CpP3vXXP, false);
  numBytes += cIf_init(&cIf_ZW16yINf, false);
  numBytes += cDelay_init(this, &cDelay_MuAPdhBd, 10.0f);
  numBytes += sVarf_init(&sVarf_9ayv7ARl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_20H6qoPw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dawSvtgN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Rb0ziSsZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ho7IVEcR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sgPLyfGq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lJ4Zp2HV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zlO9z2Ll, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_M6z8ZRie, 0.0f);
  numBytes += cSlice_init(&cSlice_gN94HEUw, 1, -1);
  numBytes += cVar_init_f(&cVar_QdjnaHYn, 1.0f);
  numBytes += cSlice_init(&cSlice_kNhp8V0P, 1, -1);
  numBytes += cVar_init_f(&cVar_89Extq2M, 0.0f);
  numBytes += cSlice_init(&cSlice_auBwzb5w, 1, -1);
  numBytes += cVar_init_f(&cVar_sK2BnpgX, 512.0f);
  numBytes += cSlice_init(&cSlice_7zv0UItU, 1, -1);
  numBytes += cVar_init_f(&cVar_k7lxzujy, 1.0f);
  numBytes += cSlice_init(&cSlice_JgYVTdKO, 1, -1);
  numBytes += cVar_init_f(&cVar_AqlxfQ2v, 1.0f);
  numBytes += cDelay_init(this, &cDelay_LILGbqKl, 20.0f);
  numBytes += cVar_init_f(&cVar_UL7arkBE, 0.0f);
  numBytes += cIf_init(&cIf_j1QpMAW1, false);
  numBytes += cIf_init(&cIf_Pg2SOCyM, false);
  numBytes += cBinop_init(&cBinop_wHkCxo04, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_Qc8cgAm6, 1, -1);
  numBytes += cVar_init_f(&cVar_RswpCNxH, 0.0f);
  numBytes += sVarf_init(&sVarf_xkJxL5Bb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_n8cX84MZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0CYnwvKA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fM88vnz2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gG4eQjnC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Jx7YOPRd, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_cVr9n9kR, 0.0f);
  numBytes += cVar_init_f(&cVar_5GovrkQA, 0.0f);
  numBytes += cIf_init(&cIf_W5xYOO9F, false);
  numBytes += cIf_init(&cIf_jzCTVTno, false);
  numBytes += cDelay_init(this, &cDelay_IJz1GHMh, 10.0f);
  numBytes += cIf_init(&cIf_XuM76j3X, false);
  numBytes += cIf_init(&cIf_Zlc5UmWr, false);
  numBytes += cDelay_init(this, &cDelay_EV7Gb5CS, 10.0f);
  numBytes += cIf_init(&cIf_Ka8LxVMw, false);
  numBytes += cIf_init(&cIf_dDUNlDAS, false);
  numBytes += cDelay_init(this, &cDelay_427c59m0, 10.0f);
  numBytes += cIf_init(&cIf_B3yKMugJ, false);
  numBytes += cIf_init(&cIf_xZaq62tc, false);
  numBytes += cDelay_init(this, &cDelay_WQxKyKur, 10.0f);
  numBytes += cIf_init(&cIf_npjOqs5j, false);
  numBytes += cIf_init(&cIf_VVq0Ga4I, false);
  numBytes += cDelay_init(this, &cDelay_G4SnwVKi, 10.0f);
  numBytes += cIf_init(&cIf_9qROX6bF, false);
  numBytes += cIf_init(&cIf_q0EHDHRG, false);
  numBytes += cDelay_init(this, &cDelay_Z9RCmn6d, 10.0f);
  numBytes += cIf_init(&cIf_F7zcgvRn, false);
  numBytes += cIf_init(&cIf_pGKDiWIQ, false);
  numBytes += cDelay_init(this, &cDelay_VzUUHKEv, 10.0f);
  numBytes += cIf_init(&cIf_uXnQ73LY, false);
  numBytes += cIf_init(&cIf_tWioE624, false);
  numBytes += cDelay_init(this, &cDelay_aTnzbX45, 10.0f);
  numBytes += cIf_init(&cIf_Df5c3YGR, false);
  numBytes += cIf_init(&cIf_K8ICzRxe, false);
  numBytes += cDelay_init(this, &cDelay_Wt4g4FV7, 10.0f);
  numBytes += cIf_init(&cIf_Y0U57AKq, false);
  numBytes += cIf_init(&cIf_YGMzDLcs, false);
  numBytes += cDelay_init(this, &cDelay_W5rasrjR, 10.0f);
  numBytes += cIf_init(&cIf_Fw5wrESz, false);
  numBytes += cIf_init(&cIf_3yfx3hXc, false);
  numBytes += cDelay_init(this, &cDelay_UhwqFsNn, 10.0f);
  numBytes += cIf_init(&cIf_3iUCZDUk, false);
  numBytes += cIf_init(&cIf_zNFitrAC, false);
  numBytes += cDelay_init(this, &cDelay_W8sVtYSk, 10.0f);
  numBytes += sVarf_init(&sVarf_VHPswbjZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IvSoZWb9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Mtmtgu6E, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZUWF2rUx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hfsggIGd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_W66CDLQP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fcRJlSIH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2zrugvNQ, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_AEroAmfE, 0.0f);
  numBytes += cSlice_init(&cSlice_1r0QXjWj, 1, -1);
  numBytes += cVar_init_f(&cVar_Q6uauMKE, 1.0f);
  numBytes += cSlice_init(&cSlice_ofrTXllH, 1, -1);
  numBytes += cVar_init_f(&cVar_GMv7EP9j, 0.0f);
  numBytes += cSlice_init(&cSlice_PCgg3HMl, 1, -1);
  numBytes += cVar_init_f(&cVar_A3iZxPgG, 512.0f);
  numBytes += cSlice_init(&cSlice_etF2xKbK, 1, -1);
  numBytes += cVar_init_f(&cVar_aDptkESi, 1.0f);
  numBytes += cSlice_init(&cSlice_9R6GO5AH, 1, -1);
  numBytes += cVar_init_f(&cVar_M68YG6YU, 1.0f);
  numBytes += cDelay_init(this, &cDelay_NWwVJIpT, 20.0f);
  numBytes += cVar_init_f(&cVar_EC1KbLTi, 0.0f);
  numBytes += cIf_init(&cIf_LylJ5Pfm, false);
  numBytes += cIf_init(&cIf_rsOJTeLu, false);
  numBytes += cBinop_init(&cBinop_NGxSeKLz, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_gi0Sm5yz, 1, -1);
  numBytes += cVar_init_f(&cVar_EAb2FUNH, 0.0f);
  numBytes += sVarf_init(&sVarf_hRPUUGmX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3iwkJS9M, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fAW78hc9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_icyr69Qd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EMlsGK1c, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LdYTNF1D, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_w7nhLI5I, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_V4xYawvO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Phhd5oMH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gdbzAEJW, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_m3YFGIVZ, 0.0f);
  numBytes += cVar_init_f(&cVar_ssmrCi7R, 0.0f);
  numBytes += cVar_init_f(&cVar_rJiZbPL8, 0.0f);
  numBytes += cVar_init_f(&cVar_EzngAcBT, 0.0f);
  numBytes += cVar_init_f(&cVar_xLMaQRlq, 0.0f);
  numBytes += cVar_init_f(&cVar_H7YYhhbd, 1.0f);
  numBytes += cSlice_init(&cSlice_jQZJ7Vqx, 1, -1);
  numBytes += cVar_init_f(&cVar_c5cixGjW, 0.5f);
  numBytes += cVar_init_f(&cVar_fB8c7l4h, 0.0f);
  numBytes += cVar_init_f(&cVar_mHmGa52i, 0.0f);
  numBytes += cIf_init(&cIf_EwFTaKNi, false);
  numBytes += cIf_init(&cIf_287wu5cS, false);
  numBytes += cDelay_init(this, &cDelay_KmbhoVbj, 10.0f);
  numBytes += cIf_init(&cIf_iUm65imH, false);
  numBytes += cIf_init(&cIf_rVZKd2lE, false);
  numBytes += cDelay_init(this, &cDelay_nBAyi0x7, 10.0f);
  numBytes += cIf_init(&cIf_MFP5qQ6Y, false);
  numBytes += cIf_init(&cIf_hBtR9JSI, false);
  numBytes += cDelay_init(this, &cDelay_wlOSZshg, 10.0f);
  numBytes += cIf_init(&cIf_NhYwCptO, false);
  numBytes += cIf_init(&cIf_TZ8pGGuM, false);
  numBytes += cDelay_init(this, &cDelay_HK449oLT, 10.0f);
  numBytes += cIf_init(&cIf_93n7sxT4, false);
  numBytes += cIf_init(&cIf_qutvRgQu, false);
  numBytes += cDelay_init(this, &cDelay_KJOB6O0F, 10.0f);
  numBytes += cIf_init(&cIf_pIlMMVuP, false);
  numBytes += cIf_init(&cIf_jO9abhC6, false);
  numBytes += cDelay_init(this, &cDelay_z8C31oSD, 10.0f);
  numBytes += cIf_init(&cIf_N7lPI7B3, false);
  numBytes += cIf_init(&cIf_YuFkXD0W, false);
  numBytes += cDelay_init(this, &cDelay_csQ2VY1I, 10.0f);
  numBytes += cIf_init(&cIf_2OECpdgP, false);
  numBytes += cIf_init(&cIf_6ryh4wlf, false);
  numBytes += cDelay_init(this, &cDelay_8dVJFeN9, 10.0f);
  numBytes += cIf_init(&cIf_agfaSQuh, false);
  numBytes += cIf_init(&cIf_zEzc00ZQ, false);
  numBytes += cDelay_init(this, &cDelay_OzHBMdbc, 10.0f);
  numBytes += cIf_init(&cIf_yovJ5AkJ, false);
  numBytes += cIf_init(&cIf_NvOBZRft, false);
  numBytes += cDelay_init(this, &cDelay_61am8gKN, 10.0f);
  numBytes += cIf_init(&cIf_jvnMTeWd, false);
  numBytes += cIf_init(&cIf_NTWedMiE, false);
  numBytes += cDelay_init(this, &cDelay_4WbUvump, 10.0f);
  numBytes += cIf_init(&cIf_chDyMape, false);
  numBytes += cIf_init(&cIf_hSnXm4yF, false);
  numBytes += cDelay_init(this, &cDelay_rZ4YzNB3, 10.0f);
  numBytes += sVarf_init(&sVarf_6rQApx13, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_k0qHz87i, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tFs6lBX2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CQS1aAV9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VKDmcKpi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zpg7Tb79, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Z7EK7iqV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_83ZZlnLH, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_lF8GeV1P, 0.0f);
  numBytes += cSlice_init(&cSlice_vMvO5JOg, 1, -1);
  numBytes += cVar_init_f(&cVar_qRl5n9Au, 1.0f);
  numBytes += cSlice_init(&cSlice_kmh7mgsI, 1, -1);
  numBytes += cVar_init_f(&cVar_vcGjWvE9, 0.0f);
  numBytes += cSlice_init(&cSlice_j56RDPRv, 1, -1);
  numBytes += cVar_init_f(&cVar_fWPO9Zcq, 512.0f);
  numBytes += cSlice_init(&cSlice_PSpLWk81, 1, -1);
  numBytes += cVar_init_f(&cVar_CqtW1KH5, 1.0f);
  numBytes += cSlice_init(&cSlice_W2nGZkhD, 1, -1);
  numBytes += cVar_init_f(&cVar_xthLHeVv, 1.0f);
  numBytes += cDelay_init(this, &cDelay_6cLs8naa, 20.0f);
  numBytes += cVar_init_f(&cVar_AYRaiYX1, 0.0f);
  numBytes += cIf_init(&cIf_FkI5bcU5, false);
  numBytes += cIf_init(&cIf_AcZ2xMpZ, false);
  numBytes += cBinop_init(&cBinop_3pFKw8Tz, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_u81GAqTG, 1, -1);
  numBytes += cVar_init_f(&cVar_Dty4I6eG, 0.0f);
  numBytes += sVarf_init(&sVarf_cDVgJMWS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HqUE5cUo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BhIQcjQ1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VK5UHsud, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZFtDQOoL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VxY1zPOK, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_hyeZcgLq, 0.0f);
  numBytes += cVar_init_f(&cVar_LHoN6Nzm, 0.0f);
  numBytes += cIf_init(&cIf_aT6hWdCZ, false);
  numBytes += cIf_init(&cIf_sVW4FChB, false);
  numBytes += cDelay_init(this, &cDelay_5mE9bj4B, 10.0f);
  numBytes += cIf_init(&cIf_dJ99unWs, false);
  numBytes += cIf_init(&cIf_uI7QDa7W, false);
  numBytes += cDelay_init(this, &cDelay_imnZvlLT, 10.0f);
  numBytes += cIf_init(&cIf_db6Vg1jM, false);
  numBytes += cIf_init(&cIf_2mYjbg4X, false);
  numBytes += cDelay_init(this, &cDelay_OP7KN4s9, 10.0f);
  numBytes += cIf_init(&cIf_ZNJPspGm, false);
  numBytes += cIf_init(&cIf_E0cmsVAI, false);
  numBytes += cDelay_init(this, &cDelay_FZRCJKIG, 10.0f);
  numBytes += cIf_init(&cIf_3UNcuGFI, false);
  numBytes += cIf_init(&cIf_DvtumWVu, false);
  numBytes += cDelay_init(this, &cDelay_Q6eHigju, 10.0f);
  numBytes += cIf_init(&cIf_WKQcvdxL, false);
  numBytes += cIf_init(&cIf_CjEEqE9r, false);
  numBytes += cDelay_init(this, &cDelay_zHIxJiqi, 10.0f);
  numBytes += cIf_init(&cIf_bT2Kizod, false);
  numBytes += cIf_init(&cIf_E6zBsSGn, false);
  numBytes += cDelay_init(this, &cDelay_CgmqybxV, 10.0f);
  numBytes += cIf_init(&cIf_CTrMeJEp, false);
  numBytes += cIf_init(&cIf_liqp7iZ3, false);
  numBytes += cDelay_init(this, &cDelay_mEhzfzHu, 10.0f);
  numBytes += cIf_init(&cIf_xn5tKNZo, false);
  numBytes += cIf_init(&cIf_hXRMfVV0, false);
  numBytes += cDelay_init(this, &cDelay_4QzOrBnZ, 10.0f);
  numBytes += cIf_init(&cIf_B7OBg6gf, false);
  numBytes += cIf_init(&cIf_8lGQx7eo, false);
  numBytes += cDelay_init(this, &cDelay_Q24CQiBO, 10.0f);
  numBytes += cIf_init(&cIf_rWpBlJXw, false);
  numBytes += cIf_init(&cIf_4ohcBw0K, false);
  numBytes += cDelay_init(this, &cDelay_vrkq10fB, 10.0f);
  numBytes += cIf_init(&cIf_sPCI6xjb, false);
  numBytes += cIf_init(&cIf_Z2SB5uTr, false);
  numBytes += cDelay_init(this, &cDelay_SZ76EHNb, 10.0f);
  numBytes += sVarf_init(&sVarf_Bhf2Qulj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Rykha20k, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lZXEiFs5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GbdDfjnv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_L7wLPwHs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FRODmhLf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TLGtazcF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YN4ywUSd, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_96oSfx34, 0.0f);
  numBytes += cSlice_init(&cSlice_rMUcBrVz, 1, -1);
  numBytes += cVar_init_f(&cVar_wgexMyrp, 1.0f);
  numBytes += cSlice_init(&cSlice_SuK4eRiC, 1, -1);
  numBytes += cVar_init_f(&cVar_pBUc2bq4, 0.0f);
  numBytes += cSlice_init(&cSlice_o0wdI9cm, 1, -1);
  numBytes += cVar_init_f(&cVar_vCWBhLXC, 512.0f);
  numBytes += cSlice_init(&cSlice_U25P3KnY, 1, -1);
  numBytes += cVar_init_f(&cVar_NRnEHJgw, 1.0f);
  numBytes += cSlice_init(&cSlice_YPlTRjkP, 1, -1);
  numBytes += cVar_init_f(&cVar_IuMJMf3C, 1.0f);
  numBytes += cDelay_init(this, &cDelay_aBhtEcID, 20.0f);
  numBytes += cVar_init_f(&cVar_ONpmbR0p, 0.0f);
  numBytes += cIf_init(&cIf_LQRszp61, false);
  numBytes += cIf_init(&cIf_NZ9B8Lor, false);
  numBytes += cBinop_init(&cBinop_qYv6mFiJ, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_zvUFakAW, 1, -1);
  numBytes += cVar_init_f(&cVar_ETMXhUfZ, 0.0f);
  numBytes += sVarf_init(&sVarf_Vvy9vpOY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_J4jMcuaJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UKKVvJkl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xq5f0HOu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TOE65W5e, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wSp2FIZS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_b4BBPgiu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZrXZSjRR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BfvyCdPP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_71FzrhTo, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_p70SBIlx, 0.0f);
  numBytes += cVar_init_f(&cVar_7cVLz8hg, 0.0f);
  numBytes += cVar_init_f(&cVar_wE1xsWBq, 0.0f);
  numBytes += sVarf_init(&sVarf_5EFCX5AA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Q8D1ucGp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_miupiRXD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DrC8HhQl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JEA2j0g7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MDOIVzEU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aP2zsKNU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pxadBFVJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kodbm7jG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tfighzuD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Mq9bmeOE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YUiYeO2G, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_M3NGLR::~Heavy_WSTD_M3NGLR() {
  sEnv_free(&sEnv_5qKe5h8N);
  sEnv_free(&sEnv_xxgWipqJ);
  sEnv_free(&sEnv_RzaS4zhU);
  sEnv_free(&sEnv_dqvPljUk);
  sEnv_free(&sEnv_L5B6lpDQ);
  sEnv_free(&sEnv_YIhbZgr6);
  sEnv_free(&sEnv_rnRfn47V);
  sEnv_free(&sEnv_wyvist55);
  sEnv_free(&sEnv_MkNYtrzu);
  sEnv_free(&sEnv_ccdQtJRP);
  sEnv_free(&sEnv_8f1avqgT);
  sEnv_free(&sEnv_3yVDvi4X);
}

HvTable *Heavy_WSTD_M3NGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_M3NGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SOrkKYDH_sendMessage);
      break;
    }
    case 0xCFF7A234: { // High_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AvnYv4Ll_sendMessage);
      break;
    }
    case 0x12EF45B9: { // High_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eIx9RhR4_sendMessage);
      break;
    }
    case 0xC05E9A15: { // High_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pqM1djyS_sendMessage);
      break;
    }
    case 0x8E596A67: { // High_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_u21uJmKq_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_f15D44n5_sendMessage);
      break;
    }
    case 0x585E4A54: { // High_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0lrPzH6C_sendMessage);
      break;
    }
    case 0x14A9747F: { // High_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_l4ZwBHpe_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FmXMyqFJ_sendMessage);
      break;
    }
    case 0xEBDB0C5E: { // Low_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AxAwUI06_sendMessage);
      break;
    }
    case 0xF974E926: { // Low_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ls2b0IYK_sendMessage);
      break;
    }
    case 0xBB56D13C: { // Low_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YKRnJugf_sendMessage);
      break;
    }
    case 0xB4EFBAC1: { // Low_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Gocm9jIV_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dpXGaN3I_sendMessage);
      break;
    }
    case 0x1665AEE9: { // Low_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fjtjBakp_sendMessage);
      break;
    }
    case 0x860CA1D9: { // Low_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9B1T2ND4_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZZPaJLDC_sendMessage);
      break;
    }
    case 0xEA9DEF12: { // Mid_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UQaHPA8s_sendMessage);
      break;
    }
    case 0xDBF6FE0A: { // Mid_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FhVVj21u_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RnBbH3zv_sendMessage);
      break;
    }
    case 0x23F5E910: { // Mid_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4pmwWUOz_sendMessage);
      break;
    }
    case 0x33C126B6: { // Mid_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pvN6zDsV_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2F4AdxTg_sendMessage);
      break;
    }
    case 0x64B1268F: { // Mid_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gDzU5Mrk_sendMessage);
      break;
    }
    case 0xA91022F8: { // Mid_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6ieeNXSq_sendMessage);
      break;
    }
    case 0x1AFCE6EB: { // 1025-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9QKff6Kq_sendMessage);
      break;
    }
    case 0xD8B5B1DB: { // 1025-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yXJkOP8b_sendMessage);
      break;
    }
    case 0x3794F656: { // 1025-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_O6yhNEJ7_sendMessage);
      break;
    }
    case 0x94AE0ED9: { // 1025-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_z81Bmxsk_sendMessage);
      break;
    }
    case 0xCC4DB41E: { // 1025-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5XUASl8u_sendMessage);
      break;
    }
    case 0xAFE114F6: { // 1084-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aCoH02hm_sendMessage);
      break;
    }
    case 0x98647BAD: { // 1084-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zqHRtZb4_sendMessage);
      break;
    }
    case 0xA4661944: { // 1084-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_l4b60Wmj_sendMessage);
      break;
    }
    case 0x505CED7B: { // 1125-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CjIYwEVm_sendMessage);
      break;
    }
    case 0x82611A6: { // 1125-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AnHqRhCF_sendMessage);
      break;
    }
    case 0x1B990984: { // 1125-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_s6k6xeV6_sendMessage);
      break;
    }
    case 0x5F0AFAC5: { // 1166-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9l1IvX85_sendMessage);
      break;
    }
    case 0x25349984: { // 1166-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MfnvP35B_sendMessage);
      break;
    }
    case 0x8258EF5C: { // 1166-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8zS5jx2q_sendMessage);
      break;
    }
    case 0xBC1DF870: { // 1181-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PqWeU9K1_sendMessage);
      break;
    }
    case 0x9A5A2ED: { // 1181-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_acfqYKEy_sendMessage);
      break;
    }
    case 0x6714DCEB: { // 1181-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kXJzIqrg_sendMessage);
      break;
    }
    case 0xE583CFFE: { // 1181-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zRnzPACZ_sendMessage);
      break;
    }
    case 0xA6D36AFA: { // 1181-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gUug4hQA_sendMessage);
      break;
    }
    case 0x2AD225: { // 1240-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7QWAjhfP_sendMessage);
      break;
    }
    case 0x7DD55B03: { // 1240-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XoIuqr04_sendMessage);
      break;
    }
    case 0xCF4D157B: { // 1240-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZbtJdJko_sendMessage);
      break;
    }
    case 0x4DF9D195: { // 1281-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6R94sZdv_sendMessage);
      break;
    }
    case 0x58CB5D1B: { // 1281-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7XLsh0jV_sendMessage);
      break;
    }
    case 0xE926ADAA: { // 1281-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kc8cyPpB_sendMessage);
      break;
    }
    case 0x839669AF: { // 1322-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_u4F1FbnW_sendMessage);
      break;
    }
    case 0x89AA8991: { // 1322-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4YdrVs0U_sendMessage);
      break;
    }
    case 0xC43C6A92: { // 1322-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BIxIhYJw_sendMessage);
      break;
    }
    case 0x44C46A9A: { // 1345-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9KOikjFI_sendMessage);
      break;
    }
    case 0x5B005CAA: { // 1352-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0pehrk0N_sendMessage);
      break;
    }
    case 0xBBD23460: { // 1352-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_K2LH9HzP_sendMessage);
      break;
    }
    case 0x23884B06: { // 1352-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fRiQRLPQ_sendMessage);
      break;
    }
    case 0x91BE5650: { // 1352-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eaVLVjuJ_sendMessage);
      break;
    }
    case 0x51E8B18D: { // 1352-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fuoi1YRY_sendMessage);
      break;
    }
    case 0x2CAD1402: { // 1352-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6nHpzl0M_sendMessage);
      break;
    }
    case 0x8CE949DD: { // 1470-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0j5uDFQn_sendMessage);
      break;
    }
    case 0x1A98A8C5: { // 1470-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bevtRcdk_sendMessage);
      break;
    }
    case 0x4211FC92: { // 1470-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DOGCPpbl_sendMessage);
      break;
    }
    case 0x86F6710B: { // 1470-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_d60GcozU_sendMessage);
      break;
    }
    case 0x102FAA7E: { // 1470-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GpMgF3hL_sendMessage);
      break;
    }
    case 0x1A325FAC: { // 1470-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Cq3rGCJX_sendMessage);
      break;
    }
    case 0x5FF45DD7: { // 1602-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ASarWlO4_sendMessage);
      break;
    }
    case 0xA63D49D8: { // 1609-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sXCogLd5_sendMessage);
      break;
    }
    case 0xFB1C4FF4: { // 1609-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1hOQenee_sendMessage);
      break;
    }
    case 0x2D7D2212: { // 1609-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gUv0K9QM_sendMessage);
      break;
    }
    case 0xB4610071: { // 1609-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cJ62b9Q2_sendMessage);
      break;
    }
    case 0x47BBE59E: { // 1609-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8zJOMTzW_sendMessage);
      break;
    }
    case 0xD51403EB: { // 1609-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FHqYuD0c_sendMessage);
      break;
    }
    case 0x559ECA90: { // 1727-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1ojaMLFz_sendMessage);
      break;
    }
    case 0xB4F19FB9: { // 1727-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eAHCJYCk_sendMessage);
      break;
    }
    case 0x7CE4DF88: { // 1727-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yJt7isjb_sendMessage);
      break;
    }
    case 0x9FD7A64D: { // 1727-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uzr7DWF4_sendMessage);
      break;
    }
    case 0x52C25AFE: { // 1727-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rJkJybnt_sendMessage);
      break;
    }
    case 0x801C27A5: { // 1727-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IRDdowG3_sendMessage);
      break;
    }
    case 0xE5875B65: { // 1859-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ubvayiq8_sendMessage);
      break;
    }
    case 0x40898D28: { // 1866-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vruNnkpQ_sendMessage);
      break;
    }
    case 0x9D616407: { // 1866-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hZo3JHq0_sendMessage);
      break;
    }
    case 0xE8DBDB0: { // 1866-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TCJ5bAE9_sendMessage);
      break;
    }
    case 0xD770731A: { // 1866-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jYwxN8sZ_sendMessage);
      break;
    }
    case 0x124CD18B: { // 1866-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vMeMo5wP_sendMessage);
      break;
    }
    case 0x4017FCCD: { // 1866-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HY6lASBk_sendMessage);
      break;
    }
    case 0x1B1DD5FB: { // 1984-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_i6Pv9k4w_sendMessage);
      break;
    }
    case 0xA478FA4C: { // 1984-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ih1wvV0L_sendMessage);
      break;
    }
    case 0x97EB3671: { // 1984-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eFiYCYAi_sendMessage);
      break;
    }
    case 0xF3FECDEE: { // 1984-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3dLAqCJD_sendMessage);
      break;
    }
    case 0x9558C335: { // 1984-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eQICMYu4_sendMessage);
      break;
    }
    case 0x4131288C: { // 1984-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YOEzzOjU_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mFcz6ojY_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_M3NGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Crshr";
        info->hash = 0xCFF7A234;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 2: {
        info->name = "High_Fldr";
        info->hash = 0x12EF45B9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 3: {
        info->name = "High_Gain";
        info->hash = 0xC05E9A15;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "High_Lmtr";
        info->hash = 0x8E596A67;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 5: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 6: {
        info->name = "High_Smthr";
        info->hash = 0x585E4A54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "High_Sqnc";
        info->hash = 0x14A9747F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 9: {
        info->name = "Low_Crshr";
        info->hash = 0xEBDB0C5E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 10: {
        info->name = "Low_Fldr";
        info->hash = 0xF974E926;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 11: {
        info->name = "Low_Gain";
        info->hash = 0xBB56D13C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Lmtr";
        info->hash = 0xB4EFBAC1;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 13: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 14: {
        info->name = "Low_Smthr";
        info->hash = 0x1665AEE9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 15: {
        info->name = "Low_Sqnc";
        info->hash = 0x860CA1D9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Crshr";
        info->hash = 0xEA9DEF12;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Fldr";
        info->hash = 0xDBF6FE0A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Gain";
        info->hash = 0x23F5E910;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 21: {
        info->name = "Mid_Lmtr";
        info->hash = 0x33C126B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 22: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 23: {
        info->name = "Mid_Smthr";
        info->hash = 0x64B1268F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 24: {
        info->name = "Mid_Sqnc";
        info->hash = 0xA91022F8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 25;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_M3NGLR::cVar_uaOiGexE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qBXvDANe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_R8qXHQe8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4NpKDgX1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_SL6sz9Mq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ozlSPrhv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_89xigxCj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X6ose1vt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_xaCnMqpF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Hzq95p0R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_7BAcLdpS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_U33sXbLo_sendMessage);
  cMsg_GBlxfUWE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_U33sXbLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7BAcLdpS, 1, m, &cVar_7BAcLdpS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_waIt9klw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jyxhvDqb_sendMessage(_c, 0, m);
  cMsg_pMpjZ31w_sendMessage(_c, 0, m);
  cMsg_5fo4RIE6_sendMessage(_c, 0, m);
  cMsg_k6rnj8q3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_M9v6ODGO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SQxFatgR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Ny9HVUUZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k4uSoH2J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_RU4YGpXb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UY4QWFmC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_wdDAUY0w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MXCTmEge_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GFhccGwO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_obX5AS3p_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v1WcKW0p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VSm1A9SX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6lTYbd80, 0, m, &cSlice_6lTYbd80_sendMessage);
      break;
    }
    default: {
      cSwitchcase_FbAMNnUc_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_6lTYbd80_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_2yyj4EVM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_2yyj4EVM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_SvEk1LI5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2yyj4EVM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_2yyj4EVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_O6yhNEJ7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_jPUxejQv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ZaFNfweN_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_QwRtHK6R, 0, m, &cIf_QwRtHK6R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_QwRtHK6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_zZZv9kxf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_7qzbxYbC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_cLmbqE9H_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_4bF5ylUd_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_6LQ9konN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AS0BOQnJ, HV_BINOP_POW, 0, m, &cBinop_AS0BOQnJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AS0BOQnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Nq1b05pU, 0, m, &cIf_Nq1b05pU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hq6PNajS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Dcly5ILD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KfjKgTZ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_37To5GOh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1wRq6JTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7qzbxYbC, 0, m, &cIf_7qzbxYbC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_37To5GOh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7qzbxYbC, 1, m, &cIf_7qzbxYbC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4bF5ylUd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_hq6PNajS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cLmbqE9H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Nq1b05pU, 0, m, &cIf_Nq1b05pU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Dcly5ILD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AS0BOQnJ, HV_BINOP_POW, 1, m, &cBinop_AS0BOQnJ_sendMessage);
  cMsg_6LQ9konN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_Nq1b05pU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TPXFrv2O_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_ZaFNfweN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QwRtHK6R, 1, m, &cIf_QwRtHK6R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zZZv9kxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GVVbuhZS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vFVqqgo7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZDJKsAjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KfjKgTZ2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1wRq6JTP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_59lCgc88_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Nq1b05pU, 1, m, &cIf_Nq1b05pU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jTwGogxr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N3epjLR2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_N3epjLR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_TPXFrv2O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_W09ooINC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_ZDJKsAjY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GVVbuhZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jTwGogxr, HV_BINOP_EQ, 1, m, &cBinop_jTwGogxr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vFVqqgo7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_59lCgc88, HV_BINOP_GREATER_THAN, 1, m, &cBinop_59lCgc88_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mY4Q0ujk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W09ooINC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_1wHWUyuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jPUxejQv, 0, m, &cVar_jPUxejQv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CZLUEqit_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_59lCgc88, HV_BINOP_GREATER_THAN, 0, m, &cBinop_59lCgc88_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SC3parWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jTwGogxr, HV_BINOP_EQ, 0, m, &cBinop_jTwGogxr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_kDbbFr4f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_47EOeIPG_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_eA1Tv9F7, 0, m, &cIf_eA1Tv9F7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_eA1Tv9F7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_vzrySvyM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_hKkJN7T1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_cHlS9vYF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_g7X87uVM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_QzB0Dk1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZvQ8kmZI, HV_BINOP_POW, 0, m, &cBinop_ZvQ8kmZI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZvQ8kmZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_60U72cxM, 0, m, &cIf_60U72cxM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_R4l5z6Hn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_n5yKxZ5k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NOnhghEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_1QVVx6Uz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MwUGfEFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hKkJN7T1, 0, m, &cIf_hKkJN7T1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1QVVx6Uz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hKkJN7T1, 1, m, &cIf_hKkJN7T1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_g7X87uVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_R4l5z6Hn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cHlS9vYF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_60U72cxM, 0, m, &cIf_60U72cxM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_n5yKxZ5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZvQ8kmZI, HV_BINOP_POW, 1, m, &cBinop_ZvQ8kmZI_sendMessage);
  cMsg_QzB0Dk1j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_60U72cxM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TEhFzvKk_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PZmn9KKO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_47EOeIPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eA1Tv9F7, 1, m, &cIf_eA1Tv9F7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vzrySvyM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ryc9v6GZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MpdCcBHy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yURUWe5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NOnhghEz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MwUGfEFi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0ShGHzpZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_60U72cxM, 1, m, &cIf_60U72cxM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PRQvG5zR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QNBOrvpw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QNBOrvpw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TEhFzvKk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PZmn9KKO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RgjeL4IO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_yURUWe5E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MpdCcBHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0ShGHzpZ, HV_BINOP_GREATER_THAN, 1, m, &cBinop_0ShGHzpZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ryc9v6GZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PRQvG5zR, HV_BINOP_EQ, 1, m, &cBinop_PRQvG5zR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_o1K48esX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PRQvG5zR, HV_BINOP_EQ, 0, m, &cBinop_PRQvG5zR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LU2RQbmt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RgjeL4IO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_cYZ5YTCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0ShGHzpZ, HV_BINOP_GREATER_THAN, 0, m, &cBinop_0ShGHzpZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LuSY2u55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kDbbFr4f, 0, m, &cVar_kDbbFr4f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_5lC35tQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_UzNXMejP_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_SJHMNxil, 0, m, &cIf_SJHMNxil_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_SJHMNxil_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_3EpKNfeH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_qWZDkiOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_hltebj2L_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_uas4g04x_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_ZBDSywK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JhnyF3Ck, HV_BINOP_POW, 0, m, &cBinop_JhnyF3Ck_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JhnyF3Ck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tahi8FIC, 0, m, &cIf_tahi8FIC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zMoqHS53_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_ZKVF6Hd8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qumReBnA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_s7QoNi11_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uE7iQj78_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qWZDkiOi, 0, m, &cIf_qWZDkiOi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_s7QoNi11_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qWZDkiOi, 1, m, &cIf_qWZDkiOi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uas4g04x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_zMoqHS53_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hltebj2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_tahi8FIC, 0, m, &cIf_tahi8FIC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZKVF6Hd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JhnyF3Ck, HV_BINOP_POW, 1, m, &cBinop_JhnyF3Ck_sendMessage);
  cMsg_ZBDSywK2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_tahi8FIC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zb0qYrZ5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_UzNXMejP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SJHMNxil, 1, m, &cIf_SJHMNxil_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3EpKNfeH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_W7Ef5Qaq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P1hmrBRL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XtPdw6yD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qumReBnA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uE7iQj78_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xAiFUZMe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tahi8FIC, 1, m, &cIf_tahi8FIC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_X6DxpYrC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XUIhhKw3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_XUIhhKw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_zb0qYrZ5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1zxT2uS0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_XtPdw6yD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_P1hmrBRL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xAiFUZMe, HV_BINOP_GREATER_THAN, 1, m, &cBinop_xAiFUZMe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_W7Ef5Qaq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X6DxpYrC, HV_BINOP_EQ, 1, m, &cBinop_X6DxpYrC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_28xAH4Rw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1zxT2uS0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Vh27m9Ve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5lC35tQS, 0, m, &cVar_5lC35tQS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_w0yRB37s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X6DxpYrC, HV_BINOP_EQ, 0, m, &cBinop_X6DxpYrC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FS0pMfSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xAiFUZMe, HV_BINOP_GREATER_THAN, 0, m, &cBinop_xAiFUZMe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_K4mTyJx4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_K8XvxTlX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_8CYaxN28_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_2EUg6OpV, 0, m, &cSlice_2EUg6OpV_sendMessage);
      break;
    }
    default: {
      cSwitchcase_CfEuvtJ0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_2EUg6OpV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9gZXZioE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9gZXZioE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_GC8oryyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9gZXZioE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_9gZXZioE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9QKff6Kq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_CfEuvtJ0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_lOxXKv8A, 0, m, &cSlice_lOxXKv8A_sendMessage);
      break;
    }
    default: {
      cSwitchcase_VSm1A9SX_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_lOxXKv8A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mQyFTs7R_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mQyFTs7R_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_K8UkPzvz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mQyFTs7R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_mQyFTs7R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5XUASl8u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_FbAMNnUc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_izFWGSqo, 0, m, &cSlice_izFWGSqo_sendMessage);
      break;
    }
    default: {
      cSwitchcase_BLjOd8Si_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_izFWGSqo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_2TVD8ZYv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_2TVD8ZYv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_43rYHGgW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2TVD8ZYv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_2TVD8ZYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yXJkOP8b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_BLjOd8Si_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_dBpJBysl, 0, m, &cSlice_dBpJBysl_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_dBpJBysl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_HYHXUeBd_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_HYHXUeBd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_PLm8e3DC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HYHXUeBd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_HYHXUeBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_z81Bmxsk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xha9xBjq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_G6kJ5DnP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HMWJtrWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rWKxEhfB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YylZXBP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b8VW2dOA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NBllrY2Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ya9Dn5ZW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vkjFDr6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Pqzo76Lg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_v6NlPGKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xhLaECaT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_xhLaECaT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8bFirYD2, HV_BINOP_DIVIDE, 1, m, &cBinop_8bFirYD2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Jy6DXiM9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_vQ0pBm3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_FdNCYm6b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GftPTcHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_vQ0pBm3s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FdNCYm6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8bFirYD2, HV_BINOP_DIVIDE, 0, m, &cBinop_8bFirYD2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Jy6DXiM9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GftPTcHX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_8bFirYD2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oZenSymL, HV_BINOP_MULTIPLY, 1, m, &cBinop_oZenSymL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oZenSymL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9EPIkzgO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6OJR8CtR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_Zsjd9dWd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_glouOSdw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_mybQUr4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sfjJFpDa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_GUGpDC30_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_2chT5Zqs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2chT5Zqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oZenSymL, HV_BINOP_MULTIPLY, 0, m, &cBinop_oZenSymL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MK6Xdfq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_04HaD0SU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_04HaD0SU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3kWLEKgy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_tU6DoSkU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aM8yl7Br, 1, m, &cVar_aM8yl7Br_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_aM8yl7Br_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W1e8J4sO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_qpngBZvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lDwdlVJC, HV_BINOP_MULTIPLY, 1, m, &cBinop_lDwdlVJC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gNcHAgj2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qpngBZvw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kvExouQm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_WTdJaC0J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WTdJaC0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dIT9FY3Z, HV_BINOP_MULTIPLY, 1, m, &cBinop_dIT9FY3Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PdQ07PUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5NnDDbjv, HV_BINOP_MULTIPLY, 1, m, &cBinop_5NnDDbjv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_de7PUpLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_PdQ07PUA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_usL6Ey25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BsuTWA6V, HV_BINOP_MULTIPLY, 1, m, &cBinop_BsuTWA6V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1yadRv3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_kvEUrvua_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kvEUrvua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tUUyQYsr, HV_BINOP_MULTIPLY, 1, m, &cBinop_tUUyQYsr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_z2GjQlOk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OttcZiDJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_GUGpDC30_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KcbcwXXL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_nTfM5W25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_MK6Xdfq9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9EPIkzgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_Zsjd9dWd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6OJR8CtR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_mybQUr4b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_glouOSdw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_l4b60Wmj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_sfjJFpDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zqHRtZb4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_0zVDc3eE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_aCoH02hm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3kWLEKgy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Pg8C4B2i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Pg8C4B2i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IxAKYdhD, HV_BINOP_MULTIPLY, 1, m, &cBinop_IxAKYdhD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IxAKYdhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_k6LIZEhk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_k6LIZEhk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0zVDc3eE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_W1e8J4sO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_IZ1Gyc3R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IZ1Gyc3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GiSXbxxA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KE52YZgQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_25Sbkgrz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_avZFYXuK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_glZuei42_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MsceoJ9K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lDwdlVJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xha9xBjq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_dIT9FY3Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HMWJtrWB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_5NnDDbjv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YylZXBP6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_BsuTWA6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NBllrY2Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_tUUyQYsr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vkjFDr6g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_9pueKyZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_z2GjQlOk, 0, m, &cVar_z2GjQlOk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TAc23oI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nTfM5W25, 1, m, &cVar_nTfM5W25_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GiSXbxxA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_MsceoJ9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lDwdlVJC, HV_BINOP_MULTIPLY, 0, m, &cBinop_lDwdlVJC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_avZFYXuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5NnDDbjv, HV_BINOP_MULTIPLY, 0, m, &cBinop_5NnDDbjv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_glZuei42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dIT9FY3Z, HV_BINOP_MULTIPLY, 0, m, &cBinop_dIT9FY3Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_25Sbkgrz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BsuTWA6V, HV_BINOP_MULTIPLY, 0, m, &cBinop_BsuTWA6V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KE52YZgQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tUUyQYsr, HV_BINOP_MULTIPLY, 0, m, &cBinop_tUUyQYsr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KcbcwXXL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aM8yl7Br, 0, m, &cVar_aM8yl7Br_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OttcZiDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nTfM5W25, 0, m, &cVar_nTfM5W25_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Mfvm9AKz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M1I2rTgA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LDeEcuXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RiHHQ1Md, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HmWXuedm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kqqy7VH6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_iHf8iZCP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hUk0yMz1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_6m1qqO0g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_u8yC51qL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_u8yC51qL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AwGyy6zd, HV_BINOP_DIVIDE, 1, m, &cBinop_AwGyy6zd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XgQXnR57_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_j0JQLjl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_3FWo5RGC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4FobOm4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_j0JQLjl5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3FWo5RGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AwGyy6zd, HV_BINOP_DIVIDE, 0, m, &cBinop_AwGyy6zd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XgQXnR57_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4FobOm4j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_AwGyy6zd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hhuckUgu, HV_BINOP_MULTIPLY, 1, m, &cBinop_hhuckUgu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hhuckUgu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PSCNABci_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dFXM0ncO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_2N7dob6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Pwj1qZED_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_HZ3cRNSE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_caDj0O1t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_PqNmWbPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_NPJYxrIF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NPJYxrIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hhuckUgu, HV_BINOP_MULTIPLY, 0, m, &cBinop_hhuckUgu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2knS5ivT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_01NNCFRX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_01NNCFRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FjgcsjXJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_nzYfYdan_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vY1wldzi, HV_BINOP_MULTIPLY, 1, m, &cBinop_vY1wldzi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZEZCGYfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1BSuzLVa, 1, m, &cVar_1BSuzLVa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yD8GyV1d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rLBwWd2p, HV_BINOP_MULTIPLY, 1, m, &cBinop_rLBwWd2p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QVq7mZmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_jtit4ShY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jtit4ShY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9ZkEzTEL, HV_BINOP_MULTIPLY, 1, m, &cBinop_9ZkEzTEL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_1BSuzLVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Te2w89L4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_kNDIs2Z0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pM32NJHc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_PqNmWbPT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RvJ4mBYQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_Xgir8xkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_2knS5ivT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dFXM0ncO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_HZ3cRNSE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PSCNABci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_2N7dob6T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_Pwj1qZED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_s6k6xeV6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_caDj0O1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AnHqRhCF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_EBBBoulA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CjIYwEVm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_FjgcsjXJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_iEA1k2yl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iEA1k2yl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ANGlnnqo, HV_BINOP_MULTIPLY, 1, m, &cBinop_ANGlnnqo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ANGlnnqo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0yLTB1KB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0yLTB1KB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EBBBoulA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Te2w89L4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_rbGmYhU3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rbGmYhU3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uAdfWVEk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KvaPchiK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Jji3bOn0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WCj0TyqL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nSDZzA8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Mfvm9AKz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_vY1wldzi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LDeEcuXM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_rLBwWd2p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HmWXuedm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_9ZkEzTEL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iHf8iZCP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_AguxaNK1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Xgir8xkJ, 1, m, &cVar_Xgir8xkJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GDOmYYEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kNDIs2Z0, 0, m, &cVar_kNDIs2Z0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pM32NJHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Xgir8xkJ, 0, m, &cVar_Xgir8xkJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RvJ4mBYQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1BSuzLVa, 0, m, &cVar_1BSuzLVa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WCj0TyqL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nSDZzA8P, HV_BINOP_MULTIPLY, 0, m, &cBinop_nSDZzA8P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Jji3bOn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vY1wldzi, HV_BINOP_MULTIPLY, 0, m, &cBinop_vY1wldzi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KvaPchiK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rLBwWd2p, HV_BINOP_MULTIPLY, 0, m, &cBinop_rLBwWd2p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uAdfWVEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9ZkEzTEL, HV_BINOP_MULTIPLY, 0, m, &cBinop_9ZkEzTEL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QT6Kzsf9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KfVxMb66, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_N2kIex77_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BbYzWumJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zCkomzYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BEr3sgs7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qPiNAgtO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ljfGrcXn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ySEZ2wye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_06FLLY0q, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DsQ2wkv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_f9tS6tGF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_f9tS6tGF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gdwUFMb5, HV_BINOP_DIVIDE, 1, m, &cBinop_gdwUFMb5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2q63qSQW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_aqJ5EWBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_tdrmChi6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MbGC3PT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_aqJ5EWBq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tdrmChi6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gdwUFMb5, HV_BINOP_DIVIDE, 0, m, &cBinop_gdwUFMb5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2q63qSQW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MbGC3PT6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_gdwUFMb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zW3qfOLw, HV_BINOP_MULTIPLY, 1, m, &cBinop_zW3qfOLw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zW3qfOLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T95it2Gt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TAMC1bpI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_ED6Klgtg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xLZvmUMr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_E3myvWRO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3VcYs2of_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_wHdx2EuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_qQfAldOy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qQfAldOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zW3qfOLw, HV_BINOP_MULTIPLY, 0, m, &cBinop_zW3qfOLw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_S1I4k8uo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_Q8KUYSsN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Q8KUYSsN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZJmUPdnD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_QrLY4qVi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_viBqE1Nh, HV_BINOP_MULTIPLY, 1, m, &cBinop_viBqE1Nh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xLgO47e2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rAodUqIR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rAodUqIR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_QrLY4qVi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_w7SPsoHp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_O66DRy8b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_O66DRy8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_twI8klXb, HV_BINOP_MULTIPLY, 1, m, &cBinop_twI8klXb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Zc3mop5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iwTDhXZj, HV_BINOP_MULTIPLY, 1, m, &cBinop_iwTDhXZj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oCk91E4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_zwf9Pvo6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zwf9Pvo6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Zc3mop5J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_y1C9giXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_j9NDC8Qg, 1, m, &cVar_j9NDC8Qg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SmcSbkwS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XIcRsxs8, HV_BINOP_MULTIPLY, 1, m, &cBinop_XIcRsxs8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9RVmz77M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_31kh3ubk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_31kh3ubk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zcVUiF7L, HV_BINOP_MULTIPLY, 1, m, &cBinop_zcVUiF7L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_j9NDC8Qg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VYE0B34F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_5ekJyMZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Igqp1CeN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_wHdx2EuL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SIkXR9VI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_RZjI37Rj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_S1I4k8uo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TAMC1bpI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_E3myvWRO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_T95it2Gt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_ED6Klgtg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_xLZvmUMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8zS5jx2q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_3VcYs2of_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MfnvP35B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_0udZQl37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9l1IvX85_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZJmUPdnD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_sOvToem3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sOvToem3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0QtCAJKD, HV_BINOP_MULTIPLY, 1, m, &cBinop_0QtCAJKD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0QtCAJKD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_YjyJ3ZBj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YjyJ3ZBj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0udZQl37_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VYE0B34F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_OofQbrKN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OofQbrKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mLbshCuv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RFztFxJm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WRiOQ4qD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v8GMXllg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JUIi5u3h_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Tl6NgoHW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_viBqE1Nh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QT6Kzsf9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_twI8klXb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N2kIex77_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_iwTDhXZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zCkomzYT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_XIcRsxs8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qPiNAgtO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_zcVUiF7L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ySEZ2wye_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_89ej8Z5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RZjI37Rj, 1, m, &cVar_RZjI37Rj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kYf89Gra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5ekJyMZj, 0, m, &cVar_5ekJyMZj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RFztFxJm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zcVUiF7L, HV_BINOP_MULTIPLY, 0, m, &cBinop_zcVUiF7L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JUIi5u3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_twI8klXb, HV_BINOP_MULTIPLY, 0, m, &cBinop_twI8klXb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Tl6NgoHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_viBqE1Nh, HV_BINOP_MULTIPLY, 0, m, &cBinop_viBqE1Nh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mLbshCuv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_WRiOQ4qD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XIcRsxs8, HV_BINOP_MULTIPLY, 0, m, &cBinop_XIcRsxs8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_v8GMXllg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iwTDhXZj, HV_BINOP_MULTIPLY, 0, m, &cBinop_iwTDhXZj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Igqp1CeN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RZjI37Rj, 0, m, &cVar_RZjI37Rj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SIkXR9VI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_j9NDC8Qg, 0, m, &cVar_j9NDC8Qg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uM8SM48S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K4mTyJx4, 1, m, &cIf_K4mTyJx4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZsKb6Oji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_K8XvxTlX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_aFfxcHbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZsKb6Oji_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_EVJkHV2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K4mTyJx4, 0, m, &cIf_K4mTyJx4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TPXFrv2O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XzosgNlC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_K8XvxTlX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rA9zCPq8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zb0qYrZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7oqWfbFB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_TEhFzvKk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_uM8SM48S_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_aFfxcHbL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PZmn9KKO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_EVJkHV2r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_phaCNA0Y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XtWUc3tO, 0, m, &cSlice_XtWUc3tO_sendMessage);
      break;
    }
    default: {
      cSwitchcase_EkoYx8Af_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_XtWUc3tO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qWeYggY0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qWeYggY0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_gmf0TLna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qWeYggY0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_qWeYggY0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kXJzIqrg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_9WzftSxC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ChD8ZUrJ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_qIQqyknP, 0, m, &cIf_qIQqyknP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_qIQqyknP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_23RdK7J9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_MqNoX3t9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_7gqcc7V5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_G0kgHHml_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_lhGJ7E49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_O9FutILy, HV_BINOP_POW, 0, m, &cBinop_O9FutILy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_O9FutILy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AD4SY0W9, 0, m, &cIf_AD4SY0W9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JsrRqgHT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_oONoeLyB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2p6F3bZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MqNoX3t9, 0, m, &cIf_MqNoX3t9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NZEgwcfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_YBZCmNeo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YBZCmNeo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MqNoX3t9, 1, m, &cIf_MqNoX3t9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_G0kgHHml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_JsrRqgHT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7gqcc7V5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_AD4SY0W9, 0, m, &cIf_AD4SY0W9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oONoeLyB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O9FutILy, HV_BINOP_POW, 1, m, &cBinop_O9FutILy_sendMessage);
  cMsg_lhGJ7E49_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_AD4SY0W9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GxtFmkrx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_ChD8ZUrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qIQqyknP, 1, m, &cIf_qIQqyknP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_23RdK7J9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2LbcFw50_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QQpkJQx1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_U4kUHTfM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NZEgwcfz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2p6F3bZj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_N33olJAk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AD4SY0W9, 1, m, &cIf_AD4SY0W9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GGYTReUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BwiTib5v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_BwiTib5v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_GxtFmkrx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_E5Tz2rFA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_U4kUHTfM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QQpkJQx1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N33olJAk, HV_BINOP_GREATER_THAN, 1, m, &cBinop_N33olJAk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2LbcFw50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GGYTReUF, HV_BINOP_EQ, 1, m, &cBinop_GGYTReUF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ncRt3HWI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N33olJAk, HV_BINOP_GREATER_THAN, 0, m, &cBinop_N33olJAk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XJO3HlXv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9WzftSxC, 0, m, &cVar_9WzftSxC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_a3APkwkE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E5Tz2rFA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_2y5IbO9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GGYTReUF, HV_BINOP_EQ, 0, m, &cBinop_GGYTReUF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_5jMJRe0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_oJ6zHmhW_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_JTbc6xU7, 0, m, &cIf_JTbc6xU7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_JTbc6xU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_veFRG1zO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_k9qGzcI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_diubUytV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_4RU9QDWZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_d0Vh8qKk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mTZzkdG1, HV_BINOP_POW, 0, m, &cBinop_mTZzkdG1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mTZzkdG1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ql2b5qFK, 0, m, &cIf_Ql2b5qFK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YtVs1AdT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_4q7VYGsv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_G2WmiJH2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_k9qGzcI6, 0, m, &cIf_k9qGzcI6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DaPGAWhP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_yC2TtpEU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yC2TtpEU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_k9qGzcI6, 1, m, &cIf_k9qGzcI6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4RU9QDWZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_YtVs1AdT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_diubUytV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Ql2b5qFK, 0, m, &cIf_Ql2b5qFK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4q7VYGsv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mTZzkdG1, HV_BINOP_POW, 1, m, &cBinop_mTZzkdG1_sendMessage);
  cMsg_d0Vh8qKk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_Ql2b5qFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fIrRIS9b_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_w5uRukCR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_oJ6zHmhW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JTbc6xU7, 1, m, &cIf_JTbc6xU7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_veFRG1zO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tW8bNylo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YzQveLhW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eDWdMuhc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DaPGAWhP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_G2WmiJH2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UbjpcGky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ql2b5qFK, 1, m, &cIf_Ql2b5qFK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4m6s1JtP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Tz01u69J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Tz01u69J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fIrRIS9b_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_w5uRukCR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ERuWPf5Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_eDWdMuhc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YzQveLhW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UbjpcGky, HV_BINOP_GREATER_THAN, 1, m, &cBinop_UbjpcGky_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tW8bNylo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4m6s1JtP, HV_BINOP_EQ, 1, m, &cBinop_4m6s1JtP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xjNiErES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UbjpcGky, HV_BINOP_GREATER_THAN, 0, m, &cBinop_UbjpcGky_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_b0ocfv1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5jMJRe0K, 0, m, &cVar_5jMJRe0K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_URkSf2tm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ERuWPf5Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_pzNeAggx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4m6s1JtP, HV_BINOP_EQ, 0, m, &cBinop_4m6s1JtP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_EwoexLan_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_imj0kME9_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Df3GEOYD, 0, m, &cIf_Df3GEOYD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_Df3GEOYD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_gGT19n8O_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_IafgxDPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_5lyzy87h_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_beAkplyp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_nhp2ORHl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_680ckwzX, HV_BINOP_POW, 0, m, &cBinop_680ckwzX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_680ckwzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y01dwNJk, 0, m, &cIf_y01dwNJk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1430P6SP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_ItPYCFG0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WwJ0Wc9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_gaEVmFe4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SPfTuVUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IafgxDPr, 0, m, &cIf_IafgxDPr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gaEVmFe4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IafgxDPr, 1, m, &cIf_IafgxDPr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_beAkplyp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_1430P6SP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5lyzy87h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_y01dwNJk, 0, m, &cIf_y01dwNJk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ItPYCFG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_680ckwzX, HV_BINOP_POW, 1, m, &cBinop_680ckwzX_sendMessage);
  cMsg_nhp2ORHl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_y01dwNJk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FmjO8g2q_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_imj0kME9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Df3GEOYD, 1, m, &cIf_Df3GEOYD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gGT19n8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PxsgHeOT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Pciw7ocL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tRmrwzLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WwJ0Wc9A_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SPfTuVUE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zvI0Bpry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y01dwNJk, 1, m, &cIf_y01dwNJk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nKzutRp8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gaRQcCTi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_gaRQcCTi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_FmjO8g2q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VNPSNJgi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_tRmrwzLO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PxsgHeOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nKzutRp8, HV_BINOP_EQ, 1, m, &cBinop_nKzutRp8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Pciw7ocL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zvI0Bpry, HV_BINOP_GREATER_THAN, 1, m, &cBinop_zvI0Bpry_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FRXFgg90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nKzutRp8, HV_BINOP_EQ, 0, m, &cBinop_nKzutRp8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RhcrG3Nu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zvI0Bpry, HV_BINOP_GREATER_THAN, 0, m, &cBinop_zvI0Bpry_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ukT2a0KG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VNPSNJgi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_9wXbjhxY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EwoexLan, 0, m, &cVar_EwoexLan_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_OxXbHx7L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DCIPqQk4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_uN8bRyfc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_KzVzxeao, 0, m, &cSlice_KzVzxeao_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zDn2ebm6_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_KzVzxeao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_YrTX6bdj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_YrTX6bdj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_SlVLMLcm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YrTX6bdj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_YrTX6bdj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PqWeU9K1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zDn2ebm6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gvq9mHFR, 0, m, &cSlice_gvq9mHFR_sendMessage);
      break;
    }
    default: {
      cSwitchcase_phaCNA0Y_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_gvq9mHFR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0MPGJbx4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0MPGJbx4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_qvA2Ym9i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0MPGJbx4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_0MPGJbx4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gUug4hQA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_EkoYx8Af_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ksaBQjWy, 0, m, &cSlice_ksaBQjWy_sendMessage);
      break;
    }
    default: {
      cSwitchcase_KKCqNwal_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ksaBQjWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_b7ay83NO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_b7ay83NO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_BmlEsJW6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_b7ay83NO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_b7ay83NO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_acfqYKEy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KKCqNwal_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jrvpXUKA, 0, m, &cSlice_jrvpXUKA_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_jrvpXUKA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3JLekTq5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3JLekTq5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_PKmnfQe6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3JLekTq5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_3JLekTq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zRnzPACZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ThJYQ4uG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6ja6DLGB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vFBl6uSE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Qn1vCEWR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HaBputUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YmJDT9yK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_i6LnGQsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CmXn1URJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_n6uMIim6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_02OM5bGf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_CxkKkoyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wbBvbr2Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_wbBvbr2Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z8KQFyL7, HV_BINOP_DIVIDE, 1, m, &cBinop_Z8KQFyL7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TzGHAmvT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_mriqwWWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_nznMJ9px_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZfYfbXBD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_mriqwWWF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nznMJ9px_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z8KQFyL7, HV_BINOP_DIVIDE, 0, m, &cBinop_Z8KQFyL7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TzGHAmvT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZfYfbXBD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Z8KQFyL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cRDWQ3Ma, HV_BINOP_MULTIPLY, 1, m, &cBinop_cRDWQ3Ma_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cRDWQ3Ma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z2uWYGT1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Yn2F84sO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_xOdK3K4L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_d3Ic9LF1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_3RJbcso6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_95fYoHYF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_cIfiishQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_AFkPmfyQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AFkPmfyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cRDWQ3Ma, HV_BINOP_MULTIPLY, 0, m, &cBinop_cRDWQ3Ma_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gQSvCCbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_qUAPUVdr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qUAPUVdr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R1IMUlUd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_C0XRppMc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4U4npUX8, 1, m, &cVar_4U4npUX8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_4U4npUX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mBurmQtc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_2nfvdyVw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sNhXUxp1, HV_BINOP_MULTIPLY, 1, m, &cBinop_sNhXUxp1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kxAHvcB4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_2nfvdyVw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_c7MhJmDW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_9cyHF5AB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9cyHF5AB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F8T2gz5T, HV_BINOP_MULTIPLY, 1, m, &cBinop_F8T2gz5T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BmhHWWPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nAxvQTLA, HV_BINOP_MULTIPLY, 1, m, &cBinop_nAxvQTLA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Me8lj254_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_BmhHWWPZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Cc3h49Br_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9rEzxXHe, HV_BINOP_MULTIPLY, 1, m, &cBinop_9rEzxXHe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_P5I96aAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_9MFyWc4N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9MFyWc4N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ni8hN35s, HV_BINOP_MULTIPLY, 1, m, &cBinop_ni8hN35s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_m5QIIEOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PI9THM5j_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_cIfiishQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KowUyt8i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_zBTNzEic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_gQSvCCbW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Yn2F84sO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_3RJbcso6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Z2uWYGT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_xOdK3K4L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_d3Ic9LF1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZbtJdJko_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_95fYoHYF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XoIuqr04_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_0HsMJrem_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7QWAjhfP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_R1IMUlUd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Rc7xv2aH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Rc7xv2aH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_muUSatnB, HV_BINOP_MULTIPLY, 1, m, &cBinop_muUSatnB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_muUSatnB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_BP6SHNNA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BP6SHNNA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0HsMJrem_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mBurmQtc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_LwEFJzeb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LwEFJzeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_e3bFaY2H_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kRG9Hxn1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YfL4JpwH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3AixQxSd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a3CGkLtl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6Q9iM4HN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sNhXUxp1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ThJYQ4uG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_F8T2gz5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vFBl6uSE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_nAxvQTLA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HaBputUa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_9rEzxXHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i6LnGQsy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ni8hN35s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n6uMIim6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Q5uXyBXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_m5QIIEOT, 0, m, &cVar_m5QIIEOT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_scexh7YK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zBTNzEic, 1, m, &cVar_zBTNzEic_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kRG9Hxn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ni8hN35s, HV_BINOP_MULTIPLY, 0, m, &cBinop_ni8hN35s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6Q9iM4HN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sNhXUxp1, HV_BINOP_MULTIPLY, 0, m, &cBinop_sNhXUxp1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_e3bFaY2H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_a3CGkLtl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F8T2gz5T, HV_BINOP_MULTIPLY, 0, m, &cBinop_F8T2gz5T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3AixQxSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nAxvQTLA, HV_BINOP_MULTIPLY, 0, m, &cBinop_nAxvQTLA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YfL4JpwH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9rEzxXHe, HV_BINOP_MULTIPLY, 0, m, &cBinop_9rEzxXHe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PI9THM5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zBTNzEic, 0, m, &cVar_zBTNzEic_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KowUyt8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4U4npUX8, 0, m, &cVar_4U4npUX8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2uKejUKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_o5oEcyxJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_B4gq3RAq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6P2Bccjt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_WTDrazMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ITnFN1Bt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mH0RGRhi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tR03KMGo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mYdMdTxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gWeLcYYo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_gWeLcYYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h3HVXElf, HV_BINOP_DIVIDE, 1, m, &cBinop_h3HVXElf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ClUB3cUS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_I262GyNF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_OhLfl7PG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_J2cjcjw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_I262GyNF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OhLfl7PG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h3HVXElf, HV_BINOP_DIVIDE, 0, m, &cBinop_h3HVXElf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ClUB3cUS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J2cjcjw3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_h3HVXElf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g7oaDfvA, HV_BINOP_MULTIPLY, 1, m, &cBinop_g7oaDfvA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_g7oaDfvA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rzxvqHWN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8hizXPic_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_AMlJaz5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ztsQxXz3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_X6FvmRrq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_alI7JE3S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_2FvXQFPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_HGESZ2EN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HGESZ2EN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g7oaDfvA, HV_BINOP_MULTIPLY, 0, m, &cBinop_g7oaDfvA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3Xz7zJpv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_Wa1Ok0mF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Wa1Ok0mF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lgzk1oyV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_tX3BWVll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pv9xGmF0, HV_BINOP_MULTIPLY, 1, m, &cBinop_pv9xGmF0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rI9y9WPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xl6sSUFY, 1, m, &cVar_xl6sSUFY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Zv7vgbZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5IrYkhep, HV_BINOP_MULTIPLY, 1, m, &cBinop_5IrYkhep_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XzUzVdr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FGOelRdi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FGOelRdi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CI3HfR02, HV_BINOP_MULTIPLY, 1, m, &cBinop_CI3HfR02_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_xl6sSUFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CI0eiKu0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_OQt5KIut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mhGN5qAn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_2FvXQFPS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xBUSXM47_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_8YHQRdBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_3Xz7zJpv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8hizXPic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_X6FvmRrq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rzxvqHWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_AMlJaz5K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_ztsQxXz3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kc8cyPpB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_alI7JE3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7XLsh0jV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_9R81nvOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6R94sZdv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lgzk1oyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_zlGAxU3g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zlGAxU3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x5o92xjZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_x5o92xjZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_x5o92xjZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9eSXBE2Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9eSXBE2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9R81nvOl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CI0eiKu0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_jH5j8d6S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jH5j8d6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IPelTNr5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LTbPnikq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cBL55LPx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bUjG50Rp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3DQVrbOV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2uKejUKS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_pv9xGmF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B4gq3RAq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_5IrYkhep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WTDrazMU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_CI3HfR02_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mH0RGRhi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_5sjrLAHf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OQt5KIut, 0, m, &cVar_OQt5KIut_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Bn6xLna5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8YHQRdBI, 1, m, &cVar_8YHQRdBI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xBUSXM47_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xl6sSUFY, 0, m, &cVar_xl6sSUFY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mhGN5qAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8YHQRdBI, 0, m, &cVar_8YHQRdBI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LTbPnikq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5IrYkhep, HV_BINOP_MULTIPLY, 0, m, &cBinop_5IrYkhep_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IPelTNr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CI3HfR02, HV_BINOP_MULTIPLY, 0, m, &cBinop_CI3HfR02_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bUjG50Rp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3DQVrbOV, HV_BINOP_MULTIPLY, 0, m, &cBinop_3DQVrbOV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cBL55LPx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pv9xGmF0, HV_BINOP_MULTIPLY, 0, m, &cBinop_pv9xGmF0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FdqGTLcO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GGl2P8q0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_EEkyNuSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hfK5BTgm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_kHPjad2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Oalunc8c, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_iBa4B1tt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_g88EbpX3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0tlpDbC5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fPKr2ko1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_6Eyzktm7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_onbJLVQR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_onbJLVQR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aqGONUBY, HV_BINOP_DIVIDE, 1, m, &cBinop_aqGONUBY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bLc9LdtN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_vIZom5sm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_1tdUdL38_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oYKhfb5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_vIZom5sm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1tdUdL38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aqGONUBY, HV_BINOP_DIVIDE, 0, m, &cBinop_aqGONUBY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bLc9LdtN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oYKhfb5l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_aqGONUBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gOUhQ4pE, HV_BINOP_MULTIPLY, 1, m, &cBinop_gOUhQ4pE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gOUhQ4pE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d8Cl1Ict_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kKYB0392_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_Vv1WRnwt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ikNmm5Ii_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_zfAzLBVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DvdAiy6m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_dvi275Pt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_sPaBirss_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sPaBirss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gOUhQ4pE, HV_BINOP_MULTIPLY, 0, m, &cBinop_gOUhQ4pE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lgt2uvvq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_DnT0m3g6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DnT0m3g6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1jfdPytB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_MDAaFFph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nWh7xA5o, HV_BINOP_MULTIPLY, 1, m, &cBinop_nWh7xA5o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nLMrEUZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_I3dPJQc5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_I3dPJQc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_MDAaFFph_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_guGUTZZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_xjVMc2OD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xjVMc2OD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wHGkr394, HV_BINOP_MULTIPLY, 1, m, &cBinop_wHGkr394_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AzgSqc2W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fJaPbODD, HV_BINOP_MULTIPLY, 1, m, &cBinop_fJaPbODD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NgDAPdLE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_JsQYvbSi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JsQYvbSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_AzgSqc2W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PwymIl0g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OPaZhprN, 1, m, &cVar_OPaZhprN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_klaWFjvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ywmgHDsC, HV_BINOP_MULTIPLY, 1, m, &cBinop_ywmgHDsC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SwyiXCIs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_f7BEKEbS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_f7BEKEbS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BFfqv4jA, HV_BINOP_MULTIPLY, 1, m, &cBinop_BFfqv4jA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_OPaZhprN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8byIbzV4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_TfvSA2ap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_77MQ1o5m_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_dvi275Pt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BV5mNjZ3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_UZt4n5Z2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_lgt2uvvq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_d8Cl1Ict_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_Vv1WRnwt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kKYB0392_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_zfAzLBVJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_ikNmm5Ii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BIxIhYJw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_DvdAiy6m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4YdrVs0U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_xeGxYclI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_u4F1FbnW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1jfdPytB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_frg0U3qf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_frg0U3qf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZxPdzIqD, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZxPdzIqD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZxPdzIqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_XSzSjRxM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XSzSjRxM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xeGxYclI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8byIbzV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_NX1hFYdy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NX1hFYdy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nk7zX5jA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7XYz9yCL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2TyM685Q_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PFK9YfjN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JGe0xo0x_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3l74bSqE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nWh7xA5o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FdqGTLcO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_wHGkr394_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EEkyNuSZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_fJaPbODD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kHPjad2F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ywmgHDsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iBa4B1tt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_BFfqv4jA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0tlpDbC5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_N8YEpEaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TfvSA2ap, 0, m, &cVar_TfvSA2ap_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sqBhFFYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UZt4n5Z2, 1, m, &cVar_UZt4n5Z2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7XYz9yCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BFfqv4jA, HV_BINOP_MULTIPLY, 0, m, &cBinop_BFfqv4jA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JGe0xo0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wHGkr394, HV_BINOP_MULTIPLY, 0, m, &cBinop_wHGkr394_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3l74bSqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nWh7xA5o, HV_BINOP_MULTIPLY, 0, m, &cBinop_nWh7xA5o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nk7zX5jA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_2TyM685Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ywmgHDsC, HV_BINOP_MULTIPLY, 0, m, &cBinop_ywmgHDsC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PFK9YfjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fJaPbODD, HV_BINOP_MULTIPLY, 0, m, &cBinop_fJaPbODD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_77MQ1o5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UZt4n5Z2, 0, m, &cVar_UZt4n5Z2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BV5mNjZ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OPaZhprN, 0, m, &cVar_OPaZhprN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ih8si67N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OxXbHx7L, 1, m, &cIf_OxXbHx7L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WnuciXS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_DCIPqQk4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_WH1o7eg1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WnuciXS7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_zi9epJ6f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OxXbHx7L, 0, m, &cIf_OxXbHx7L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GxtFmkrx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6YZNnS84, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DCIPqQk4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uNyIGWRH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FmjO8g2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MRkwWgNC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_fIrRIS9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Ih8si67N_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WH1o7eg1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_w5uRukCR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_zi9epJ6f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_VDdPEQQk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sHJRfABv, HV_BINOP_DIVIDE, 0, m, &cBinop_sHJRfABv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_UxScprUQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MD5r5gKB, HV_BINOP_DIVIDE, 1, m, &cBinop_MD5r5gKB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_sHJRfABv, HV_BINOP_DIVIDE, 1, m, &cBinop_sHJRfABv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_nXsqM2vx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GhjNfAK4, HV_BINOP_DIVIDE, 0, m, &cBinop_GhjNfAK4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_F8Lh0FWs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GhjNfAK4, HV_BINOP_DIVIDE, 1, m, &cBinop_GhjNfAK4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_v1WcKW0p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MD5r5gKB, HV_BINOP_DIVIDE, 0, m, &cBinop_MD5r5gKB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GFhccGwO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UxScprUQ, 0, m, &cVar_UxScprUQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_obX5AS3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VDdPEQQk, 0, m, &cVar_VDdPEQQk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MD5r5gKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_nXsqM2vx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sHJRfABv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_F8Lh0FWs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GhjNfAK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_JNxAzFoc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_z7JkFFIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_zcHajXmt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tj9g1Pl2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_OCF7rUd8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JNxAzFoc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_tj9g1Pl2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OCF7rUd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_z7JkFFIG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zcHajXmt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CcX9iZFH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_q8Do4SS9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bLoxbD1j, 0, m, &cSlice_bLoxbD1j_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_bLoxbD1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_OemfQOra_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_OemfQOra_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_MHIXNa7B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OemfQOra_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_OemfQOra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9KOikjFI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_zygpFREP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_rgA6QfYM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rgA6QfYM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_7uUYp4oi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7uUYp4oi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_jBzIyDdM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jBzIyDdM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ec3QyPNE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dmCgbBpg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ec3QyPNE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_oYGYA7XF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dmCgbBpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dRahLkzw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_oYGYA7XF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6Hthgr9N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dRahLkzw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_e7xIITmj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_e7xIITmj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_NYjfx5ko_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6Hthgr9N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BR2yK2kY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_NYjfx5ko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4aJzdJ09_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_BR2yK2kY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_k5QcbYdf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4aJzdJ09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MgYClfBv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_wf3A4o9W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W7lNM6gA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_627egroc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vGMLhjNU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3lBHkwdV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FPm21cCL_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XMYT2u13_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gzlfvl6U_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LTxKCUJ7_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yGGAZOWW_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FzJwQw3h_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_FPm21cCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ePsv9QbW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_XMYT2u13_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tf2NXA2I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_gzlfvl6U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GspxrvcI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_LTxKCUJ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5KuC3SHU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_yGGAZOWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YPCGlDzQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_FzJwQw3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_42d0d8ge_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_aZ1Y7RBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_IGfE0gJR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_eS00Fhb1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5JFa6yxY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_kmTietL9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CUEd6Ith_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CUEd6Ith_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_YP3JaPjp, 1, m, &cDelay_YP3JaPjp_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fPaKHxX4_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_YP3JaPjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YP3JaPjp, m);
  cIf_onMessage(_c, &Context(_c)->cIf_aZ1Y7RBB, 0, m, &cIf_aZ1Y7RBB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CUEd6Ith_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_YP3JaPjp, 0, m, &cDelay_YP3JaPjp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fPaKHxX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YP3JaPjp, 0, m, &cDelay_YP3JaPjp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1uanPP2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lfmSSZtg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FpgbZjmI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vjxbCBCW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NjvS8t6E_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YfwlB3jW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YfwlB3jW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kmTietL9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_NjvS8t6E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aZ1Y7RBB, 1, m, &cIf_aZ1Y7RBB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FpgbZjmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eS00Fhb1, 0, m, &cIf_eS00Fhb1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lfmSSZtg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eS00Fhb1, 1, m, &cIf_eS00Fhb1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5JFa6yxY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NbQGWOIy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_IGfE0gJR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NbQGWOIy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_eI6Pbdiw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0ecK5tim_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_2DvDgzrB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yA55bczb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_onDU0KLS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_lNU8PHoc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_lNU8PHoc_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_eGCQdk2k, 1, m, &cDelay_eGCQdk2k_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hrrqYsWp_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_eGCQdk2k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_eGCQdk2k, m);
  cIf_onMessage(_c, &Context(_c)->cIf_eI6Pbdiw, 0, m, &cIf_eI6Pbdiw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lNU8PHoc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_eGCQdk2k, 0, m, &cDelay_eGCQdk2k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hrrqYsWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_eGCQdk2k, 0, m, &cDelay_eGCQdk2k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2SInkZ7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dlQIeQ77_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hZcfbaWf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JSSIKf4N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xp05fCZ2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wrtMnoBe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xp05fCZ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eI6Pbdiw, 1, m, &cIf_eI6Pbdiw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wrtMnoBe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_onDU0KLS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_hZcfbaWf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2DvDgzrB, 0, m, &cIf_2DvDgzrB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dlQIeQ77_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2DvDgzrB, 1, m, &cIf_2DvDgzrB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yA55bczb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6mDp8joA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0ecK5tim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6mDp8joA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_psL9jOQt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GLv691Vz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_a5dx0HXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YH1DuBlV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_wSTNBhFu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_3SP1CsOj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_3SP1CsOj_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_fNpzy9tV, 1, m, &cDelay_fNpzy9tV_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HLLWdXR8_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_fNpzy9tV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fNpzy9tV, m);
  cIf_onMessage(_c, &Context(_c)->cIf_psL9jOQt, 0, m, &cIf_psL9jOQt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3SP1CsOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fNpzy9tV, 0, m, &cDelay_fNpzy9tV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HLLWdXR8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fNpzy9tV, 0, m, &cDelay_fNpzy9tV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EbV4FuTm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GB83clHX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S7GTl5ZF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Md426iAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g5nRSql4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4z16FdST_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4z16FdST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_wSTNBhFu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_g5nRSql4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_psL9jOQt, 1, m, &cIf_psL9jOQt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GB83clHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_a5dx0HXa, 1, m, &cIf_a5dx0HXa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_S7GTl5ZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_a5dx0HXa, 0, m, &cIf_a5dx0HXa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YH1DuBlV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_P4DxNeie, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GLv691Vz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_P4DxNeie, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_SOphkTLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Z84YEGDO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_HwuDwTX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dsmzFSWH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4QrbnyGy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_hDv6aWEl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_hDv6aWEl_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_HsmOyhiY, 1, m, &cDelay_HsmOyhiY_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Hkscjk7y_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_HsmOyhiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HsmOyhiY, m);
  cIf_onMessage(_c, &Context(_c)->cIf_SOphkTLC, 0, m, &cIf_SOphkTLC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hDv6aWEl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_HsmOyhiY, 0, m, &cDelay_HsmOyhiY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Hkscjk7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HsmOyhiY, 0, m, &cDelay_HsmOyhiY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LgPCqroR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pXuhEyDv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O6o3VAWT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hmUfzMwm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0xJj5ul2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_flpY5kqC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_flpY5kqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4QrbnyGy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_0xJj5ul2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SOphkTLC, 1, m, &cIf_SOphkTLC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pXuhEyDv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HwuDwTX3, 1, m, &cIf_HwuDwTX3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_O6o3VAWT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HwuDwTX3, 0, m, &cIf_HwuDwTX3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dsmzFSWH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_T6iqH1Dj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Z84YEGDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_T6iqH1Dj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ELTJrmE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3UeU6yeA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_s2vGmILa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_iotWB7IG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_b21vvsdx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_U63JetCI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_U63JetCI_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_2yXO6Ms4, 1, m, &cDelay_2yXO6Ms4_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CXvK9FcV_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_2yXO6Ms4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2yXO6Ms4, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ELTJrmE7, 0, m, &cIf_ELTJrmE7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_U63JetCI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_2yXO6Ms4, 0, m, &cDelay_2yXO6Ms4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CXvK9FcV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2yXO6Ms4, 0, m, &cDelay_2yXO6Ms4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NhzUdjAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hx3oPEmA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tURmnNRQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_W0KR2aAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2VzYTb1U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UBBqrXZ2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2VzYTb1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ELTJrmE7, 1, m, &cIf_ELTJrmE7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UBBqrXZ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_b21vvsdx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_hx3oPEmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_s2vGmILa, 1, m, &cIf_s2vGmILa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tURmnNRQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_s2vGmILa, 0, m, &cIf_s2vGmILa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iotWB7IG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CkaVCiCz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3UeU6yeA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CkaVCiCz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_vzE5txfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MbIC3h35_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_PqB1toDZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NirkUPdk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_FYczmT1K_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_oop6VC8I_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_oop6VC8I_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_kPVMyyuR, 1, m, &cDelay_kPVMyyuR_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L27OkT3m_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_kPVMyyuR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kPVMyyuR, m);
  cIf_onMessage(_c, &Context(_c)->cIf_vzE5txfd, 0, m, &cIf_vzE5txfd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oop6VC8I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_kPVMyyuR, 0, m, &cDelay_kPVMyyuR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_L27OkT3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kPVMyyuR, 0, m, &cDelay_kPVMyyuR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aak4EPX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1ye067yY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FuOUF5cK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DqHubyAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LmT8AHPC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DIFUC48J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DIFUC48J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_FYczmT1K_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_LmT8AHPC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vzE5txfd, 1, m, &cIf_vzE5txfd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1ye067yY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PqB1toDZ, 1, m, &cIf_PqB1toDZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FuOUF5cK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PqB1toDZ, 0, m, &cIf_PqB1toDZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NirkUPdk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JRFySmqY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MbIC3h35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JRFySmqY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_NoEtlfh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DhXfsl1C_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_XVzYBq1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_o4Gq8cBi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Q1uftQ69_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_yznuM6kW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_yznuM6kW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_npUTyDxU, 1, m, &cDelay_npUTyDxU_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iXpXf9Us_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_npUTyDxU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_npUTyDxU, m);
  cIf_onMessage(_c, &Context(_c)->cIf_NoEtlfh6, 0, m, &cIf_NoEtlfh6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yznuM6kW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_npUTyDxU, 0, m, &cDelay_npUTyDxU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iXpXf9Us_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_npUTyDxU, 0, m, &cDelay_npUTyDxU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QNwW32Lj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hjQRAFNo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CKaphqR9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7oNW8rFo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oEcA4seD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lxwYAlBQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lxwYAlBQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Q1uftQ69_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_oEcA4seD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NoEtlfh6, 1, m, &cIf_NoEtlfh6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CKaphqR9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XVzYBq1J, 0, m, &cIf_XVzYBq1J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hjQRAFNo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XVzYBq1J, 1, m, &cIf_XVzYBq1J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_o4Gq8cBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jyOmKENv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DhXfsl1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jyOmKENv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_yNKjMpNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nJI00m6p_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_js3R7EEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_pVjhWIs0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6b5AYKYv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Y9BmP2mh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Y9BmP2mh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_I6fbIWCX, 1, m, &cDelay_I6fbIWCX_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Kf2EOSGS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_I6fbIWCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_I6fbIWCX, m);
  cIf_onMessage(_c, &Context(_c)->cIf_yNKjMpNU, 0, m, &cIf_yNKjMpNU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Y9BmP2mh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_I6fbIWCX, 0, m, &cDelay_I6fbIWCX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Kf2EOSGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_I6fbIWCX, 0, m, &cDelay_I6fbIWCX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_57iT774K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T4iMWN10_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4wqydpm5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_US5LBgC0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P2EjSOWe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ByWEOaep_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ByWEOaep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6b5AYKYv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_P2EjSOWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yNKjMpNU, 1, m, &cIf_yNKjMpNU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4wqydpm5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_js3R7EEN, 0, m, &cIf_js3R7EEN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_T4iMWN10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_js3R7EEN, 1, m, &cIf_js3R7EEN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pVjhWIs0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_g1PHdxfQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_nJI00m6p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_g1PHdxfQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_P6ayOtWs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TVHqNgO2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ajl1Nlkc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Ph6VUWkM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_vCBnu0ZN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_LyFPfbmF_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_LyFPfbmF_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_09r7VfXO, 1, m, &cDelay_09r7VfXO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_78rdPMLI_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_09r7VfXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_09r7VfXO, m);
  cIf_onMessage(_c, &Context(_c)->cIf_P6ayOtWs, 0, m, &cIf_P6ayOtWs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LyFPfbmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_09r7VfXO, 0, m, &cDelay_09r7VfXO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_78rdPMLI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_09r7VfXO, 0, m, &cDelay_09r7VfXO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ekv575s0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WKi3lEfS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Gk4wOA6J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SvXJRFrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nhEoKh7l_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2AY7zE0g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2AY7zE0g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vCBnu0ZN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_nhEoKh7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_P6ayOtWs, 1, m, &cIf_P6ayOtWs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WKi3lEfS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ajl1Nlkc, 1, m, &cIf_ajl1Nlkc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Gk4wOA6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ajl1Nlkc, 0, m, &cIf_ajl1Nlkc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ph6VUWkM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_73ao6fc2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_TVHqNgO2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_73ao6fc2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_R4OPOMVb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_IKpzOgXC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_O1tlWER0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_or5WYK1V_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_AQF4ld5v_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ioQRvpTi_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ioQRvpTi_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_JXKQsoX1, 1, m, &cDelay_JXKQsoX1_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LkCv3dWt_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_JXKQsoX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JXKQsoX1, m);
  cIf_onMessage(_c, &Context(_c)->cIf_R4OPOMVb, 0, m, &cIf_R4OPOMVb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ioQRvpTi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JXKQsoX1, 0, m, &cDelay_JXKQsoX1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LkCv3dWt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JXKQsoX1, 0, m, &cDelay_JXKQsoX1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fEr5NAYQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QxrOx71j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UxLsWR3I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BYEOUVaX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_G0l9p32y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0i7CnMqa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0i7CnMqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_AQF4ld5v_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_G0l9p32y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R4OPOMVb, 1, m, &cIf_R4OPOMVb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QxrOx71j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O1tlWER0, 1, m, &cIf_O1tlWER0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UxLsWR3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O1tlWER0, 0, m, &cIf_O1tlWER0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_or5WYK1V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1duFCYvx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_IKpzOgXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1duFCYvx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_w6r1d1Ww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gFM1rhal_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_cIh4JIOq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_46Ft6dbN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PYB1FWTq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_lfjFhFkd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_lfjFhFkd_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_SM8ZEUaX, 1, m, &cDelay_SM8ZEUaX_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nTDorhsU_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_SM8ZEUaX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SM8ZEUaX, m);
  cIf_onMessage(_c, &Context(_c)->cIf_w6r1d1Ww, 0, m, &cIf_w6r1d1Ww_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lfjFhFkd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_SM8ZEUaX, 0, m, &cDelay_SM8ZEUaX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nTDorhsU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SM8ZEUaX, 0, m, &cDelay_SM8ZEUaX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_biI3ng0n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s9bUWgjL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OhrPc3cS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dN8VSOqu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_978dED3n_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4cDzeIDs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4cDzeIDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_PYB1FWTq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_978dED3n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_w6r1d1Ww, 1, m, &cIf_w6r1d1Ww_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_s9bUWgjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cIh4JIOq, 1, m, &cIf_cIh4JIOq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OhrPc3cS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cIh4JIOq, 0, m, &cIf_cIh4JIOq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_46Ft6dbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jIC9Pqu1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gFM1rhal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jIC9Pqu1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_1YhCyumQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ajrZSeuw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_kilbiFR8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FWQUYfT1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_GKcdfHVU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Pj4RoiNc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Pj4RoiNc_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ljmybEtc, 1, m, &cDelay_ljmybEtc_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pDH2dLtr_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ljmybEtc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ljmybEtc, m);
  cIf_onMessage(_c, &Context(_c)->cIf_1YhCyumQ, 0, m, &cIf_1YhCyumQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Pj4RoiNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ljmybEtc, 0, m, &cDelay_ljmybEtc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pDH2dLtr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ljmybEtc, 0, m, &cDelay_ljmybEtc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_t48LqFMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mMbfSRMb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oShe3EJz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uflEwWgl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MEYrwrnO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_INGhPYyF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_INGhPYyF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_GKcdfHVU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_MEYrwrnO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1YhCyumQ, 1, m, &cIf_1YhCyumQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mMbfSRMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kilbiFR8, 1, m, &cIf_kilbiFR8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oShe3EJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kilbiFR8, 0, m, &cIf_kilbiFR8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FWQUYfT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M5W5fIjK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ajrZSeuw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M5W5fIjK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ePsv9QbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_08REaNDN_sendMessage(_c, 0, m);
  cMsg_chEi7s95_sendMessage(_c, 0, m);
  cMsg_SivyrVEx_sendMessage(_c, 0, m);
  cMsg_cXbkzrU6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_tf2NXA2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_08REaNDN_sendMessage(_c, 0, m);
  cMsg_8lvnyjen_sendMessage(_c, 0, m);
  cMsg_s70uOBoL_sendMessage(_c, 0, m);
  cMsg_6HFxZYJu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GspxrvcI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_iPoCijE6_sendMessage(_c, 0, m);
  cMsg_8lvnyjen_sendMessage(_c, 0, m);
  cMsg_cXbkzrU6_sendMessage(_c, 0, m);
  cMsg_pf6Im3AF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5KuC3SHU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_iPoCijE6_sendMessage(_c, 0, m);
  cMsg_MfhgzsxT_sendMessage(_c, 0, m);
  cMsg_SivyrVEx_sendMessage(_c, 0, m);
  cMsg_ZMKnDfEi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_YPCGlDzQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_OT4re9WI_sendMessage(_c, 0, m);
  cMsg_6HFxZYJu_sendMessage(_c, 0, m);
  cMsg_iKWDdv6D_sendMessage(_c, 0, m);
  cMsg_SivyrVEx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_42d0d8ge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_OT4re9WI_sendMessage(_c, 0, m);
  cMsg_ZMKnDfEi_sendMessage(_c, 0, m);
  cMsg_8lvnyjen_sendMessage(_c, 0, m);
  cMsg_yZZWycjf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GpIABzS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vjxbCBCW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1uanPP2U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_X0sSFzkM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vjxbCBCW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1uanPP2U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_m23RXWUV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JSSIKf4N_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2SInkZ7P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_phbnKOZt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JSSIKf4N_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2SInkZ7P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_If8O4TwK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Md426iAM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EbV4FuTm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CZXb1b0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Md426iAM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EbV4FuTm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_08REaNDN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_GpIABzS3_sendMessage(_c, 0, m);
  cMsg_phbnKOZt_sendMessage(_c, 0, m);
  cMsg_CZXb1b0b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_iPoCijE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_X0sSFzkM_sendMessage(_c, 0, m);
  cMsg_m23RXWUV_sendMessage(_c, 0, m);
  cMsg_CZXb1b0b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OT4re9WI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_X0sSFzkM_sendMessage(_c, 0, m);
  cMsg_phbnKOZt_sendMessage(_c, 0, m);
  cMsg_If8O4TwK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_v7VZG7WS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hmUfzMwm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LgPCqroR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cBmmymu2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hmUfzMwm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LgPCqroR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uIUlGSZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_W0KR2aAH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NhzUdjAF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IFE6fGux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_W0KR2aAH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NhzUdjAF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kqR1hSAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DqHubyAS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_aak4EPX0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jH3QrZgl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DqHubyAS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_aak4EPX0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8lvnyjen_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_cBmmymu2_sendMessage(_c, 0, m);
  cMsg_IFE6fGux_sendMessage(_c, 0, m);
  cMsg_jH3QrZgl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_chEi7s95_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_cBmmymu2_sendMessage(_c, 0, m);
  cMsg_uIUlGSZY_sendMessage(_c, 0, m);
  cMsg_kqR1hSAC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MfhgzsxT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_v7VZG7WS_sendMessage(_c, 0, m);
  cMsg_IFE6fGux_sendMessage(_c, 0, m);
  cMsg_kqR1hSAC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_l2SCFUPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BYEOUVaX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fEr5NAYQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TNAl95xv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BYEOUVaX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fEr5NAYQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QgsEDQ5L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dN8VSOqu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_biI3ng0n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1e3UgBEW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dN8VSOqu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_biI3ng0n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_22LJuAAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_uflEwWgl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_t48LqFMW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BshpQs8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_uflEwWgl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_t48LqFMW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZMKnDfEi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_l2SCFUPR_sendMessage(_c, 0, m);
  cMsg_1e3UgBEW_sendMessage(_c, 0, m);
  cMsg_BshpQs8G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6HFxZYJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_TNAl95xv_sendMessage(_c, 0, m);
  cMsg_QgsEDQ5L_sendMessage(_c, 0, m);
  cMsg_BshpQs8G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cXbkzrU6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_TNAl95xv_sendMessage(_c, 0, m);
  cMsg_1e3UgBEW_sendMessage(_c, 0, m);
  cMsg_22LJuAAn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xsKWM9pN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7oNW8rFo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QNwW32Lj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_k84KOGlR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7oNW8rFo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QNwW32Lj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AXQJZ0OU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_US5LBgC0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_57iT774K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KqemrzMv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_US5LBgC0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_57iT774K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_R5Qxhptt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SvXJRFrP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ekv575s0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kmQUaYQW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SvXJRFrP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ekv575s0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SivyrVEx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_k84KOGlR_sendMessage(_c, 0, m);
  cMsg_KqemrzMv_sendMessage(_c, 0, m);
  cMsg_kmQUaYQW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_s70uOBoL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_k84KOGlR_sendMessage(_c, 0, m);
  cMsg_AXQJZ0OU_sendMessage(_c, 0, m);
  cMsg_R5Qxhptt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_yZZWycjf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_xsKWM9pN_sendMessage(_c, 0, m);
  cMsg_AXQJZ0OU_sendMessage(_c, 0, m);
  cMsg_kmQUaYQW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_iKWDdv6D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_v7VZG7WS_sendMessage(_c, 0, m);
  cMsg_uIUlGSZY_sendMessage(_c, 0, m);
  cMsg_jH3QrZgl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pf6Im3AF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_xsKWM9pN_sendMessage(_c, 0, m);
  cMsg_KqemrzMv_sendMessage(_c, 0, m);
  cMsg_R5Qxhptt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_sAXos1MU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GKSIvh5j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VbYaoiUU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gxLZMGMi, 0, m, &cSlice_gxLZMGMi_sendMessage);
      break;
    }
    default: {
      cSwitchcase_A6AJcKo4_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_gxLZMGMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_4j5CwK68_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_4j5CwK68_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_6ZkPzM0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4j5CwK68_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_4j5CwK68_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_K2LH9HzP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3ZBl5JV6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_S2oATF3d, 0, m, &cSlice_S2oATF3d_sendMessage);
      break;
    }
    default: {
      cSwitchcase_aXp0F3UG_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_S2oATF3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_lmZvlVCX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_lmZvlVCX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ZQtB3Ew7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lmZvlVCX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_lmZvlVCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6nHpzl0M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_aXp0F3UG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_KyhsQc9n, 0, m, &cSlice_KyhsQc9n_sendMessage);
      break;
    }
    default: {
      cSwitchcase_VbYaoiUU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_KyhsQc9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EDTaepm6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EDTaepm6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_DPTqLjM0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EDTaepm6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_EDTaepm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0pehrk0N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_A6AJcKo4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5QFUGlLa, 0, m, &cSlice_5QFUGlLa_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Q0RpUO45_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_5QFUGlLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ctyoEzdv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ctyoEzdv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_UJL2xvOS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ctyoEzdv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ctyoEzdv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fuoi1YRY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Q0RpUO45_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MQcBE8eO, 0, m, &cSlice_MQcBE8eO_sendMessage);
      break;
    }
    default: {
      cSwitchcase_V2v4X6zS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_MQcBE8eO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mGbE7yDi_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mGbE7yDi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_3oXlIRtK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mGbE7yDi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_mGbE7yDi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eaVLVjuJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_y2sajco1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_YBSQRlt6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_YBSQRlt6_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_22arNBHm, 1, m, &cDelay_22arNBHm_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zBDcNV43_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_22arNBHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_22arNBHm, m);
  cMsg_REtxt1bi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_YBSQRlt6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_22arNBHm, 0, m, &cDelay_22arNBHm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zBDcNV43_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_22arNBHm, 0, m, &cDelay_22arNBHm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_rVhYysNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jrfgDguZ, HV_BINOP_SUBTRACT, 0, m, &cBinop_jrfgDguZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_zWDitS35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BfJP5TnH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_MDcNghx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BfJP5TnH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_5qKe5h8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rVhYysNH, 0, m, &cVar_rVhYysNH_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_xxgWipqJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aBV66Nw3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dfivntYI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oqzMkWtb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jrfgDguZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X59gglOd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_X59gglOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Xsf7MS33_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Xsf7MS33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_3CkLOM6s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4qIPJiXb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SVSZ5BGa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OgsevxMi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OgsevxMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nAV8rOJw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_SVSZ5BGa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zWDitS35, 1, m, &cIf_zWDitS35_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Fe8hk6ld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MDcNghx6, 1, m, &cIf_MDcNghx6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nAV8rOJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_zWDitS35, 0, m, &cIf_zWDitS35_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3CkLOM6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MDcNghx6, 0, m, &cIf_MDcNghx6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oqzMkWtb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rVhYysNH, 0, m, &cVar_rVhYysNH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aBV66Nw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_dfivntYI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jrfgDguZ, HV_BINOP_SUBTRACT, 1, m, &cBinop_jrfgDguZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BfJP5TnH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SNYQFNYb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_V2v4X6zS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_RqnnLDxM, 0, m, &cSlice_RqnnLDxM_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_RqnnLDxM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5ptvs8F9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5ptvs8F9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Y2UjyjbT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5ptvs8F9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_5ptvs8F9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fRiQRLPQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_W7lNM6gA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FZaJMQYo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vGMLhjNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VL1XDnDV, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_XTUG5e9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_627egroc, 0, m, &cVar_627egroc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GKSIvh5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DufrcJW8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_3Nq0rEJl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3K0c7KVE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_fHotjAvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_y2sajco1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_REtxt1bi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zVg5tvTx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3K0c7KVE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zVg5tvTx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_C73NySOP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_eBoRj2H1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eBoRj2H1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C9tIDQTy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_C9tIDQTy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DwBPjfyo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_ThAFaZXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EFlWLLY0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_KEKw9CBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OCiKbbnb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Z4ZQw9TF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Qlx4zztz_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FIlFXmiX_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T3yL4qRg_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_my7IToVc_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ExbnyfOy_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7Yq0skeX_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_Qlx4zztz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_U4MwSPs8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_FIlFXmiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pjgqn0FU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_T3yL4qRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dEZyQOLO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_my7IToVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YZCw2id2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_ExbnyfOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nfaIDHrJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_7Yq0skeX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n6usL4TI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_VbXdRhlE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Pu5OjuYH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_wANriSFE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bigszcUv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_58ffT9xw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_poxJzWI3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_poxJzWI3_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7NNL62HB, 1, m, &cDelay_7NNL62HB_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FoHubLHh_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_7NNL62HB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7NNL62HB, m);
  cIf_onMessage(_c, &Context(_c)->cIf_VbXdRhlE, 0, m, &cIf_VbXdRhlE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_poxJzWI3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7NNL62HB, 0, m, &cDelay_7NNL62HB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FoHubLHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7NNL62HB, 0, m, &cDelay_7NNL62HB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dyhLEQW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QIOgSWrp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mIfMk9sT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_W2OaIM1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8EIJILua_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nBwPl4wr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nBwPl4wr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_58ffT9xw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_8EIJILua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VbXdRhlE, 1, m, &cIf_VbXdRhlE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QIOgSWrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wANriSFE, 1, m, &cIf_wANriSFE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mIfMk9sT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wANriSFE, 0, m, &cIf_wANriSFE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bigszcUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pKleR778, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Pu5OjuYH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pKleR778, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_cHHMLJDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0a4iubja_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_N44g5f0f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Zyi3EUVz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_T1P3sf7H_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0LE7icgd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0LE7icgd_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_oe6sqvJK, 1, m, &cDelay_oe6sqvJK_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0Xcch0SM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_oe6sqvJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oe6sqvJK, m);
  cIf_onMessage(_c, &Context(_c)->cIf_cHHMLJDc, 0, m, &cIf_cHHMLJDc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0LE7icgd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_oe6sqvJK, 0, m, &cDelay_oe6sqvJK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0Xcch0SM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oe6sqvJK, 0, m, &cDelay_oe6sqvJK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NJTubd90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PA7X8Hm3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iK6XqFLu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ieBTBeov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iqRPE7Ef_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yeR1mRDj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yeR1mRDj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_T1P3sf7H_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_iqRPE7Ef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cHHMLJDc, 1, m, &cIf_cHHMLJDc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iK6XqFLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_N44g5f0f, 0, m, &cIf_N44g5f0f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PA7X8Hm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_N44g5f0f, 1, m, &cIf_N44g5f0f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Zyi3EUVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yU6rar4v, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0a4iubja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yU6rar4v, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_kmHwwCnD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VP7LGbsU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_eqWvBmFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Uyxz4J6q_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_o0jMfvP6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_U9Za7YhJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_U9Za7YhJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_EfhbkZGv, 1, m, &cDelay_EfhbkZGv_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tXbJcpDx_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_EfhbkZGv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EfhbkZGv, m);
  cIf_onMessage(_c, &Context(_c)->cIf_kmHwwCnD, 0, m, &cIf_kmHwwCnD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_U9Za7YhJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_EfhbkZGv, 0, m, &cDelay_EfhbkZGv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tXbJcpDx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EfhbkZGv, 0, m, &cDelay_EfhbkZGv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_km4bZMZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4mT82iCx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hwz6xP49_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dkRv4uu5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RgPMvb8f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9LBZYWsb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9LBZYWsb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_o0jMfvP6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_RgPMvb8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kmHwwCnD, 1, m, &cIf_kmHwwCnD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4mT82iCx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eqWvBmFQ, 1, m, &cIf_eqWvBmFQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hwz6xP49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eqWvBmFQ, 0, m, &cIf_eqWvBmFQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Uyxz4J6q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e5AhCPL1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_VP7LGbsU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e5AhCPL1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_VOl2sMaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vYeAKIId_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_tMHyjdCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_I91qtNrM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ko7kC1x5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ppwu4for_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ppwu4for_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_zbSFXULQ, 1, m, &cDelay_zbSFXULQ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_l7tPH3KK_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_zbSFXULQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zbSFXULQ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_VOl2sMaY, 0, m, &cIf_VOl2sMaY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ppwu4for_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zbSFXULQ, 0, m, &cDelay_zbSFXULQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_l7tPH3KK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zbSFXULQ, 0, m, &cDelay_zbSFXULQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Oz7DNqGO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ra1iVIgy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BC1w135M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_89HRqSBc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TRwj4nMp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DFxOyJIt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TRwj4nMp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VOl2sMaY, 1, m, &cIf_VOl2sMaY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DFxOyJIt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ko7kC1x5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_BC1w135M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tMHyjdCk, 0, m, &cIf_tMHyjdCk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ra1iVIgy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tMHyjdCk, 1, m, &cIf_tMHyjdCk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_I91qtNrM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_61CQDJRQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vYeAKIId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_61CQDJRQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Z4ceA888_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_D18v27kw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_HumXArmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Pffb8x7j_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_jhSV7Aeq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_v6GSBCm6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_v6GSBCm6_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_TQYkGqLF, 1, m, &cDelay_TQYkGqLF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xubRb1C6_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_TQYkGqLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TQYkGqLF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Z4ceA888, 0, m, &cIf_Z4ceA888_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_v6GSBCm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_TQYkGqLF, 0, m, &cDelay_TQYkGqLF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xubRb1C6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TQYkGqLF, 0, m, &cDelay_TQYkGqLF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wDNoo761_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_U7cubq8W_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SACaqCy0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zsOmqENk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7rKfdUoU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8Bz4qCLQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8Bz4qCLQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_jhSV7Aeq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_7rKfdUoU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Z4ceA888, 1, m, &cIf_Z4ceA888_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SACaqCy0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HumXArmL, 0, m, &cIf_HumXArmL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_U7cubq8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HumXArmL, 1, m, &cIf_HumXArmL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Pffb8x7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ve6czca2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_D18v27kw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ve6czca2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_z7e1Yo0u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zSCKJz4a_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_abVTG13e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AjS8cDrZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0LjykC4m_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_OdCVYmyW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_OdCVYmyW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_SiDu6YqU, 1, m, &cDelay_SiDu6YqU_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dlQmIVOi_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_SiDu6YqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SiDu6YqU, m);
  cIf_onMessage(_c, &Context(_c)->cIf_z7e1Yo0u, 0, m, &cIf_z7e1Yo0u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OdCVYmyW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_SiDu6YqU, 0, m, &cDelay_SiDu6YqU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dlQmIVOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SiDu6YqU, 0, m, &cDelay_SiDu6YqU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2YVDHldh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YHjvvHK9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dam7XflB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kjnGLcaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mLZRzZxn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wwzLFzQt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wwzLFzQt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0LjykC4m_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_mLZRzZxn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_z7e1Yo0u, 1, m, &cIf_z7e1Yo0u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dam7XflB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_abVTG13e, 0, m, &cIf_abVTG13e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YHjvvHK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_abVTG13e, 1, m, &cIf_abVTG13e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AjS8cDrZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lIAr0GaR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zSCKJz4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lIAr0GaR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Y5nR2sqF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wy8zU4Iv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_YLDnc81g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KOZDWM1z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_TisSuGDx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_sFqaPSXR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_sFqaPSXR_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_rR9c9eUP, 1, m, &cDelay_rR9c9eUP_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a7wFLiLK_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_rR9c9eUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rR9c9eUP, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Y5nR2sqF, 0, m, &cIf_Y5nR2sqF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sFqaPSXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_rR9c9eUP, 0, m, &cDelay_rR9c9eUP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_a7wFLiLK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rR9c9eUP, 0, m, &cDelay_rR9c9eUP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Lvo88vCe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dj2IHomF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LbdNXAbo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_irUjPYem_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YKLfKh4H_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rf0fR5sE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rf0fR5sE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_TisSuGDx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_YKLfKh4H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Y5nR2sqF, 1, m, &cIf_Y5nR2sqF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dj2IHomF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YLDnc81g, 1, m, &cIf_YLDnc81g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LbdNXAbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YLDnc81g, 0, m, &cIf_YLDnc81g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KOZDWM1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nMoDIXtv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wy8zU4Iv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nMoDIXtv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_oTXPy5x2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ikr1FNO2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_qGuOgWgl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jvTN4yXa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_xpJcOaIK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_lJk19lOb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_lJk19lOb_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_b2jROwIz, 1, m, &cDelay_b2jROwIz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uAX9j1Ye_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_b2jROwIz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_b2jROwIz, m);
  cIf_onMessage(_c, &Context(_c)->cIf_oTXPy5x2, 0, m, &cIf_oTXPy5x2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lJk19lOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_b2jROwIz, 0, m, &cDelay_b2jROwIz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uAX9j1Ye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_b2jROwIz, 0, m, &cDelay_b2jROwIz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xPt6Da0Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_heOR77Fk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v5E6xXsg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WrKwOnXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dvXskGkC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F2OXYEo2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_F2OXYEo2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xpJcOaIK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_dvXskGkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oTXPy5x2, 1, m, &cIf_oTXPy5x2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_heOR77Fk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qGuOgWgl, 1, m, &cIf_qGuOgWgl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_v5E6xXsg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qGuOgWgl, 0, m, &cIf_qGuOgWgl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jvTN4yXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xkO4WGPp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ikr1FNO2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xkO4WGPp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_R4cSQNDS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yaJ8pFPw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ESFoZhUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_G50rSon9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_IiOWEuvN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_3uUv1nwQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_3uUv1nwQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_2PbQq00c, 1, m, &cDelay_2PbQq00c_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fAXF1za8_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_2PbQq00c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2PbQq00c, m);
  cIf_onMessage(_c, &Context(_c)->cIf_R4cSQNDS, 0, m, &cIf_R4cSQNDS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3uUv1nwQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_2PbQq00c, 0, m, &cDelay_2PbQq00c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fAXF1za8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2PbQq00c, 0, m, &cDelay_2PbQq00c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_B5mC9C7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MLDiKP20_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qxCYBnMi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ERlA5D84_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_acwyY6qY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VchVkmnM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VchVkmnM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_IiOWEuvN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_acwyY6qY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R4cSQNDS, 1, m, &cIf_R4cSQNDS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qxCYBnMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ESFoZhUc, 0, m, &cIf_ESFoZhUc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MLDiKP20_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ESFoZhUc, 1, m, &cIf_ESFoZhUc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_G50rSon9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Y0q5Nles, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yaJ8pFPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Y0q5Nles, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_YMiwPZHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8zCCLJbB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_MjmUwVdr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Ey6awboF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_LQSoPgIg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ZVwT1v1h_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ZVwT1v1h_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_CLylOAop, 1, m, &cDelay_CLylOAop_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0g2M9bdK_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_CLylOAop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CLylOAop, m);
  cIf_onMessage(_c, &Context(_c)->cIf_YMiwPZHj, 0, m, &cIf_YMiwPZHj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZVwT1v1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_CLylOAop, 0, m, &cDelay_CLylOAop_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0g2M9bdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CLylOAop, 0, m, &cDelay_CLylOAop_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oyjINkZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pxvS5zj6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PqvsDJ9t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_247iXJpx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZvmKVjV1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xfQWm34n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xfQWm34n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_LQSoPgIg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ZvmKVjV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YMiwPZHj, 1, m, &cIf_YMiwPZHj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pxvS5zj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MjmUwVdr, 1, m, &cIf_MjmUwVdr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PqvsDJ9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MjmUwVdr, 0, m, &cIf_MjmUwVdr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ey6awboF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jDRStYAR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_8zCCLJbB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jDRStYAR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_A39vMlI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TJdqJHoh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ngRdW3C3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_pZQjrimB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_85nnYk5o_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Nq8dnecY_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Nq8dnecY_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_TaqPYbBs, 1, m, &cDelay_TaqPYbBs_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xndoV7TB_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_TaqPYbBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TaqPYbBs, m);
  cIf_onMessage(_c, &Context(_c)->cIf_A39vMlI0, 0, m, &cIf_A39vMlI0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Nq8dnecY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_TaqPYbBs, 0, m, &cDelay_TaqPYbBs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xndoV7TB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TaqPYbBs, 0, m, &cDelay_TaqPYbBs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JPyUb5H3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oeA8wKWg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zi9OyI1W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0rAgiBRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hjz73yNt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U0rSKmMv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hjz73yNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A39vMlI0, 1, m, &cIf_A39vMlI0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_U0rSKmMv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_85nnYk5o_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_oeA8wKWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ngRdW3C3, 1, m, &cIf_ngRdW3C3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zi9OyI1W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ngRdW3C3, 0, m, &cIf_ngRdW3C3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pZQjrimB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LlIvTlov, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_TJdqJHoh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LlIvTlov, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_3am4IXEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_r9kdvLwS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_phzjNipb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6KPaWh7p_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_SVJXVBwI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_NEJNXhcC_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_NEJNXhcC_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_0CE39y4F, 1, m, &cDelay_0CE39y4F_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_POSeHoC7_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_0CE39y4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0CE39y4F, m);
  cIf_onMessage(_c, &Context(_c)->cIf_3am4IXEN, 0, m, &cIf_3am4IXEN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NEJNXhcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0CE39y4F, 0, m, &cDelay_0CE39y4F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_POSeHoC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0CE39y4F, 0, m, &cDelay_0CE39y4F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jWouCS7V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gJQOl8XP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JneaIS5N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vWDCKUwQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ALhYpD7t_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IIQb8ABm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ALhYpD7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3am4IXEN, 1, m, &cIf_3am4IXEN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IIQb8ABm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_SVJXVBwI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_gJQOl8XP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_phzjNipb, 1, m, &cIf_phzjNipb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JneaIS5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_phzjNipb, 0, m, &cIf_phzjNipb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6KPaWh7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_r8lpIm0g, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_r9kdvLwS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_r8lpIm0g, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_U4MwSPs8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_PkikZNok_sendMessage(_c, 0, m);
  cMsg_3aJdpUz2_sendMessage(_c, 0, m);
  cMsg_HTZcNGlq_sendMessage(_c, 0, m);
  cMsg_J0ia0XOJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pjgqn0FU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_PkikZNok_sendMessage(_c, 0, m);
  cMsg_8dK77lm4_sendMessage(_c, 0, m);
  cMsg_L55yK1Ds_sendMessage(_c, 0, m);
  cMsg_WfgwGKnQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dEZyQOLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_kfMJz6o9_sendMessage(_c, 0, m);
  cMsg_8dK77lm4_sendMessage(_c, 0, m);
  cMsg_J0ia0XOJ_sendMessage(_c, 0, m);
  cMsg_3oKUlx2r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_YZCw2id2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_kfMJz6o9_sendMessage(_c, 0, m);
  cMsg_NSNk1RWo_sendMessage(_c, 0, m);
  cMsg_HTZcNGlq_sendMessage(_c, 0, m);
  cMsg_Sk9HjHGy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nfaIDHrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_mPKiS57B_sendMessage(_c, 0, m);
  cMsg_WfgwGKnQ_sendMessage(_c, 0, m);
  cMsg_5HKIeSbx_sendMessage(_c, 0, m);
  cMsg_HTZcNGlq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_n6usL4TI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_mPKiS57B_sendMessage(_c, 0, m);
  cMsg_Sk9HjHGy_sendMessage(_c, 0, m);
  cMsg_8dK77lm4_sendMessage(_c, 0, m);
  cMsg_W85Y3de5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_08DmDHpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_W2OaIM1Q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dyhLEQW3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vMKqTRk7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_W2OaIM1Q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dyhLEQW3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_67OfYZMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ieBTBeov_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NJTubd90_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0oXAtBPA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ieBTBeov_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NJTubd90_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nQhwNS3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dkRv4uu5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_km4bZMZL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_89t2XSSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dkRv4uu5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_km4bZMZL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PkikZNok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_08DmDHpC_sendMessage(_c, 0, m);
  cMsg_0oXAtBPA_sendMessage(_c, 0, m);
  cMsg_89t2XSSW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kfMJz6o9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_vMKqTRk7_sendMessage(_c, 0, m);
  cMsg_67OfYZMy_sendMessage(_c, 0, m);
  cMsg_89t2XSSW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mPKiS57B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_vMKqTRk7_sendMessage(_c, 0, m);
  cMsg_0oXAtBPA_sendMessage(_c, 0, m);
  cMsg_nQhwNS3V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nSbIKIsw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_89HRqSBc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Oz7DNqGO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ove7Mkgx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_89HRqSBc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Oz7DNqGO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CC6hUMmE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zsOmqENk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wDNoo761_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ob6Ir6tT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zsOmqENk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wDNoo761_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YGl9cKOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kjnGLcaJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2YVDHldh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PjmuRBpz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kjnGLcaJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2YVDHldh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8dK77lm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_ove7Mkgx_sendMessage(_c, 0, m);
  cMsg_ob6Ir6tT_sendMessage(_c, 0, m);
  cMsg_PjmuRBpz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3aJdpUz2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_ove7Mkgx_sendMessage(_c, 0, m);
  cMsg_CC6hUMmE_sendMessage(_c, 0, m);
  cMsg_YGl9cKOm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_NSNk1RWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_nSbIKIsw_sendMessage(_c, 0, m);
  cMsg_ob6Ir6tT_sendMessage(_c, 0, m);
  cMsg_YGl9cKOm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_G8WTj35B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_247iXJpx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oyjINkZj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4lNo6DmT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_247iXJpx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oyjINkZj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IHkX2ngC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0rAgiBRk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JPyUb5H3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bs7dQVsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0rAgiBRk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JPyUb5H3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AYVeofc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vWDCKUwQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jWouCS7V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PvIMPj6v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vWDCKUwQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jWouCS7V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Sk9HjHGy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_G8WTj35B_sendMessage(_c, 0, m);
  cMsg_bs7dQVsD_sendMessage(_c, 0, m);
  cMsg_PvIMPj6v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_WfgwGKnQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_4lNo6DmT_sendMessage(_c, 0, m);
  cMsg_IHkX2ngC_sendMessage(_c, 0, m);
  cMsg_PvIMPj6v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_J0ia0XOJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_4lNo6DmT_sendMessage(_c, 0, m);
  cMsg_bs7dQVsD_sendMessage(_c, 0, m);
  cMsg_AYVeofc5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UXB5SafL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_irUjPYem_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Lvo88vCe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_b7O9Xaci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_irUjPYem_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Lvo88vCe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kKy43nKz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_WrKwOnXR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xPt6Da0Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nlvEPJ6y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_WrKwOnXR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xPt6Da0Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_clgSmu3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ERlA5D84_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_B5mC9C7h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uhSd3qaP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ERlA5D84_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_B5mC9C7h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HTZcNGlq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_b7O9Xaci_sendMessage(_c, 0, m);
  cMsg_nlvEPJ6y_sendMessage(_c, 0, m);
  cMsg_uhSd3qaP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_L55yK1Ds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_b7O9Xaci_sendMessage(_c, 0, m);
  cMsg_kKy43nKz_sendMessage(_c, 0, m);
  cMsg_clgSmu3V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_W85Y3de5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_UXB5SafL_sendMessage(_c, 0, m);
  cMsg_kKy43nKz_sendMessage(_c, 0, m);
  cMsg_uhSd3qaP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5HKIeSbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_nSbIKIsw_sendMessage(_c, 0, m);
  cMsg_CC6hUMmE_sendMessage(_c, 0, m);
  cMsg_PjmuRBpz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3oKUlx2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_UXB5SafL_sendMessage(_c, 0, m);
  cMsg_nlvEPJ6y_sendMessage(_c, 0, m);
  cMsg_clgSmu3V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_R78HaHSf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZeBSoNyH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_5KFIBKDH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0ib3P2S5, 0, m, &cSlice_0ib3P2S5_sendMessage);
      break;
    }
    default: {
      cSwitchcase_p2ojYrY6_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_0ib3P2S5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_dZM2cls6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_dZM2cls6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_b1hWPlHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dZM2cls6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_dZM2cls6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bevtRcdk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_qr1uHgyW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_VDyGpzT7, 0, m, &cSlice_VDyGpzT7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_uBSv8kTx_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_VDyGpzT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_BOfXCwmI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_BOfXCwmI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_B4txDtRf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BOfXCwmI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_BOfXCwmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Cq3rGCJX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_uBSv8kTx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9YeTjLqg, 0, m, &cSlice_9YeTjLqg_sendMessage);
      break;
    }
    default: {
      cSwitchcase_5KFIBKDH_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_9YeTjLqg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0vOPeeno_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0vOPeeno_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ut6ezehq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0vOPeeno_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_0vOPeeno_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0j5uDFQn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_p2ojYrY6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_EqBytbRd, 0, m, &cSlice_EqBytbRd_sendMessage);
      break;
    }
    default: {
      cSwitchcase_QTxlHany_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_EqBytbRd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_QrclZOFf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_QrclZOFf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_GhguSBPK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QrclZOFf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_QrclZOFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GpMgF3hL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_QTxlHany_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_JTNm3ZAV, 0, m, &cSlice_JTNm3ZAV_sendMessage);
      break;
    }
    default: {
      cSwitchcase_980u2V5A_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_JTNm3ZAV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ulViFlZy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ulViFlZy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Xw1NMszm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ulViFlZy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ulViFlZy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_d60GcozU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_40mf5YcV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9bJk5B9t_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9bJk5B9t_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_N4U0ZPhG, 1, m, &cDelay_N4U0ZPhG_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PK7Nb2z1_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_N4U0ZPhG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_N4U0ZPhG, m);
  cMsg_ENb25koC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9bJk5B9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_N4U0ZPhG, 0, m, &cDelay_N4U0ZPhG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PK7Nb2z1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_N4U0ZPhG, 0, m, &cDelay_N4U0ZPhG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_Iwitw4c6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Al7jTUHJ, HV_BINOP_SUBTRACT, 0, m, &cBinop_Al7jTUHJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_tD2d1ONE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yvX5lQuc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_wWhLJcVl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yvX5lQuc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_RzaS4zhU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Iwitw4c6, 0, m, &cVar_Iwitw4c6_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_dqvPljUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_karo6xPE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Wq2M2cwQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KFSWH4Vh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Al7jTUHJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EFVk4UfF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EFVk4UfF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Ezb3UySv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ezb3UySv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_RaAurFrQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CYSinyqG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MnnNosb8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h0fYRMRL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MnnNosb8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tD2d1ONE, 1, m, &cIf_tD2d1ONE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_h0fYRMRL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CGrb831B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_NPyVOOlZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wWhLJcVl, 1, m, &cIf_wWhLJcVl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CGrb831B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_tD2d1ONE, 0, m, &cIf_tD2d1ONE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RaAurFrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wWhLJcVl, 0, m, &cIf_wWhLJcVl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_karo6xPE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_Wq2M2cwQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Al7jTUHJ, HV_BINOP_SUBTRACT, 1, m, &cBinop_Al7jTUHJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KFSWH4Vh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Iwitw4c6, 0, m, &cVar_Iwitw4c6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yvX5lQuc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ohrFgE5d, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_980u2V5A_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8gADe7M8, 0, m, &cSlice_8gADe7M8_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_8gADe7M8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ZXaAzOvZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ZXaAzOvZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_mZ0IUyaN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZXaAzOvZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ZXaAzOvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DOGCPpbl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EFlWLLY0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cgDhbUkZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_OCiKbbnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JJiGPZGw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_6YhbVF1S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KEKw9CBO, 0, m, &cVar_KEKw9CBO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZeBSoNyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vKrXbYc9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_VzvgExqj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_40mf5YcV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_NTVaUmPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_05Yfganm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ENb25koC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Bi8R9FFN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_05Yfganm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Bi8R9FFN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_f5OJ2gZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_gxhvxOaz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gxhvxOaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MAdfLQ05_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MAdfLQ05_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7BNmHqdj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_Buxx3Lq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_je6aOhHC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_4vYs3sgm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qlaG7msk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_37qgh3tE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wZ1omQXU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_1b1izjbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QL1jVx2h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_CXrLt3K3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_t3h2a8qZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_S1bDL9D9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9VrNNlvU_sendMessage);
  cMsg_O1MmdxWb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_9VrNNlvU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_S1bDL9D9, 1, m, &cVar_S1bDL9D9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wjDebRB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eLr0Enyh_sendMessage(_c, 0, m);
  cMsg_EIOMYN34_sendMessage(_c, 0, m);
  cMsg_655g45ml_sendMessage(_c, 0, m);
  cMsg_uqfmD2RZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_D8MfxHHf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LaAbXmTR, 0, m, &cSlice_LaAbXmTR_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_LaAbXmTR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_oIiuQhUP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_oIiuQhUP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_uZfWnhLL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oIiuQhUP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_oIiuQhUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ASarWlO4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_xnA1oeSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_xmbsY8AO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xmbsY8AO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_TGIJrgpz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TGIJrgpz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_6hR4AJnt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6hR4AJnt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ht5Djg6q_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cWSSz4F6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cWSSz4F6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8jhobcPP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Ht5Djg6q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_S6nIHJyM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_S6nIHJyM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_KtCHnnJq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8jhobcPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_TJpNPNIC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TJpNPNIC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_apZhB8pm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KtCHnnJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XscDnOfO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_apZhB8pm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vICxZnHz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_XscDnOfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EpIjTFRv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vICxZnHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_f5jL3IbU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_9vASn72u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bU1WKwT1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_nUjXsKkO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f1Pqpx3a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_j4S75I40_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_89JLQy3C_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R10s2SLM_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yU1xjtdp_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JDNHgQ3q_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BMMZVL1P_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kanG39hv_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_89JLQy3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d2edz0Ey_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_R10s2SLM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7rMyCm3k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_yU1xjtdp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lH4Wu6FP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_JDNHgQ3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_haCtDvOf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_BMMZVL1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W2WJWCsd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_kanG39hv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P5cPahqH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_uLOR7JH5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1qGNoZ2Y_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_VAxW3z8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_efpyqlkY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_f5UAD94U_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_foSfHQQJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_foSfHQQJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_aETcbFV0, 1, m, &cDelay_aETcbFV0_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HYRANzUC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_aETcbFV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_aETcbFV0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_uLOR7JH5, 0, m, &cIf_uLOR7JH5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_foSfHQQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_aETcbFV0, 0, m, &cDelay_aETcbFV0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HYRANzUC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_aETcbFV0, 0, m, &cDelay_aETcbFV0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VfgNjE7X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0FUi7nZI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sBxpo5gJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Iyo8SBMY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JVGltm6b_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UKNWUGwx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JVGltm6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uLOR7JH5, 1, m, &cIf_uLOR7JH5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UKNWUGwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_f5UAD94U_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_0FUi7nZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VAxW3z8K, 1, m, &cIf_VAxW3z8K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sBxpo5gJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VAxW3z8K, 0, m, &cIf_VAxW3z8K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_efpyqlkY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_B4NZkZei, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1qGNoZ2Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_B4NZkZei, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Jzb3mSdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3JO6fnsX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_b5g0WaIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_M1SHS8K5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_TowxMHjY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_vgpirWMv_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_vgpirWMv_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_RIPQu1wH, 1, m, &cDelay_RIPQu1wH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fTNBdvXo_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_RIPQu1wH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RIPQu1wH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Jzb3mSdc, 0, m, &cIf_Jzb3mSdc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vgpirWMv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_RIPQu1wH, 0, m, &cDelay_RIPQu1wH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fTNBdvXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RIPQu1wH, 0, m, &cDelay_RIPQu1wH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CEybO2Us_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lN9O2322_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uXx2EH3u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tbT8qSEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_59ffZytn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VTTUMJxF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VTTUMJxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_TowxMHjY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_59ffZytn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Jzb3mSdc, 1, m, &cIf_Jzb3mSdc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uXx2EH3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_b5g0WaIn, 0, m, &cIf_b5g0WaIn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lN9O2322_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_b5g0WaIn, 1, m, &cIf_b5g0WaIn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_M1SHS8K5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_F60gITTo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3JO6fnsX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_F60gITTo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_GA8Kev4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3MaLXAKm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_AmhEHZRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wb7bwnKY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_1WA1AYi7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_YEPKmMlx_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_YEPKmMlx_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_nKMB1Rq0, 1, m, &cDelay_nKMB1Rq0_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5OpqeRSy_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_nKMB1Rq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nKMB1Rq0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_GA8Kev4m, 0, m, &cIf_GA8Kev4m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YEPKmMlx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_nKMB1Rq0, 0, m, &cDelay_nKMB1Rq0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5OpqeRSy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nKMB1Rq0, 0, m, &cDelay_nKMB1Rq0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4aqlUoGH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_thEHUL9E_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RD73aIFj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rPEXO2mN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dH842zOK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_itny7EPM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_itny7EPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_1WA1AYi7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_dH842zOK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GA8Kev4m, 1, m, &cIf_GA8Kev4m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RD73aIFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AmhEHZRx, 0, m, &cIf_AmhEHZRx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_thEHUL9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AmhEHZRx, 1, m, &cIf_AmhEHZRx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wb7bwnKY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8qCq5oOW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3MaLXAKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8qCq5oOW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_NTyhOK8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wWmoexZX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_WBRJcZxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OLDxqqlm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_oTyFmmdT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_jh0l9lKk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_jh0l9lKk_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_zPQmqDr3, 1, m, &cDelay_zPQmqDr3_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8ATzW5ls_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_zPQmqDr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zPQmqDr3, m);
  cIf_onMessage(_c, &Context(_c)->cIf_NTyhOK8c, 0, m, &cIf_NTyhOK8c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jh0l9lKk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zPQmqDr3, 0, m, &cDelay_zPQmqDr3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8ATzW5ls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zPQmqDr3, 0, m, &cDelay_zPQmqDr3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XRzKWP5H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u6bMzQgF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4g7GaC9w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Mg8ekZNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MRIPXZ1Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1xRGYEy7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1xRGYEy7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_oTyFmmdT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_MRIPXZ1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NTyhOK8c, 1, m, &cIf_NTyhOK8c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_u6bMzQgF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WBRJcZxL, 1, m, &cIf_WBRJcZxL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4g7GaC9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WBRJcZxL, 0, m, &cIf_WBRJcZxL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OLDxqqlm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kJfc9N4s, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wWmoexZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kJfc9N4s, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_FarrdO0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YkmpOfBI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_sZ6MERKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_icWjR4Dg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ZLurIDpE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Mpu5Ha31_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Mpu5Ha31_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_URDwlpRP, 1, m, &cDelay_URDwlpRP_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2t39cedf_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_URDwlpRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_URDwlpRP, m);
  cIf_onMessage(_c, &Context(_c)->cIf_FarrdO0K, 0, m, &cIf_FarrdO0K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Mpu5Ha31_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_URDwlpRP, 0, m, &cDelay_URDwlpRP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2t39cedf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_URDwlpRP, 0, m, &cDelay_URDwlpRP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0KqW0p6E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vtYksyAn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YINAqmx0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GnFDM4sV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_j2j3Vyaa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jkRokkp0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jkRokkp0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ZLurIDpE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_j2j3Vyaa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FarrdO0K, 1, m, &cIf_FarrdO0K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vtYksyAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sZ6MERKj, 1, m, &cIf_sZ6MERKj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YINAqmx0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sZ6MERKj, 0, m, &cIf_sZ6MERKj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_icWjR4Dg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BGvyY5H4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YkmpOfBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BGvyY5H4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_uuLJ4Ot6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kuvh4jd1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_aQRtz3ol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1u19mOdW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_cWOioFiu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_kdUperzZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_kdUperzZ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_dlUOfOjQ, 1, m, &cDelay_dlUOfOjQ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V5jqrrEH_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_dlUOfOjQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dlUOfOjQ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_uuLJ4Ot6, 0, m, &cIf_uuLJ4Ot6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kdUperzZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_dlUOfOjQ, 0, m, &cDelay_dlUOfOjQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_V5jqrrEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dlUOfOjQ, 0, m, &cDelay_dlUOfOjQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kt5a88vF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7Q8gYa23_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4pCI7ccX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LyjVx77T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dKWtagpB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h4k21gRY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_h4k21gRY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_cWOioFiu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_dKWtagpB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uuLJ4Ot6, 1, m, &cIf_uuLJ4Ot6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4pCI7ccX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aQRtz3ol, 0, m, &cIf_aQRtz3ol_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7Q8gYa23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aQRtz3ol, 1, m, &cIf_aQRtz3ol_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1u19mOdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hTFqpdxE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_kuvh4jd1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hTFqpdxE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_NmGg5SqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4gLN6SMk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_zrX09xtk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EKsvpx0h_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fVY90m30_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_6LrSUmmT_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_6LrSUmmT_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_uSGXFwFL, 1, m, &cDelay_uSGXFwFL_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bVZym1Ii_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_uSGXFwFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uSGXFwFL, m);
  cIf_onMessage(_c, &Context(_c)->cIf_NmGg5SqQ, 0, m, &cIf_NmGg5SqQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6LrSUmmT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_uSGXFwFL, 0, m, &cDelay_uSGXFwFL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bVZym1Ii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uSGXFwFL, 0, m, &cDelay_uSGXFwFL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1RGVuqlO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sUEiCB1S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N1wUAhCE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QEXHlKFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lCn0ryYK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KUmN4wbg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lCn0ryYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NmGg5SqQ, 1, m, &cIf_NmGg5SqQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KUmN4wbg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_fVY90m30_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_sUEiCB1S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zrX09xtk, 1, m, &cIf_zrX09xtk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_N1wUAhCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zrX09xtk, 0, m, &cIf_zrX09xtk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EKsvpx0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RN25Zkbz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4gLN6SMk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RN25Zkbz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_pYjKy4UF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lnw4UeYi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_NbFsNfZy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QU7xsNvR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_F2wfORYW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Hdot95we_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Hdot95we_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_cA4iE3tb, 1, m, &cDelay_cA4iE3tb_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AlB3afRy_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_cA4iE3tb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cA4iE3tb, m);
  cIf_onMessage(_c, &Context(_c)->cIf_pYjKy4UF, 0, m, &cIf_pYjKy4UF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Hdot95we_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_cA4iE3tb, 0, m, &cDelay_cA4iE3tb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AlB3afRy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cA4iE3tb, 0, m, &cDelay_cA4iE3tb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oTQQBwlb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sZqBN68Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YXeJKnt5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_U4QTTSFv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_baUCzRy4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IXikHxVr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IXikHxVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_F2wfORYW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_baUCzRy4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pYjKy4UF, 1, m, &cIf_pYjKy4UF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sZqBN68Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NbFsNfZy, 1, m, &cIf_NbFsNfZy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YXeJKnt5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NbFsNfZy, 0, m, &cIf_NbFsNfZy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QU7xsNvR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2WIlVDv2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_lnw4UeYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2WIlVDv2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_WdDy2Llk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jmfAXkI4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_CFZ0VJ6Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2hQhE1Sq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_bX5xfH1s_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_h3wa0U1j_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_h3wa0U1j_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_WygRAwzw, 1, m, &cDelay_WygRAwzw_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TxyOvuF1_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_WygRAwzw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WygRAwzw, m);
  cIf_onMessage(_c, &Context(_c)->cIf_WdDy2Llk, 0, m, &cIf_WdDy2Llk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_h3wa0U1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_WygRAwzw, 0, m, &cDelay_WygRAwzw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TxyOvuF1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WygRAwzw, 0, m, &cDelay_WygRAwzw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CyVdXbac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E8gmtnY6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UOScP8yR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_77EHWCsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_G5GEoN8K_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uSG8gLAg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_G5GEoN8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WdDy2Llk, 1, m, &cIf_WdDy2Llk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uSG8gLAg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_bX5xfH1s_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_UOScP8yR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CFZ0VJ6Y, 0, m, &cIf_CFZ0VJ6Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_E8gmtnY6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CFZ0VJ6Y, 1, m, &cIf_CFZ0VJ6Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2hQhE1Sq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_q8eu8BwN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jmfAXkI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_q8eu8BwN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_LoIcR1nh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hvpwjNhE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_0VUPH01T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lT8KmhuK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_So2awQpa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0mUV3LOg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0mUV3LOg_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5WBvOaZd, 1, m, &cDelay_5WBvOaZd_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_laibX7BV_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_5WBvOaZd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5WBvOaZd, m);
  cIf_onMessage(_c, &Context(_c)->cIf_LoIcR1nh, 0, m, &cIf_LoIcR1nh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0mUV3LOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5WBvOaZd, 0, m, &cDelay_5WBvOaZd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_laibX7BV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5WBvOaZd, 0, m, &cDelay_5WBvOaZd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CAaeVUmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UpT7bTZf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rsxTp3GZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XOlXPG25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AeipkBvY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mnbRRfQH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mnbRRfQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_So2awQpa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_AeipkBvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LoIcR1nh, 1, m, &cIf_LoIcR1nh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UpT7bTZf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0VUPH01T, 1, m, &cIf_0VUPH01T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rsxTp3GZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0VUPH01T, 0, m, &cIf_0VUPH01T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lT8KmhuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xy9GuJlN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hvpwjNhE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xy9GuJlN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_YMbzYu9N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KIqYXSqW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_aO73SMV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JJw7OAqx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_mKomeWEb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_7TWeMfgU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_7TWeMfgU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_dUhEH7bi, 1, m, &cDelay_dUhEH7bi_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R73hUrdp_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_dUhEH7bi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dUhEH7bi, m);
  cIf_onMessage(_c, &Context(_c)->cIf_YMbzYu9N, 0, m, &cIf_YMbzYu9N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7TWeMfgU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_dUhEH7bi, 0, m, &cDelay_dUhEH7bi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_R73hUrdp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dUhEH7bi, 0, m, &cDelay_dUhEH7bi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NSzvcMDN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zO2r7ZEP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Bbgg5fFg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2K4jiKUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WNJgeiAQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2sIG7bH5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2sIG7bH5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_mKomeWEb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_WNJgeiAQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YMbzYu9N, 1, m, &cIf_YMbzYu9N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Bbgg5fFg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aO73SMV6, 0, m, &cIf_aO73SMV6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zO2r7ZEP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aO73SMV6, 1, m, &cIf_aO73SMV6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JJw7OAqx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lCQXAjsh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_KIqYXSqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lCQXAjsh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_CpP3vXXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1aZBeFI4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ZW16yINf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_f7rVAp6l_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6CE97vxo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_qQpdGK6O_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_qQpdGK6O_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_MuAPdhBd, 1, m, &cDelay_MuAPdhBd_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yLanMBUe_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_MuAPdhBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MuAPdhBd, m);
  cIf_onMessage(_c, &Context(_c)->cIf_CpP3vXXP, 0, m, &cIf_CpP3vXXP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qQpdGK6O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MuAPdhBd, 0, m, &cDelay_MuAPdhBd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yLanMBUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MuAPdhBd, 0, m, &cDelay_MuAPdhBd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2M0lq85h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZGByNjz1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9oMDweDi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1cS2SzLD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6Ko0XP4J_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5ubnyhR6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5ubnyhR6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6CE97vxo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_6Ko0XP4J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CpP3vXXP, 1, m, &cIf_CpP3vXXP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZGByNjz1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZW16yINf, 1, m, &cIf_ZW16yINf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9oMDweDi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZW16yINf, 0, m, &cIf_ZW16yINf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_f7rVAp6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uB1UgHEo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1aZBeFI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uB1UgHEo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_d2edz0Ey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_ft7gjqY3_sendMessage(_c, 0, m);
  cMsg_c2LvOx5P_sendMessage(_c, 0, m);
  cMsg_Eto5dfJY_sendMessage(_c, 0, m);
  cMsg_BJYnC2I0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7rMyCm3k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_ft7gjqY3_sendMessage(_c, 0, m);
  cMsg_JMAs7ksB_sendMessage(_c, 0, m);
  cMsg_7wcsSD3e_sendMessage(_c, 0, m);
  cMsg_UBxH9CqA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lH4Wu6FP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_JmjzsJYA_sendMessage(_c, 0, m);
  cMsg_JMAs7ksB_sendMessage(_c, 0, m);
  cMsg_BJYnC2I0_sendMessage(_c, 0, m);
  cMsg_2oPPBBNs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_haCtDvOf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_JmjzsJYA_sendMessage(_c, 0, m);
  cMsg_pFd2bUH5_sendMessage(_c, 0, m);
  cMsg_Eto5dfJY_sendMessage(_c, 0, m);
  cMsg_WSE1mM2c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_W2WJWCsd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_dumMb5X8_sendMessage(_c, 0, m);
  cMsg_UBxH9CqA_sendMessage(_c, 0, m);
  cMsg_MYvg2K0E_sendMessage(_c, 0, m);
  cMsg_Eto5dfJY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_P5cPahqH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_dumMb5X8_sendMessage(_c, 0, m);
  cMsg_WSE1mM2c_sendMessage(_c, 0, m);
  cMsg_JMAs7ksB_sendMessage(_c, 0, m);
  cMsg_QpAyDRcN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SoYfzIEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Iyo8SBMY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VfgNjE7X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_s98v1QvM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Iyo8SBMY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VfgNjE7X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Xr6BBpuv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tbT8qSEt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CEybO2Us_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VB23AQht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tbT8qSEt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CEybO2Us_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_l8Pl4loX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rPEXO2mN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4aqlUoGH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZvljkaBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rPEXO2mN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4aqlUoGH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ft7gjqY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_SoYfzIEu_sendMessage(_c, 0, m);
  cMsg_VB23AQht_sendMessage(_c, 0, m);
  cMsg_ZvljkaBl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JmjzsJYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_s98v1QvM_sendMessage(_c, 0, m);
  cMsg_Xr6BBpuv_sendMessage(_c, 0, m);
  cMsg_ZvljkaBl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dumMb5X8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_s98v1QvM_sendMessage(_c, 0, m);
  cMsg_VB23AQht_sendMessage(_c, 0, m);
  cMsg_l8Pl4loX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pRFG9dun_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Mg8ekZNq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XRzKWP5H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oeD2pKid_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Mg8ekZNq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XRzKWP5H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0ltemp4r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GnFDM4sV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0KqW0p6E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LiPmliaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GnFDM4sV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0KqW0p6E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_U1hgaoQA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LyjVx77T_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kt5a88vF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7coEn159_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LyjVx77T_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kt5a88vF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JMAs7ksB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_oeD2pKid_sendMessage(_c, 0, m);
  cMsg_LiPmliaE_sendMessage(_c, 0, m);
  cMsg_7coEn159_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_c2LvOx5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_oeD2pKid_sendMessage(_c, 0, m);
  cMsg_0ltemp4r_sendMessage(_c, 0, m);
  cMsg_U1hgaoQA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pFd2bUH5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_pRFG9dun_sendMessage(_c, 0, m);
  cMsg_LiPmliaE_sendMessage(_c, 0, m);
  cMsg_U1hgaoQA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ecBNnFEq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XOlXPG25_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CAaeVUmK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_a8JlfJPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XOlXPG25_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CAaeVUmK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_h661b9zy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2K4jiKUW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NSzvcMDN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3vQ1bcnX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2K4jiKUW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NSzvcMDN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hXWnFSpA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1cS2SzLD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2M0lq85h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xJiSESdJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1cS2SzLD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2M0lq85h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WSE1mM2c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_ecBNnFEq_sendMessage(_c, 0, m);
  cMsg_3vQ1bcnX_sendMessage(_c, 0, m);
  cMsg_xJiSESdJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UBxH9CqA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_a8JlfJPr_sendMessage(_c, 0, m);
  cMsg_h661b9zy_sendMessage(_c, 0, m);
  cMsg_xJiSESdJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_BJYnC2I0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_a8JlfJPr_sendMessage(_c, 0, m);
  cMsg_3vQ1bcnX_sendMessage(_c, 0, m);
  cMsg_hXWnFSpA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fYQ7RQVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QEXHlKFY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1RGVuqlO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NUrcLHzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QEXHlKFY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1RGVuqlO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RB9mrKuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_U4QTTSFv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oTQQBwlb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_00mviCMN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_U4QTTSFv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oTQQBwlb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hDTw7BYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_77EHWCsH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CyVdXbac_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_H9VjEPW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_77EHWCsH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CyVdXbac_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Eto5dfJY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_NUrcLHzO_sendMessage(_c, 0, m);
  cMsg_00mviCMN_sendMessage(_c, 0, m);
  cMsg_H9VjEPW9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7wcsSD3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_NUrcLHzO_sendMessage(_c, 0, m);
  cMsg_RB9mrKuo_sendMessage(_c, 0, m);
  cMsg_hDTw7BYa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QpAyDRcN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_fYQ7RQVY_sendMessage(_c, 0, m);
  cMsg_RB9mrKuo_sendMessage(_c, 0, m);
  cMsg_H9VjEPW9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MYvg2K0E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_pRFG9dun_sendMessage(_c, 0, m);
  cMsg_0ltemp4r_sendMessage(_c, 0, m);
  cMsg_7coEn159_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2oPPBBNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_fYQ7RQVY_sendMessage(_c, 0, m);
  cMsg_00mviCMN_sendMessage(_c, 0, m);
  cMsg_hDTw7BYa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_M6z8ZRie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WEe4Xk4b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Hqu06O2H_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gN94HEUw, 0, m, &cSlice_gN94HEUw_sendMessage);
      break;
    }
    default: {
      cSwitchcase_XQ8npqVE_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_gN94HEUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ukKpHBwt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ukKpHBwt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_QdjnaHYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ukKpHBwt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ukKpHBwt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1hOQenee_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_plvIfVL8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_kNhp8V0P, 0, m, &cSlice_kNhp8V0P_sendMessage);
      break;
    }
    default: {
      cSwitchcase_urvqFdT5_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_kNhp8V0P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NIHvIDPN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NIHvIDPN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_89Extq2M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NIHvIDPN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_NIHvIDPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FHqYuD0c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_urvqFdT5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_auBwzb5w, 0, m, &cSlice_auBwzb5w_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Hqu06O2H_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_auBwzb5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_q6VExzQj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_q6VExzQj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_sK2BnpgX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_q6VExzQj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_q6VExzQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sXCogLd5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_XQ8npqVE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7zv0UItU, 0, m, &cSlice_7zv0UItU_sendMessage);
      break;
    }
    default: {
      cSwitchcase_PnW0nuSO_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_7zv0UItU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_tPTIOKzT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_tPTIOKzT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_k7lxzujy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tPTIOKzT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_tPTIOKzT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8zJOMTzW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PnW0nuSO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_JgYVTdKO, 0, m, &cSlice_JgYVTdKO_sendMessage);
      break;
    }
    default: {
      cSwitchcase_PsjJkO3p_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_JgYVTdKO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_oZ8UwOul_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_oZ8UwOul_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_AqlxfQ2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oZ8UwOul_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_oZ8UwOul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cJ62b9Q2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_bbdZae50_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_vghPf9Pq_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_vghPf9Pq_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_LILGbqKl, 1, m, &cDelay_LILGbqKl_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SKcRZN60_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_LILGbqKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LILGbqKl, m);
  cMsg_1ANbwyjY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_vghPf9Pq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_LILGbqKl, 0, m, &cDelay_LILGbqKl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SKcRZN60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_LILGbqKl, 0, m, &cDelay_LILGbqKl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_UL7arkBE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wHkCxo04, HV_BINOP_SUBTRACT, 0, m, &cBinop_wHkCxo04_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_j1QpMAW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1kRz0EJn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Pg2SOCyM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1kRz0EJn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_L5B6lpDQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UL7arkBE, 0, m, &cVar_UL7arkBE_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_YIhbZgr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bPncuzqj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C1ZjjwNP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CfoRHyDB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wHkCxo04_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IzsZyuOC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_IzsZyuOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ZLUD9zSM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZLUD9zSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_1SOiBrFj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OkFZDZfw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EedxZu2V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ttXu5vtY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EedxZu2V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_j1QpMAW1, 1, m, &cIf_j1QpMAW1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ttXu5vtY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l3lAARio_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_7xU7xbIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Pg2SOCyM, 1, m, &cIf_Pg2SOCyM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_l3lAARio_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_j1QpMAW1, 0, m, &cIf_j1QpMAW1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1SOiBrFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Pg2SOCyM, 0, m, &cIf_Pg2SOCyM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CfoRHyDB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UL7arkBE, 0, m, &cVar_UL7arkBE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_C1ZjjwNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wHkCxo04, HV_BINOP_SUBTRACT, 1, m, &cBinop_wHkCxo04_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bPncuzqj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cMsg_1kRz0EJn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_y9XjP1JQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PsjJkO3p_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Qc8cgAm6, 0, m, &cSlice_Qc8cgAm6_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Qc8cgAm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_DrsFXkRo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_DrsFXkRo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_RswpCNxH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DrsFXkRo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_DrsFXkRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gUv0K9QM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_bU1WKwT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_m7WYll2C, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_f1Pqpx3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UhINNUs7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_Mz10C3vx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nUjXsKkO, 0, m, &cVar_nUjXsKkO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WEe4Xk4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_E7uvkJFq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_wyqSa4w1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_bbdZae50_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ZJj3VYNw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nlRI58kG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1ANbwyjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_v6RFhU6r, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_nlRI58kG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_v6RFhU6r, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wbHEwG91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_Zux5AR8K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Zux5AR8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wYb3zP2N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wYb3zP2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qRiFl8KR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_cVr9n9kR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H0cuv585_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_5GovrkQA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wO3uOIOu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3tyXLC1n_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h2B9Bx42_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fmVD6yLT_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_e4tPqGrg_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mbs4WB5g_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HXFWnlR8_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bwjZ6RCZ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_h2B9Bx42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qLO3xSUr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_fmVD6yLT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_49rALWkA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_e4tPqGrg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8SHlxGiT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Mbs4WB5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5k2vQKrf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_HXFWnlR8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S4eRA5xr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_bwjZ6RCZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_t4JDVPhl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_W5xYOO9F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ldCimLZe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_jzCTVTno_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_M9onFGum_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_V4OHvtWT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_4zIUafKn_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_4zIUafKn_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_IJz1GHMh, 1, m, &cDelay_IJz1GHMh_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MiS7Xz8m_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_IJz1GHMh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IJz1GHMh, m);
  cIf_onMessage(_c, &Context(_c)->cIf_W5xYOO9F, 0, m, &cIf_W5xYOO9F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4zIUafKn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_IJz1GHMh, 0, m, &cDelay_IJz1GHMh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MiS7Xz8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IJz1GHMh, 0, m, &cDelay_IJz1GHMh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FXgsjh2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ruv4gXly_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ex5WbO6c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_I8oSiqcZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lQqD2r1E_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yp1T5zmy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yp1T5zmy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_V4OHvtWT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_lQqD2r1E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_W5xYOO9F, 1, m, &cIf_W5xYOO9F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ex5WbO6c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jzCTVTno, 0, m, &cIf_jzCTVTno_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ruv4gXly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jzCTVTno, 1, m, &cIf_jzCTVTno_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_M9onFGum_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_50TJhMQ1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ldCimLZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_50TJhMQ1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_XuM76j3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YuEr6AD1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Zlc5UmWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MKYPvSxM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4fRIBdlk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0FvB8LDd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0FvB8LDd_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_EV7Gb5CS, 1, m, &cDelay_EV7Gb5CS_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_43dYyy5u_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_EV7Gb5CS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EV7Gb5CS, m);
  cIf_onMessage(_c, &Context(_c)->cIf_XuM76j3X, 0, m, &cIf_XuM76j3X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0FvB8LDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_EV7Gb5CS, 0, m, &cDelay_EV7Gb5CS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_43dYyy5u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EV7Gb5CS, 0, m, &cDelay_EV7Gb5CS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wAzCj0XD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3PJc7uh9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nygqhXHn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1vWn2E7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1PMY3lLm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E09toyuC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_E09toyuC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4fRIBdlk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_1PMY3lLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XuM76j3X, 1, m, &cIf_XuM76j3X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3PJc7uh9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Zlc5UmWr, 1, m, &cIf_Zlc5UmWr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nygqhXHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Zlc5UmWr, 0, m, &cIf_Zlc5UmWr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MKYPvSxM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mttfoG52, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YuEr6AD1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mttfoG52, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Ka8LxVMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UX3ogRdD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_dDUNlDAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YaLWJxYA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VBx43Zhj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_rgB7kCRj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_rgB7kCRj_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_427c59m0, 1, m, &cDelay_427c59m0_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bKsuIp5X_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_427c59m0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_427c59m0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Ka8LxVMw, 0, m, &cIf_Ka8LxVMw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rgB7kCRj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_427c59m0, 0, m, &cDelay_427c59m0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bKsuIp5X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_427c59m0, 0, m, &cDelay_427c59m0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EW99I1Wa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bWHDfp0j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7EFSEcDl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4vii2lCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9qlnvr95_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_macbQZfD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_macbQZfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_VBx43Zhj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_9qlnvr95_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ka8LxVMw, 1, m, &cIf_Ka8LxVMw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bWHDfp0j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dDUNlDAS, 1, m, &cIf_dDUNlDAS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7EFSEcDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dDUNlDAS, 0, m, &cIf_dDUNlDAS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YaLWJxYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ufOR8jSe, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UX3ogRdD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ufOR8jSe, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_B3yKMugJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_V6TTUJOr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_xZaq62tc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lZJfnvRb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_5yfAzisz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ZnUI6fe4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ZnUI6fe4_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_WQxKyKur, 1, m, &cDelay_WQxKyKur_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BGW06Gg4_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_WQxKyKur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WQxKyKur, m);
  cIf_onMessage(_c, &Context(_c)->cIf_B3yKMugJ, 0, m, &cIf_B3yKMugJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZnUI6fe4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_WQxKyKur, 0, m, &cDelay_WQxKyKur_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BGW06Gg4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WQxKyKur, 0, m, &cDelay_WQxKyKur_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2Djqth3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pz8tzP16_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ojt8We6D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JEcxCxlF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9nkW5BFC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tLYtnXnk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9nkW5BFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_B3yKMugJ, 1, m, &cIf_B3yKMugJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tLYtnXnk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5yfAzisz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Ojt8We6D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xZaq62tc, 0, m, &cIf_xZaq62tc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pz8tzP16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xZaq62tc, 1, m, &cIf_xZaq62tc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lZJfnvRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2VjIK8O9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_V6TTUJOr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2VjIK8O9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_npjOqs5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Zhc9Vob8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_VVq0Ga4I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ePKeeSXC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_WJDmKB4W_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_xab5NjZm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_xab5NjZm_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_G4SnwVKi, 1, m, &cDelay_G4SnwVKi_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ilOpIGCo_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_G4SnwVKi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_G4SnwVKi, m);
  cIf_onMessage(_c, &Context(_c)->cIf_npjOqs5j, 0, m, &cIf_npjOqs5j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xab5NjZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_G4SnwVKi, 0, m, &cDelay_G4SnwVKi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ilOpIGCo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_G4SnwVKi, 0, m, &cDelay_G4SnwVKi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xQRgxbWZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2FVlqgJE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hgkvGd39_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6bCnvExH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JLA9A1Il_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZKfXgwyi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZKfXgwyi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_WJDmKB4W_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_JLA9A1Il_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_npjOqs5j, 1, m, &cIf_npjOqs5j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hgkvGd39_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VVq0Ga4I, 0, m, &cIf_VVq0Ga4I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2FVlqgJE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VVq0Ga4I, 1, m, &cIf_VVq0Ga4I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ePKeeSXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Z3DQkpzP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Zhc9Vob8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Z3DQkpzP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_9qROX6bF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_71BcjsHV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_q0EHDHRG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KY2V9fdJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_7Gdno1x2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_JZ5jHTcX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_JZ5jHTcX_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Z9RCmn6d, 1, m, &cDelay_Z9RCmn6d_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w3TBg2sJ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Z9RCmn6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Z9RCmn6d, m);
  cIf_onMessage(_c, &Context(_c)->cIf_9qROX6bF, 0, m, &cIf_9qROX6bF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JZ5jHTcX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Z9RCmn6d, 0, m, &cDelay_Z9RCmn6d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_w3TBg2sJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Z9RCmn6d, 0, m, &cDelay_Z9RCmn6d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7F26YvmM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AQP4vgGk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yMWeQD7C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zNxncdv9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qnxrtdoS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EFBVcGfk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qnxrtdoS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9qROX6bF, 1, m, &cIf_9qROX6bF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EFBVcGfk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7Gdno1x2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_AQP4vgGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q0EHDHRG, 1, m, &cIf_q0EHDHRG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yMWeQD7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q0EHDHRG, 0, m, &cIf_q0EHDHRG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KY2V9fdJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_J5uyPvYh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_71BcjsHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_J5uyPvYh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_F7zcgvRn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_33tjAx4o_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_pGKDiWIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WuRurVfK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_BDjRkHzu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9u9IsYZ6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9u9IsYZ6_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_VzUUHKEv, 1, m, &cDelay_VzUUHKEv_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C3zQZxlT_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_VzUUHKEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VzUUHKEv, m);
  cIf_onMessage(_c, &Context(_c)->cIf_F7zcgvRn, 0, m, &cIf_F7zcgvRn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9u9IsYZ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_VzUUHKEv, 0, m, &cDelay_VzUUHKEv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_C3zQZxlT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VzUUHKEv, 0, m, &cDelay_VzUUHKEv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yqFcjVER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QFb8fqP9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LSOjSR3t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_t1Z23NTo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oxM4aobE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mduDiT8y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mduDiT8y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BDjRkHzu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_oxM4aobE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_F7zcgvRn, 1, m, &cIf_F7zcgvRn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QFb8fqP9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pGKDiWIQ, 1, m, &cIf_pGKDiWIQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LSOjSR3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pGKDiWIQ, 0, m, &cIf_pGKDiWIQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WuRurVfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UEIBAxyN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_33tjAx4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UEIBAxyN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_uXnQ73LY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uqiEkDxA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_tWioE624_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7BuDWmgz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_SUoXH3R7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CVEx7vSf_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CVEx7vSf_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_aTnzbX45, 1, m, &cDelay_aTnzbX45_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lO66Zt5i_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_aTnzbX45_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_aTnzbX45, m);
  cIf_onMessage(_c, &Context(_c)->cIf_uXnQ73LY, 0, m, &cIf_uXnQ73LY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CVEx7vSf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_aTnzbX45, 0, m, &cDelay_aTnzbX45_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lO66Zt5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_aTnzbX45, 0, m, &cDelay_aTnzbX45_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_V7LzkD01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q1uvmczW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YeOLfTNH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XjqRfMN6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Cv5VkD2O_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Z0qLxzz0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Cv5VkD2O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uXnQ73LY, 1, m, &cIf_uXnQ73LY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Z0qLxzz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_SUoXH3R7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_YeOLfTNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tWioE624, 0, m, &cIf_tWioE624_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Q1uvmczW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tWioE624, 1, m, &cIf_tWioE624_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7BuDWmgz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4daaTl5n, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_uqiEkDxA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4daaTl5n, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Df5c3YGR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vjJ3oXf4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_K8ICzRxe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NuiBVx3o_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_sbx75hkj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9GUOZbSW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9GUOZbSW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Wt4g4FV7, 1, m, &cDelay_Wt4g4FV7_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_e0GptC0B_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Wt4g4FV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Wt4g4FV7, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Df5c3YGR, 0, m, &cIf_Df5c3YGR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9GUOZbSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Wt4g4FV7, 0, m, &cDelay_Wt4g4FV7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_e0GptC0B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Wt4g4FV7, 0, m, &cDelay_Wt4g4FV7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eDQCi9kq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4BUNNvcv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ENE3cI08_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_A1nKkmAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_G74odMQg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y1tY8c3e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_y1tY8c3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_sbx75hkj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_G74odMQg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Df5c3YGR, 1, m, &cIf_Df5c3YGR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ENE3cI08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K8ICzRxe, 0, m, &cIf_K8ICzRxe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4BUNNvcv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K8ICzRxe, 1, m, &cIf_K8ICzRxe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NuiBVx3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0glMcTB4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vjJ3oXf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0glMcTB4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Y0U57AKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_I90hMEZJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_YGMzDLcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_A0c7YwW1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_WCDEYatS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_H81Ujwv4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_H81Ujwv4_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_W5rasrjR, 1, m, &cDelay_W5rasrjR_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_85QQLf6f_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_W5rasrjR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_W5rasrjR, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Y0U57AKq, 0, m, &cIf_Y0U57AKq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_H81Ujwv4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_W5rasrjR, 0, m, &cDelay_W5rasrjR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_85QQLf6f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_W5rasrjR, 0, m, &cDelay_W5rasrjR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iEuu7CbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TsZtrVLW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y1ZfFaFp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LA04Hvfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QDs0rIRC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Imn1fomU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Imn1fomU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_WCDEYatS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_QDs0rIRC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Y0U57AKq, 1, m, &cIf_Y0U57AKq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TsZtrVLW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YGMzDLcs, 1, m, &cIf_YGMzDLcs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_y1ZfFaFp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YGMzDLcs, 0, m, &cIf_YGMzDLcs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_A0c7YwW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mwSs0Ge4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_I90hMEZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mwSs0Ge4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Fw5wrESz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tYYj8tiX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_3yfx3hXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GLuztKIh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_X6OSKPJQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_d3W1Xjvk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_d3W1Xjvk_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_UhwqFsNn, 1, m, &cDelay_UhwqFsNn_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8BHeR0Iw_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_UhwqFsNn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UhwqFsNn, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Fw5wrESz, 0, m, &cIf_Fw5wrESz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_d3W1Xjvk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_UhwqFsNn, 0, m, &cDelay_UhwqFsNn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8BHeR0Iw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UhwqFsNn, 0, m, &cDelay_UhwqFsNn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IGYtG83S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5ky63TUB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DKcM9K6A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DjXuSXq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jjqhqx9s_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r1Z0HPVA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jjqhqx9s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Fw5wrESz, 1, m, &cIf_Fw5wrESz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_r1Z0HPVA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_X6OSKPJQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_DKcM9K6A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3yfx3hXc, 0, m, &cIf_3yfx3hXc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5ky63TUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3yfx3hXc, 1, m, &cIf_3yfx3hXc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GLuztKIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_j8U4XpLX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tYYj8tiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_j8U4XpLX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_3iUCZDUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zBFX0fux_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_zNFitrAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OFioLYZp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_xxzm7k03_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_2lRLQHxs_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_2lRLQHxs_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_W8sVtYSk, 1, m, &cDelay_W8sVtYSk_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qNKMqxyJ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_W8sVtYSk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_W8sVtYSk, m);
  cIf_onMessage(_c, &Context(_c)->cIf_3iUCZDUk, 0, m, &cIf_3iUCZDUk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2lRLQHxs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_W8sVtYSk, 0, m, &cDelay_W8sVtYSk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qNKMqxyJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_W8sVtYSk, 0, m, &cDelay_W8sVtYSk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UFbLFIFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gE6ECxgd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lIzogAje_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_w87ac7ba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_irHpAZCP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_d3AJZ7Z3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_d3AJZ7Z3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xxzm7k03_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_irHpAZCP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3iUCZDUk, 1, m, &cIf_3iUCZDUk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lIzogAje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zNFitrAC, 0, m, &cIf_zNFitrAC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gE6ECxgd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zNFitrAC, 1, m, &cIf_zNFitrAC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OFioLYZp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kR7Mcgkk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zBFX0fux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kR7Mcgkk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qLO3xSUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_ePX5hS7C_sendMessage(_c, 0, m);
  cMsg_PEcZdAih_sendMessage(_c, 0, m);
  cMsg_UDnbvJTD_sendMessage(_c, 0, m);
  cMsg_wFxotW1r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_49rALWkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_ePX5hS7C_sendMessage(_c, 0, m);
  cMsg_lJy748FM_sendMessage(_c, 0, m);
  cMsg_inV58IRT_sendMessage(_c, 0, m);
  cMsg_X8AAjO2o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8SHlxGiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_OxW1cenG_sendMessage(_c, 0, m);
  cMsg_lJy748FM_sendMessage(_c, 0, m);
  cMsg_wFxotW1r_sendMessage(_c, 0, m);
  cMsg_JZtYCRG4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5k2vQKrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_OxW1cenG_sendMessage(_c, 0, m);
  cMsg_hMB0NZdy_sendMessage(_c, 0, m);
  cMsg_UDnbvJTD_sendMessage(_c, 0, m);
  cMsg_DlMUUo1m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_S4eRA5xr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_f0z2zm7w_sendMessage(_c, 0, m);
  cMsg_X8AAjO2o_sendMessage(_c, 0, m);
  cMsg_r6EbVvST_sendMessage(_c, 0, m);
  cMsg_UDnbvJTD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_t4JDVPhl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_f0z2zm7w_sendMessage(_c, 0, m);
  cMsg_DlMUUo1m_sendMessage(_c, 0, m);
  cMsg_lJy748FM_sendMessage(_c, 0, m);
  cMsg_C3eLv6Ay_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lRGl9pnL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_I8oSiqcZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FXgsjh2E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_C51BiFEG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_I8oSiqcZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FXgsjh2E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qtgeLfbO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1vWn2E7C_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wAzCj0XD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_J0JCU7sH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1vWn2E7C_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wAzCj0XD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8uqVXb0Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4vii2lCa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EW99I1Wa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wLeUHeDK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4vii2lCa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EW99I1Wa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ePX5hS7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_lRGl9pnL_sendMessage(_c, 0, m);
  cMsg_J0JCU7sH_sendMessage(_c, 0, m);
  cMsg_wLeUHeDK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OxW1cenG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_C51BiFEG_sendMessage(_c, 0, m);
  cMsg_qtgeLfbO_sendMessage(_c, 0, m);
  cMsg_wLeUHeDK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_f0z2zm7w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_C51BiFEG_sendMessage(_c, 0, m);
  cMsg_J0JCU7sH_sendMessage(_c, 0, m);
  cMsg_8uqVXb0Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_f3IlVTm5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JEcxCxlF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2Djqth3r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_h8aF24P8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JEcxCxlF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2Djqth3r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jRjUMV1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6bCnvExH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xQRgxbWZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ljMNDnqX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6bCnvExH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xQRgxbWZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6eb4CGM3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zNxncdv9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7F26YvmM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yMScmPrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zNxncdv9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7F26YvmM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lJy748FM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_h8aF24P8_sendMessage(_c, 0, m);
  cMsg_ljMNDnqX_sendMessage(_c, 0, m);
  cMsg_yMScmPrP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PEcZdAih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_h8aF24P8_sendMessage(_c, 0, m);
  cMsg_jRjUMV1n_sendMessage(_c, 0, m);
  cMsg_6eb4CGM3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hMB0NZdy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_f3IlVTm5_sendMessage(_c, 0, m);
  cMsg_ljMNDnqX_sendMessage(_c, 0, m);
  cMsg_6eb4CGM3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2oSy8DEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LA04Hvfu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iEuu7CbI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rCTbdmrw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LA04Hvfu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iEuu7CbI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9px3aQZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DjXuSXq3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IGYtG83S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oPXltP7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DjXuSXq3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IGYtG83S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_intZkecX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_w87ac7ba_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_UFbLFIFS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fcVhWzFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_w87ac7ba_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_UFbLFIFS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DlMUUo1m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_2oSy8DEa_sendMessage(_c, 0, m);
  cMsg_oPXltP7t_sendMessage(_c, 0, m);
  cMsg_fcVhWzFQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_X8AAjO2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_rCTbdmrw_sendMessage(_c, 0, m);
  cMsg_9px3aQZw_sendMessage(_c, 0, m);
  cMsg_fcVhWzFQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wFxotW1r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_rCTbdmrw_sendMessage(_c, 0, m);
  cMsg_oPXltP7t_sendMessage(_c, 0, m);
  cMsg_intZkecX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qVdsYs8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_t1Z23NTo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yqFcjVER_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_a0yEBAey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_t1Z23NTo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yqFcjVER_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OXSU9glY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XjqRfMN6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_V7LzkD01_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CCNBK0sg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XjqRfMN6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_V7LzkD01_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_C0BW0LQ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_A1nKkmAH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eDQCi9kq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8sLQByTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_A1nKkmAH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eDQCi9kq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UDnbvJTD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_a0yEBAey_sendMessage(_c, 0, m);
  cMsg_CCNBK0sg_sendMessage(_c, 0, m);
  cMsg_8sLQByTL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_inV58IRT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_a0yEBAey_sendMessage(_c, 0, m);
  cMsg_OXSU9glY_sendMessage(_c, 0, m);
  cMsg_C0BW0LQ6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_C3eLv6Ay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_qVdsYs8G_sendMessage(_c, 0, m);
  cMsg_OXSU9glY_sendMessage(_c, 0, m);
  cMsg_8sLQByTL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_r6EbVvST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_f3IlVTm5_sendMessage(_c, 0, m);
  cMsg_jRjUMV1n_sendMessage(_c, 0, m);
  cMsg_yMScmPrP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JZtYCRG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_qVdsYs8G_sendMessage(_c, 0, m);
  cMsg_CCNBK0sg_sendMessage(_c, 0, m);
  cMsg_C0BW0LQ6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_AEroAmfE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P56Fm9Qz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_B3Ao1an4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1r0QXjWj, 0, m, &cSlice_1r0QXjWj_sendMessage);
      break;
    }
    default: {
      cSwitchcase_LDfVVWjx_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_1r0QXjWj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_8eAH4jyj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_8eAH4jyj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Q6uauMKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8eAH4jyj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_8eAH4jyj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eAHCJYCk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_anjOgIOV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ofrTXllH, 0, m, &cSlice_ofrTXllH_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pRFi5P6S_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ofrTXllH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_cfWfshYI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_cfWfshYI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_GMv7EP9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cfWfshYI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_cfWfshYI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IRDdowG3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_pRFi5P6S_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PCgg3HMl, 0, m, &cSlice_PCgg3HMl_sendMessage);
      break;
    }
    default: {
      cSwitchcase_B3Ao1an4_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_PCgg3HMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_s0qRh7ca_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_s0qRh7ca_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_A3iZxPgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_s0qRh7ca_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_s0qRh7ca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1ojaMLFz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_LDfVVWjx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_etF2xKbK, 0, m, &cSlice_etF2xKbK_sendMessage);
      break;
    }
    default: {
      cSwitchcase_wWesvAzS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_etF2xKbK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EnhsByFw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EnhsByFw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_aDptkESi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EnhsByFw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_EnhsByFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rJkJybnt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_wWesvAzS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9R6GO5AH, 0, m, &cSlice_9R6GO5AH_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Sd5A9yly_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_9R6GO5AH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LxLJF1kE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LxLJF1kE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_M68YG6YU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LxLJF1kE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_LxLJF1kE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uzr7DWF4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_TV7T54bc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_a0wF42Vr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_a0wF42Vr_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_NWwVJIpT, 1, m, &cDelay_NWwVJIpT_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_angIHh9L_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_NWwVJIpT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NWwVJIpT, m);
  cMsg_dRNbjbHC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_a0wF42Vr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_NWwVJIpT, 0, m, &cDelay_NWwVJIpT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_angIHh9L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NWwVJIpT, 0, m, &cDelay_NWwVJIpT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_EC1KbLTi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NGxSeKLz, HV_BINOP_SUBTRACT, 0, m, &cBinop_NGxSeKLz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_LylJ5Pfm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mCxiSwa8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_rsOJTeLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mCxiSwa8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_rnRfn47V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EC1KbLTi, 0, m, &cVar_EC1KbLTi_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_wyvist55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_15Udfi0d_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a5HuCEBK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j6BdKu98_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NGxSeKLz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xnGriFzS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xnGriFzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FjsiRnK9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FjsiRnK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_eEKRl1Tv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PQbqtnVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GEBkuOob_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uF3CansD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uF3CansD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zlEXFGJp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_GEBkuOob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LylJ5Pfm, 1, m, &cIf_LylJ5Pfm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pfe3n8vu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rsOJTeLu, 1, m, &cIf_rsOJTeLu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zlEXFGJp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_LylJ5Pfm, 0, m, &cIf_LylJ5Pfm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eEKRl1Tv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rsOJTeLu, 0, m, &cIf_rsOJTeLu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_j6BdKu98_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EC1KbLTi, 0, m, &cVar_EC1KbLTi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_15Udfi0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_a5HuCEBK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NGxSeKLz, HV_BINOP_SUBTRACT, 1, m, &cBinop_NGxSeKLz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mCxiSwa8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9HEtgyT2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Sd5A9yly_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gi0Sm5yz, 0, m, &cSlice_gi0Sm5yz_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_gi0Sm5yz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ZpgYBnOR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ZpgYBnOR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_EAb2FUNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZpgYBnOR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ZpgYBnOR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yJt7isjb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_H0cuv585_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zmiK1Gvb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wO3uOIOu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0cTdnOr6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_KrinGi96_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5GovrkQA, 0, m, &cVar_5GovrkQA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_P56Fm9Qz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZCxOQ1Fz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ipFxqo0I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_TV7T54bc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_aEW0aM2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E26G1WB7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dRNbjbHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DYD3oFkr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_E26G1WB7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DYD3oFkr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HpNvfScr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_EsapLqWY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EsapLqWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_022jAzc0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_022jAzc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XlN8478S, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_m3YFGIVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SXBZnlYl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ssmrCi7R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Gt7wVoDw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_rJiZbPL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JtB8O5OR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_EzngAcBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f2ZmN9zk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_xLMaQRlq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QVqRRrpC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_H7YYhhbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_mWPyy6zh_sendMessage);
  cMsg_qGH3yDOo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_mWPyy6zh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_H7YYhhbd, 1, m, &cVar_H7YYhhbd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9Pfu6ylV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FZwtPYP5_sendMessage(_c, 0, m);
  cMsg_PRxJoJt6_sendMessage(_c, 0, m);
  cMsg_oM2AU6IH_sendMessage(_c, 0, m);
  cMsg_tfEf5cV7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9m5TSO0S_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jQZJ7Vqx, 0, m, &cSlice_jQZJ7Vqx_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_jQZJ7Vqx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ftH0auHB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ftH0auHB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_c5cixGjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ftH0auHB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ftH0auHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ubvayiq8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_dxSLXUU9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_wOJO82XZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wOJO82XZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_j9is7jJ3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_j9is7jJ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_6Xh8i6YF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6Xh8i6YF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cXpV4mrm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RwcNwnCJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cXpV4mrm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_MEKLuLjx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RwcNwnCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vN6mkGOO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_MEKLuLjx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_YwkHkJi9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vN6mkGOO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_UwvpDPAK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UwvpDPAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_M95b1uEx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YwkHkJi9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kmVIs5jQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_M95b1uEx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cQeLOtaa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kmVIs5jQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9AC0HQLq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cQeLOtaa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eJA8JcFk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_fB8c7l4h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Mw4JaCxm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_mHmGa52i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bNmBcROI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_oxzOrAOz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0IjWrveE_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xzt6CD3k_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_orYig522_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bs2wOEEh_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QgOtaAx6_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wpt8b7Ej_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_0IjWrveE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3icWexqi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_xzt6CD3k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vd7cCpFs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_orYig522_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2XI9JCLg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_bs2wOEEh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DJh8PRSz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_QgOtaAx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OURpO0Ob_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Wpt8b7Ej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fGBRJYLI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_EwFTaKNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gOnNB9IT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_287wu5cS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KOsntw6p_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PMJIpifi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_mAQx7hHA_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_mAQx7hHA_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_KmbhoVbj, 1, m, &cDelay_KmbhoVbj_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MfkbNA5o_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_KmbhoVbj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KmbhoVbj, m);
  cIf_onMessage(_c, &Context(_c)->cIf_EwFTaKNi, 0, m, &cIf_EwFTaKNi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mAQx7hHA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_KmbhoVbj, 0, m, &cDelay_KmbhoVbj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MfkbNA5o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KmbhoVbj, 0, m, &cDelay_KmbhoVbj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nUVnQVRu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M6OaDgev_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BZKFN0ZA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8PiW9cje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d4ZqYILE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vCN2Gir5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vCN2Gir5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_PMJIpifi_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_d4ZqYILE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EwFTaKNi, 1, m, &cIf_EwFTaKNi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_M6OaDgev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_287wu5cS, 1, m, &cIf_287wu5cS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BZKFN0ZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_287wu5cS, 0, m, &cIf_287wu5cS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KOsntw6p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TadTAmQx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gOnNB9IT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TadTAmQx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_iUm65imH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aMxdjMK2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_rVZKd2lE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gWY66JYC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6P7kozdL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_R8WsoRJD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_R8WsoRJD_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_nBAyi0x7, 1, m, &cDelay_nBAyi0x7_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_214WPlTg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_nBAyi0x7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nBAyi0x7, m);
  cIf_onMessage(_c, &Context(_c)->cIf_iUm65imH, 0, m, &cIf_iUm65imH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_R8WsoRJD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_nBAyi0x7, 0, m, &cDelay_nBAyi0x7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_214WPlTg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nBAyi0x7, 0, m, &cDelay_nBAyi0x7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xMJ10KqG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LYLEfBCR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3rAUebHL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WzcxnSf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rqub9gGm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ffvIV9Lt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ffvIV9Lt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6P7kozdL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_rqub9gGm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iUm65imH, 1, m, &cIf_iUm65imH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3rAUebHL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rVZKd2lE, 0, m, &cIf_rVZKd2lE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LYLEfBCR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rVZKd2lE, 1, m, &cIf_rVZKd2lE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gWY66JYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uh8mTyiv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_aMxdjMK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uh8mTyiv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_MFP5qQ6Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VEhhl2AR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_hBtR9JSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JfNHCEDQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_uWIhFCKs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_DBM9SdiJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_DBM9SdiJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wlOSZshg, 1, m, &cDelay_wlOSZshg_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Sf25TfyL_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_wlOSZshg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wlOSZshg, m);
  cIf_onMessage(_c, &Context(_c)->cIf_MFP5qQ6Y, 0, m, &cIf_MFP5qQ6Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DBM9SdiJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wlOSZshg, 0, m, &cDelay_wlOSZshg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Sf25TfyL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wlOSZshg, 0, m, &cDelay_wlOSZshg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Uxv1toUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wQDdUwNy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vFfJZ2WU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WuDlGOdN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wWAjWW6l_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eZSG4UGN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wWAjWW6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MFP5qQ6Y, 1, m, &cIf_MFP5qQ6Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eZSG4UGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_uWIhFCKs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_vFfJZ2WU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hBtR9JSI, 0, m, &cIf_hBtR9JSI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wQDdUwNy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hBtR9JSI, 1, m, &cIf_hBtR9JSI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JfNHCEDQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4lAFjgeE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_VEhhl2AR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4lAFjgeE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_NhYwCptO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DYwwm1a8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_TZ8pGGuM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GMAXweFP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_iJzGZfxy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_6zZ8hSM4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_6zZ8hSM4_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_HK449oLT, 1, m, &cDelay_HK449oLT_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QbWU8jEe_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_HK449oLT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HK449oLT, m);
  cIf_onMessage(_c, &Context(_c)->cIf_NhYwCptO, 0, m, &cIf_NhYwCptO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6zZ8hSM4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_HK449oLT, 0, m, &cDelay_HK449oLT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QbWU8jEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HK449oLT, 0, m, &cDelay_HK449oLT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7pYHRRt7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_obFIszAl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N750050G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xywDoGdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XozD28uf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_75hIbYa1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_75hIbYa1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_iJzGZfxy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_XozD28uf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NhYwCptO, 1, m, &cIf_NhYwCptO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_obFIszAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TZ8pGGuM, 1, m, &cIf_TZ8pGGuM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_N750050G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TZ8pGGuM, 0, m, &cIf_TZ8pGGuM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GMAXweFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zsVU29qC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DYwwm1a8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zsVU29qC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_93n7sxT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_btYu63jH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_qutvRgQu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_v14VjwNL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_QIenSJG1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_cEjy09dM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_cEjy09dM_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_KJOB6O0F, 1, m, &cDelay_KJOB6O0F_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r8wM9xh3_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_KJOB6O0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KJOB6O0F, m);
  cIf_onMessage(_c, &Context(_c)->cIf_93n7sxT4, 0, m, &cIf_93n7sxT4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cEjy09dM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_KJOB6O0F, 0, m, &cDelay_KJOB6O0F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_r8wM9xh3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KJOB6O0F, 0, m, &cDelay_KJOB6O0F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YRpyVeGZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ut9CDcXp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JKDRQ1Ii_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BTibBoLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TwM3lrHG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NgSmgFPF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NgSmgFPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_QIenSJG1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_TwM3lrHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_93n7sxT4, 1, m, &cIf_93n7sxT4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ut9CDcXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qutvRgQu, 1, m, &cIf_qutvRgQu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JKDRQ1Ii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qutvRgQu, 0, m, &cIf_qutvRgQu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_v14VjwNL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8LEcWOj7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_btYu63jH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8LEcWOj7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_pIlMMVuP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_iGuPJoSF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_jO9abhC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_T8PpbZ44_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PVCVSlWG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_bCjwxiD7_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_bCjwxiD7_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_z8C31oSD, 1, m, &cDelay_z8C31oSD_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dDcbNMaR_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_z8C31oSD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_z8C31oSD, m);
  cIf_onMessage(_c, &Context(_c)->cIf_pIlMMVuP, 0, m, &cIf_pIlMMVuP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bCjwxiD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_z8C31oSD, 0, m, &cDelay_z8C31oSD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dDcbNMaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_z8C31oSD, 0, m, &cDelay_z8C31oSD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4LR013hR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_J59jzFMH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Rf9qGqkv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VDH190B9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mUjO007s_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tw3MnKNU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tw3MnKNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_PVCVSlWG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_mUjO007s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pIlMMVuP, 1, m, &cIf_pIlMMVuP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_J59jzFMH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jO9abhC6, 1, m, &cIf_jO9abhC6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Rf9qGqkv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jO9abhC6, 0, m, &cIf_jO9abhC6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_T8PpbZ44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jlrC4lBc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_iGuPJoSF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jlrC4lBc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_N7lPI7B3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BOczysZi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_YuFkXD0W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7go8Ut89_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_LYHlzMtF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_83qD0PlP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_83qD0PlP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_csQ2VY1I, 1, m, &cDelay_csQ2VY1I_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1PoPFhtK_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_csQ2VY1I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_csQ2VY1I, m);
  cIf_onMessage(_c, &Context(_c)->cIf_N7lPI7B3, 0, m, &cIf_N7lPI7B3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_83qD0PlP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_csQ2VY1I, 0, m, &cDelay_csQ2VY1I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1PoPFhtK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_csQ2VY1I, 0, m, &cDelay_csQ2VY1I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0qFB4nek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sKpcO3HZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bhXW8EDD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BdTzHlim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LSBXBcEY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dFpExCsL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dFpExCsL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_LYHlzMtF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_LSBXBcEY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_N7lPI7B3, 1, m, &cIf_N7lPI7B3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sKpcO3HZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YuFkXD0W, 1, m, &cIf_YuFkXD0W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bhXW8EDD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YuFkXD0W, 0, m, &cIf_YuFkXD0W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7go8Ut89_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZjU2F2Oq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_BOczysZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZjU2F2Oq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_2OECpdgP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_iOkOxxNZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_6ryh4wlf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yAMuKw9K_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_XWYsLoQI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_lHyKZ4G6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_lHyKZ4G6_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_8dVJFeN9, 1, m, &cDelay_8dVJFeN9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uH9c8ImN_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_8dVJFeN9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8dVJFeN9, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2OECpdgP, 0, m, &cIf_2OECpdgP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lHyKZ4G6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_8dVJFeN9, 0, m, &cDelay_8dVJFeN9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uH9c8ImN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8dVJFeN9, 0, m, &cDelay_8dVJFeN9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tsPHyxRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SbXvfuFY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_amJ6kMnY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uu9Azm3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vgJ4JpRN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wtd4dA9D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Wtd4dA9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_XWYsLoQI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_vgJ4JpRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2OECpdgP, 1, m, &cIf_2OECpdgP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_amJ6kMnY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6ryh4wlf, 0, m, &cIf_6ryh4wlf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SbXvfuFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6ryh4wlf, 1, m, &cIf_6ryh4wlf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yAMuKw9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CQAyyN9W, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_iOkOxxNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CQAyyN9W, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_agfaSQuh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AKjnfZOJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_zEzc00ZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ocfy5u00_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_paCSKALn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Qys1mvqs_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Qys1mvqs_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_OzHBMdbc, 1, m, &cDelay_OzHBMdbc_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tJtLIC8N_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_OzHBMdbc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OzHBMdbc, m);
  cIf_onMessage(_c, &Context(_c)->cIf_agfaSQuh, 0, m, &cIf_agfaSQuh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Qys1mvqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_OzHBMdbc, 0, m, &cDelay_OzHBMdbc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tJtLIC8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OzHBMdbc, 0, m, &cDelay_OzHBMdbc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rlR0RKsb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_G7kKDOGg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WHEkZa3R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NWZqzcpB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UvMX5ESq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LdNIgs00_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LdNIgs00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_paCSKALn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_UvMX5ESq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_agfaSQuh, 1, m, &cIf_agfaSQuh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_G7kKDOGg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zEzc00ZQ, 1, m, &cIf_zEzc00ZQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WHEkZa3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zEzc00ZQ, 0, m, &cIf_zEzc00ZQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ocfy5u00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_avkEH5I6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_AKjnfZOJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_avkEH5I6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_yovJ5AkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4pIINpbk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_NvOBZRft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9MPOM8Dk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_pBfUE0Ur_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_fIhDmqvz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_fIhDmqvz_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_61am8gKN, 1, m, &cDelay_61am8gKN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TBDe0h2y_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_61am8gKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_61am8gKN, m);
  cIf_onMessage(_c, &Context(_c)->cIf_yovJ5AkJ, 0, m, &cIf_yovJ5AkJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fIhDmqvz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_61am8gKN, 0, m, &cDelay_61am8gKN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TBDe0h2y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_61am8gKN, 0, m, &cDelay_61am8gKN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_46udo3Z8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZdceeWzf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M9Gr5mXc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RiR9pTAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_loelHzVp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nh2dQNQj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_loelHzVp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yovJ5AkJ, 1, m, &cIf_yovJ5AkJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nh2dQNQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_pBfUE0Ur_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ZdceeWzf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NvOBZRft, 1, m, &cIf_NvOBZRft_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_M9Gr5mXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NvOBZRft, 0, m, &cIf_NvOBZRft_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9MPOM8Dk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wGKFAbvM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4pIINpbk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wGKFAbvM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_jvnMTeWd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_pRq2T9X1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_NTWedMiE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_khlCDkhW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_vl0wU3VF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Ef8SAUZi_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Ef8SAUZi_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4WbUvump, 1, m, &cDelay_4WbUvump_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3k8eLhoE_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_4WbUvump_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4WbUvump, m);
  cIf_onMessage(_c, &Context(_c)->cIf_jvnMTeWd, 0, m, &cIf_jvnMTeWd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ef8SAUZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4WbUvump, 0, m, &cDelay_4WbUvump_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3k8eLhoE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4WbUvump, 0, m, &cDelay_4WbUvump_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fNE2lN4Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4okwYX2y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5YbNNVPG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_riDzCKey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Y2L0OYQE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ssCfQWHY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Y2L0OYQE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jvnMTeWd, 1, m, &cIf_jvnMTeWd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ssCfQWHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vl0wU3VF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_5YbNNVPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NTWedMiE, 0, m, &cIf_NTWedMiE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4okwYX2y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NTWedMiE, 1, m, &cIf_NTWedMiE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_khlCDkhW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZMFtYear, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_pRq2T9X1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZMFtYear, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_chDyMape_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ajKh7b1o_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_hSnXm4yF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7gmhx5TS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_e0xGIcSu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ej8czJVe_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ej8czJVe_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_rZ4YzNB3, 1, m, &cDelay_rZ4YzNB3_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KBbbc4Yk_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_rZ4YzNB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rZ4YzNB3, m);
  cIf_onMessage(_c, &Context(_c)->cIf_chDyMape, 0, m, &cIf_chDyMape_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ej8czJVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_rZ4YzNB3, 0, m, &cDelay_rZ4YzNB3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KBbbc4Yk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rZ4YzNB3, 0, m, &cDelay_rZ4YzNB3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FLdE0GFv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_97cq8NKU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_poZWFiId_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5lGRtKiM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VSYvQMdc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KfkFP9Wc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VSYvQMdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_chDyMape, 1, m, &cIf_chDyMape_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KfkFP9Wc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_e0xGIcSu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_poZWFiId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hSnXm4yF, 0, m, &cIf_hSnXm4yF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_97cq8NKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hSnXm4yF, 1, m, &cIf_hSnXm4yF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7gmhx5TS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9PbNWfXs, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ajKh7b1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9PbNWfXs, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3icWexqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_sSDmHceC_sendMessage(_c, 0, m);
  cMsg_dbfqy9rK_sendMessage(_c, 0, m);
  cMsg_shoMbGnR_sendMessage(_c, 0, m);
  cMsg_OT4cksCq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_vd7cCpFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_sSDmHceC_sendMessage(_c, 0, m);
  cMsg_WzFjmSGh_sendMessage(_c, 0, m);
  cMsg_bqO3F9ZL_sendMessage(_c, 0, m);
  cMsg_akZ2zhbp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2XI9JCLg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_DikiypF3_sendMessage(_c, 0, m);
  cMsg_WzFjmSGh_sendMessage(_c, 0, m);
  cMsg_OT4cksCq_sendMessage(_c, 0, m);
  cMsg_6JxLMMY9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DJh8PRSz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_DikiypF3_sendMessage(_c, 0, m);
  cMsg_2UonNH0i_sendMessage(_c, 0, m);
  cMsg_shoMbGnR_sendMessage(_c, 0, m);
  cMsg_5HImKaN6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OURpO0Ob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_XJ4plUY9_sendMessage(_c, 0, m);
  cMsg_akZ2zhbp_sendMessage(_c, 0, m);
  cMsg_s3uIDVj9_sendMessage(_c, 0, m);
  cMsg_shoMbGnR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fGBRJYLI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_XJ4plUY9_sendMessage(_c, 0, m);
  cMsg_5HImKaN6_sendMessage(_c, 0, m);
  cMsg_WzFjmSGh_sendMessage(_c, 0, m);
  cMsg_3IAz7rVG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2zi7G79y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_8PiW9cje_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nUVnQVRu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eBxMTAtS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_8PiW9cje_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nUVnQVRu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uwTETqmk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_WzcxnSf7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xMJ10KqG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_44lUqbRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_WzcxnSf7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xMJ10KqG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8aNJ9tof_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_WuDlGOdN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Uxv1toUX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aBiz4Va8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_WuDlGOdN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Uxv1toUX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sSDmHceC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_2zi7G79y_sendMessage(_c, 0, m);
  cMsg_44lUqbRc_sendMessage(_c, 0, m);
  cMsg_aBiz4Va8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DikiypF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_eBxMTAtS_sendMessage(_c, 0, m);
  cMsg_uwTETqmk_sendMessage(_c, 0, m);
  cMsg_aBiz4Va8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_XJ4plUY9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_eBxMTAtS_sendMessage(_c, 0, m);
  cMsg_44lUqbRc_sendMessage(_c, 0, m);
  cMsg_8aNJ9tof_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3YUeQWcA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xywDoGdq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7pYHRRt7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VQzMBDWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xywDoGdq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7pYHRRt7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sRpkCYnN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BTibBoLc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YRpyVeGZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kXyjlUrg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BTibBoLc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YRpyVeGZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CjmwUlbR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VDH190B9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4LR013hR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_O9R2rKfl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VDH190B9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4LR013hR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WzFjmSGh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_VQzMBDWg_sendMessage(_c, 0, m);
  cMsg_kXyjlUrg_sendMessage(_c, 0, m);
  cMsg_O9R2rKfl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dbfqy9rK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_VQzMBDWg_sendMessage(_c, 0, m);
  cMsg_sRpkCYnN_sendMessage(_c, 0, m);
  cMsg_CjmwUlbR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2UonNH0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_3YUeQWcA_sendMessage(_c, 0, m);
  cMsg_kXyjlUrg_sendMessage(_c, 0, m);
  cMsg_CjmwUlbR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_atv1w1jN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RiR9pTAb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_46udo3Z8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_P1YnZk4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RiR9pTAb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_46udo3Z8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jWG8P7R7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_riDzCKey_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fNE2lN4Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_q539chJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_riDzCKey_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fNE2lN4Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gsalCizL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5lGRtKiM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FLdE0GFv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6voW2XAA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5lGRtKiM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FLdE0GFv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5HImKaN6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_atv1w1jN_sendMessage(_c, 0, m);
  cMsg_q539chJf_sendMessage(_c, 0, m);
  cMsg_6voW2XAA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_akZ2zhbp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_P1YnZk4W_sendMessage(_c, 0, m);
  cMsg_jWG8P7R7_sendMessage(_c, 0, m);
  cMsg_6voW2XAA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OT4cksCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_P1YnZk4W_sendMessage(_c, 0, m);
  cMsg_q539chJf_sendMessage(_c, 0, m);
  cMsg_gsalCizL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5nSW6zzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BdTzHlim_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0qFB4nek_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_p6gW6AGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BdTzHlim_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0qFB4nek_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ESO6gMmY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_uu9Azm3C_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tsPHyxRN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TzSMhL7v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_uu9Azm3C_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tsPHyxRN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kInN4MmV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_NWZqzcpB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rlR0RKsb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jxABxIE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_NWZqzcpB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rlR0RKsb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_shoMbGnR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_p6gW6AGt_sendMessage(_c, 0, m);
  cMsg_TzSMhL7v_sendMessage(_c, 0, m);
  cMsg_jxABxIE1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_bqO3F9ZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_p6gW6AGt_sendMessage(_c, 0, m);
  cMsg_ESO6gMmY_sendMessage(_c, 0, m);
  cMsg_kInN4MmV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3IAz7rVG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_5nSW6zzS_sendMessage(_c, 0, m);
  cMsg_ESO6gMmY_sendMessage(_c, 0, m);
  cMsg_jxABxIE1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_s3uIDVj9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_3YUeQWcA_sendMessage(_c, 0, m);
  cMsg_sRpkCYnN_sendMessage(_c, 0, m);
  cMsg_O9R2rKfl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6JxLMMY9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_5nSW6zzS_sendMessage(_c, 0, m);
  cMsg_TzSMhL7v_sendMessage(_c, 0, m);
  cMsg_kInN4MmV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_lF8GeV1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e7vau8Rn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UFRFy5YG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vMvO5JOg, 0, m, &cSlice_vMvO5JOg_sendMessage);
      break;
    }
    default: {
      cSwitchcase_s7kTERif_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_vMvO5JOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_E0W0KuZX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_E0W0KuZX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_qRl5n9Au_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_E0W0KuZX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_E0W0KuZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hZo3JHq0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zrKNePD5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_kmh7mgsI, 0, m, &cSlice_kmh7mgsI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_fSeiDvVE_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_kmh7mgsI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Vyb2RkE1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Vyb2RkE1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_vcGjWvE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Vyb2RkE1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Vyb2RkE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HY6lASBk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fSeiDvVE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_j56RDPRv, 0, m, &cSlice_j56RDPRv_sendMessage);
      break;
    }
    default: {
      cSwitchcase_UFRFy5YG_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_j56RDPRv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_V26h58c1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_V26h58c1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_fWPO9Zcq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_V26h58c1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_V26h58c1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vruNnkpQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_s7kTERif_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PSpLWk81, 0, m, &cSlice_PSpLWk81_sendMessage);
      break;
    }
    default: {
      cSwitchcase_V5JwAv5E_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_PSpLWk81_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_fJEWvEPV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_fJEWvEPV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_CqtW1KH5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fJEWvEPV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_fJEWvEPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vMeMo5wP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_V5JwAv5E_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_W2nGZkhD, 0, m, &cSlice_W2nGZkhD_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ClLYJzxK_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_W2nGZkhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_sdy6E1HD_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_sdy6E1HD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_xthLHeVv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sdy6E1HD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_sdy6E1HD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jYwxN8sZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_B35hHQOc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_k20z7rIQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_k20z7rIQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_6cLs8naa, 1, m, &cDelay_6cLs8naa_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3GDVFkOA_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_6cLs8naa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6cLs8naa, m);
  cMsg_9mhgZnnT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_k20z7rIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_6cLs8naa, 0, m, &cDelay_6cLs8naa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3GDVFkOA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6cLs8naa, 0, m, &cDelay_6cLs8naa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_AYRaiYX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3pFKw8Tz, HV_BINOP_SUBTRACT, 0, m, &cBinop_3pFKw8Tz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_FkI5bcU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JI65B8O1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_AcZ2xMpZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JI65B8O1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_MkNYtrzu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AYRaiYX1, 0, m, &cVar_AYRaiYX1_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_ccdQtJRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xoAQfcfr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xRh9oyyV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O4LLc9cj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3pFKw8Tz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Hty44KHI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Hty44KHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_JO66VRca_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JO66VRca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_gspHeD5O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eRVfTt0P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YgRYDcdh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C66qekVD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_C66qekVD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tfONd46Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_YgRYDcdh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FkI5bcU5, 1, m, &cIf_FkI5bcU5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RBvyMmUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AcZ2xMpZ, 1, m, &cIf_AcZ2xMpZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tfONd46Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_FkI5bcU5, 0, m, &cIf_FkI5bcU5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gspHeD5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AcZ2xMpZ, 0, m, &cIf_AcZ2xMpZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_O4LLc9cj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AYRaiYX1, 0, m, &cVar_AYRaiYX1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xoAQfcfr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_xRh9oyyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3pFKw8Tz, HV_BINOP_SUBTRACT, 1, m, &cBinop_3pFKw8Tz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JI65B8O1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_y8vhNhW8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ClLYJzxK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_u81GAqTG, 0, m, &cSlice_u81GAqTG_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_u81GAqTG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NrmjQAhi_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NrmjQAhi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Dty4I6eG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NrmjQAhi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_NrmjQAhi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TCJ5bAE9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Mw4JaCxm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0o76B904, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_bNmBcROI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9pYR8xkk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_Rv4Qk0S1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mHmGa52i, 0, m, &cVar_mHmGa52i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_e7vau8Rn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3G0VnOCE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_1v0I1A8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_B35hHQOc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_I9skuXV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iS9fjf0J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9mhgZnnT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_W7qaelao, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_iS9fjf0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_W7qaelao, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Wdzl0tUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_C54kJyzz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_C54kJyzz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_86TlPHgr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_86TlPHgr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kQHOZqfc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_hyeZcgLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hgU94Ftf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_LHoN6Nzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GsaLGRiJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_rOAPPJhu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Jc4hKBJC_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SeenO8eq_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6HsoX33Y_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yNpfLKX1_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YKP8e9Dd_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GjPWiALk_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_Jc4hKBJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zWmC6lDO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_SeenO8eq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Km1tUx5r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_6HsoX33Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OG7wIQXI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_yNpfLKX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UDXXgbhf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_YKP8e9Dd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9bt6AHZi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_GjPWiALk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OiQ5Gt5U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_aT6hWdCZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EoHAQUiX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_sVW4FChB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zMr254xj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_onxlcsRP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_i19DWbed_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_i19DWbed_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5mE9bj4B, 1, m, &cDelay_5mE9bj4B_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5idoaCsA_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_5mE9bj4B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5mE9bj4B, m);
  cIf_onMessage(_c, &Context(_c)->cIf_aT6hWdCZ, 0, m, &cIf_aT6hWdCZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_i19DWbed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5mE9bj4B, 0, m, &cDelay_5mE9bj4B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5idoaCsA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5mE9bj4B, 0, m, &cDelay_5mE9bj4B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3Mmz7GHP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1gCRjRDP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JpT8ybpg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_F9ifqQF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y9kmvI5K_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rcsOWWJZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rcsOWWJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_onxlcsRP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_y9kmvI5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aT6hWdCZ, 1, m, &cIf_aT6hWdCZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JpT8ybpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sVW4FChB, 0, m, &cIf_sVW4FChB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1gCRjRDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sVW4FChB, 1, m, &cIf_sVW4FChB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zMr254xj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Vc1TQR6O, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_EoHAQUiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Vc1TQR6O, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_dJ99unWs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YrMSXrUg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_uI7QDa7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aXr9ryUm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_m7kQF9o3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_5N6K6kzL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_5N6K6kzL_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_imnZvlLT, 1, m, &cDelay_imnZvlLT_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_usZqHpV0_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_imnZvlLT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_imnZvlLT, m);
  cIf_onMessage(_c, &Context(_c)->cIf_dJ99unWs, 0, m, &cIf_dJ99unWs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5N6K6kzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_imnZvlLT, 0, m, &cDelay_imnZvlLT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_usZqHpV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_imnZvlLT, 0, m, &cDelay_imnZvlLT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qBVi3UnV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DD5jVJib_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rQE7vsv2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kstle1VP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JCHejUBK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4KJy4nPb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4KJy4nPb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_m7kQF9o3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_JCHejUBK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dJ99unWs, 1, m, &cIf_dJ99unWs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DD5jVJib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uI7QDa7W, 1, m, &cIf_uI7QDa7W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rQE7vsv2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uI7QDa7W, 0, m, &cIf_uI7QDa7W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aXr9ryUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oVb1uorp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YrMSXrUg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oVb1uorp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_db6Vg1jM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2sWIlI0q_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_2mYjbg4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uUvdh3UO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_kT5XeBp7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_AUtUx2HP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_AUtUx2HP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_OP7KN4s9, 1, m, &cDelay_OP7KN4s9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4vf3sC9m_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_OP7KN4s9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OP7KN4s9, m);
  cIf_onMessage(_c, &Context(_c)->cIf_db6Vg1jM, 0, m, &cIf_db6Vg1jM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AUtUx2HP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_OP7KN4s9, 0, m, &cDelay_OP7KN4s9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4vf3sC9m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OP7KN4s9, 0, m, &cDelay_OP7KN4s9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pjDSYNBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3N3g1Hj1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NJ3N6Btc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2vgn6aJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u9eiYQql_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KOhg6XR8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KOhg6XR8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kT5XeBp7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_u9eiYQql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_db6Vg1jM, 1, m, &cIf_db6Vg1jM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NJ3N6Btc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2mYjbg4X, 0, m, &cIf_2mYjbg4X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3N3g1Hj1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2mYjbg4X, 1, m, &cIf_2mYjbg4X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uUvdh3UO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2WuHKoFb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_2sWIlI0q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2WuHKoFb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ZNJPspGm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_udExLm5P_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_E0cmsVAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SgUksd64_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_vtGa50iC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_UA1XJCki_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_UA1XJCki_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_FZRCJKIG, 1, m, &cDelay_FZRCJKIG_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9Emr7dB8_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_FZRCJKIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FZRCJKIG, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ZNJPspGm, 0, m, &cIf_ZNJPspGm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UA1XJCki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_FZRCJKIG, 0, m, &cDelay_FZRCJKIG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9Emr7dB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FZRCJKIG, 0, m, &cDelay_FZRCJKIG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YayXWn2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KSJ8jOU8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yZ9al9RY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QKG5MVMG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vJS5lbEG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_l07u4CSM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_l07u4CSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vtGa50iC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_vJS5lbEG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZNJPspGm, 1, m, &cIf_ZNJPspGm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KSJ8jOU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_E0cmsVAI, 1, m, &cIf_E0cmsVAI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yZ9al9RY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_E0cmsVAI, 0, m, &cIf_E0cmsVAI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SgUksd64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2nNyH92V, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_udExLm5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2nNyH92V, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_3UNcuGFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gG5GGeaH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_DvtumWVu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NJz0BtJ6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_8lljrVNL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Ava6yxlz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Ava6yxlz_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Q6eHigju, 1, m, &cDelay_Q6eHigju_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CZfhrsUc_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Q6eHigju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Q6eHigju, m);
  cIf_onMessage(_c, &Context(_c)->cIf_3UNcuGFI, 0, m, &cIf_3UNcuGFI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ava6yxlz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q6eHigju, 0, m, &cDelay_Q6eHigju_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CZfhrsUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q6eHigju, 0, m, &cDelay_Q6eHigju_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Z7mDGayM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QXHzWNiM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HOEJubLt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZSefXPO6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ohM0CG4H_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Zgwjvglj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Zgwjvglj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8lljrVNL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ohM0CG4H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3UNcuGFI, 1, m, &cIf_3UNcuGFI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HOEJubLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DvtumWVu, 0, m, &cIf_DvtumWVu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QXHzWNiM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DvtumWVu, 1, m, &cIf_DvtumWVu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NJz0BtJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zAbd9Zup, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gG5GGeaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zAbd9Zup, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_WKQcvdxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_D6YBa415_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_CjEEqE9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lvYhOT09_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_CuPPjATn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_40Y4If8X_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_40Y4If8X_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_zHIxJiqi, 1, m, &cDelay_zHIxJiqi_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ueAwxyda_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_zHIxJiqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zHIxJiqi, m);
  cIf_onMessage(_c, &Context(_c)->cIf_WKQcvdxL, 0, m, &cIf_WKQcvdxL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_40Y4If8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zHIxJiqi, 0, m, &cDelay_zHIxJiqi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ueAwxyda_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zHIxJiqi, 0, m, &cDelay_zHIxJiqi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MmvFvwX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_F09Yk428_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RsRdVOVR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vRvc0N15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d3Plnx4i_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BpWjiHfa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BpWjiHfa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_CuPPjATn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_d3Plnx4i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WKQcvdxL, 1, m, &cIf_WKQcvdxL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RsRdVOVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CjEEqE9r, 0, m, &cIf_CjEEqE9r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_F09Yk428_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CjEEqE9r, 1, m, &cIf_CjEEqE9r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lvYhOT09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_L8ddu7d1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_D6YBa415_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_L8ddu7d1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_bT2Kizod_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yY7ImODs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_E6zBsSGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XqdNi0Jq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_SjpLzF49_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_bLgaeQ92_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_bLgaeQ92_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_CgmqybxV, 1, m, &cDelay_CgmqybxV_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hJ7AGFTW_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_CgmqybxV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CgmqybxV, m);
  cIf_onMessage(_c, &Context(_c)->cIf_bT2Kizod, 0, m, &cIf_bT2Kizod_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bLgaeQ92_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_CgmqybxV, 0, m, &cDelay_CgmqybxV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hJ7AGFTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CgmqybxV, 0, m, &cDelay_CgmqybxV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7r7WKNVj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hQ27TZQ8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BtohkjoH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_B3NA8Wsf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gJzGdPWT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mZ49mQPg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gJzGdPWT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bT2Kizod, 1, m, &cIf_bT2Kizod_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mZ49mQPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_SjpLzF49_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_BtohkjoH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_E6zBsSGn, 0, m, &cIf_E6zBsSGn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hQ27TZQ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_E6zBsSGn, 1, m, &cIf_E6zBsSGn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XqdNi0Jq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EtUrVCZB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yY7ImODs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EtUrVCZB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_CTrMeJEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_n2ltb832_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_liqp7iZ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_oRhtVxHX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_cKK8U0G2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_YfYOSANI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_YfYOSANI_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_mEhzfzHu, 1, m, &cDelay_mEhzfzHu_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JEVR0ozJ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_mEhzfzHu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mEhzfzHu, m);
  cIf_onMessage(_c, &Context(_c)->cIf_CTrMeJEp, 0, m, &cIf_CTrMeJEp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YfYOSANI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_mEhzfzHu, 0, m, &cDelay_mEhzfzHu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JEVR0ozJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mEhzfzHu, 0, m, &cDelay_mEhzfzHu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qtKXsjoL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_40QfdZ4m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6XCODEkZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wVRwd2Nq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZbYGZl5h_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_I9JIHNJt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_I9JIHNJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_cKK8U0G2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ZbYGZl5h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CTrMeJEp, 1, m, &cIf_CTrMeJEp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6XCODEkZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_liqp7iZ3, 0, m, &cIf_liqp7iZ3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_40QfdZ4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_liqp7iZ3, 1, m, &cIf_liqp7iZ3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oRhtVxHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_z0RMZ0hW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_n2ltb832_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_z0RMZ0hW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_xn5tKNZo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FIOVrIl7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_hXRMfVV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bTINRUny_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_vwZhauVk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_X4d4pXzZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_X4d4pXzZ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4QzOrBnZ, 1, m, &cDelay_4QzOrBnZ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tybRHsBo_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_4QzOrBnZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4QzOrBnZ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_xn5tKNZo, 0, m, &cIf_xn5tKNZo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_X4d4pXzZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4QzOrBnZ, 0, m, &cDelay_4QzOrBnZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tybRHsBo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4QzOrBnZ, 0, m, &cDelay_4QzOrBnZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rYrPZnku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YBDHNXSE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M6QK23nI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_u2qKXiU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FZRYybMW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PQhLYOc6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PQhLYOc6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vwZhauVk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_FZRYybMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xn5tKNZo, 1, m, &cIf_xn5tKNZo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_M6QK23nI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hXRMfVV0, 0, m, &cIf_hXRMfVV0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YBDHNXSE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hXRMfVV0, 1, m, &cIf_hXRMfVV0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bTINRUny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7P6gwSX8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FIOVrIl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7P6gwSX8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_B7OBg6gf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qskLErR0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_8lGQx7eo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Z2YmNH70_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_NLa76OjA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_4DOMvBCu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_4DOMvBCu_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Q24CQiBO, 1, m, &cDelay_Q24CQiBO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_35rwyjnW_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Q24CQiBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Q24CQiBO, m);
  cIf_onMessage(_c, &Context(_c)->cIf_B7OBg6gf, 0, m, &cIf_B7OBg6gf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4DOMvBCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q24CQiBO, 0, m, &cDelay_Q24CQiBO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_35rwyjnW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q24CQiBO, 0, m, &cDelay_Q24CQiBO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_u82ZUmS8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D1jkbrsr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NejAu1vi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JdbgkcMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YZvtO6me_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DCWsv6TW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DCWsv6TW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NLa76OjA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_YZvtO6me_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_B7OBg6gf, 1, m, &cIf_B7OBg6gf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NejAu1vi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8lGQx7eo, 0, m, &cIf_8lGQx7eo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_D1jkbrsr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8lGQx7eo, 1, m, &cIf_8lGQx7eo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Z2YmNH70_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mgDLNC5N, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qskLErR0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mgDLNC5N, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_rWpBlJXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jfVNXd3I_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_4ohcBw0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aUeC1OvK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_r6pJSqYz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_hm1ELIBr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_hm1ELIBr_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vrkq10fB, 1, m, &cDelay_vrkq10fB_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UVptmP2w_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_vrkq10fB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vrkq10fB, m);
  cIf_onMessage(_c, &Context(_c)->cIf_rWpBlJXw, 0, m, &cIf_rWpBlJXw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hm1ELIBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vrkq10fB, 0, m, &cDelay_vrkq10fB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UVptmP2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vrkq10fB, 0, m, &cDelay_vrkq10fB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_R54ILsfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vCLRGCqq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HZfHVcME_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_73Sh5cte_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JYXL0YbF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VlyQfrDJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JYXL0YbF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rWpBlJXw, 1, m, &cIf_rWpBlJXw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VlyQfrDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_r6pJSqYz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_HZfHVcME_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4ohcBw0K, 0, m, &cIf_4ohcBw0K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vCLRGCqq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4ohcBw0K, 1, m, &cIf_4ohcBw0K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aUeC1OvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UqVYeDfp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jfVNXd3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UqVYeDfp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_sPCI6xjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WQIiFa4f_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Z2SB5uTr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_G7JWiLmT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ndc7y53c_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_io8FkXym_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_io8FkXym_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_SZ76EHNb, 1, m, &cDelay_SZ76EHNb_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kB1mzyUX_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_SZ76EHNb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SZ76EHNb, m);
  cIf_onMessage(_c, &Context(_c)->cIf_sPCI6xjb, 0, m, &cIf_sPCI6xjb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_io8FkXym_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_SZ76EHNb, 0, m, &cDelay_SZ76EHNb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kB1mzyUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SZ76EHNb, 0, m, &cDelay_SZ76EHNb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_P4oZZyJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JaSMnKyD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KX7Bz4S9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LMbVbjlA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c2cA9dSR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ucCrieuH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_c2cA9dSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sPCI6xjb, 1, m, &cIf_sPCI6xjb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ucCrieuH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ndc7y53c_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_KX7Bz4S9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Z2SB5uTr, 0, m, &cIf_Z2SB5uTr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JaSMnKyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Z2SB5uTr, 1, m, &cIf_Z2SB5uTr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_G7JWiLmT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_auDZnzx9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_WQIiFa4f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_auDZnzx9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zWmC6lDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_pn8yKvmt_sendMessage(_c, 0, m);
  cMsg_1e1eeY5G_sendMessage(_c, 0, m);
  cMsg_kV0ivrF2_sendMessage(_c, 0, m);
  cMsg_rEbLSIMy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Km1tUx5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_pn8yKvmt_sendMessage(_c, 0, m);
  cMsg_xM6mxLyA_sendMessage(_c, 0, m);
  cMsg_HvdViUXK_sendMessage(_c, 0, m);
  cMsg_UNBaLU6z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OG7wIQXI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_Hh8Vk9uw_sendMessage(_c, 0, m);
  cMsg_xM6mxLyA_sendMessage(_c, 0, m);
  cMsg_rEbLSIMy_sendMessage(_c, 0, m);
  cMsg_J2jx1jtQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UDXXgbhf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_Hh8Vk9uw_sendMessage(_c, 0, m);
  cMsg_PVXwZcI7_sendMessage(_c, 0, m);
  cMsg_kV0ivrF2_sendMessage(_c, 0, m);
  cMsg_gwnk2mXF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9bt6AHZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_iCUbDmdq_sendMessage(_c, 0, m);
  cMsg_UNBaLU6z_sendMessage(_c, 0, m);
  cMsg_CrfmZ1XQ_sendMessage(_c, 0, m);
  cMsg_kV0ivrF2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OiQ5Gt5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_iCUbDmdq_sendMessage(_c, 0, m);
  cMsg_gwnk2mXF_sendMessage(_c, 0, m);
  cMsg_xM6mxLyA_sendMessage(_c, 0, m);
  cMsg_cQjkowA1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OCTXsIM2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_F9ifqQF3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3Mmz7GHP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_J8sYwsYq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_F9ifqQF3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3Mmz7GHP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_i8UNBy8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kstle1VP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qBVi3UnV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AHqRb72z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kstle1VP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qBVi3UnV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Rk3bCSj2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2vgn6aJo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pjDSYNBB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lN0y6iIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2vgn6aJo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pjDSYNBB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pn8yKvmt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_OCTXsIM2_sendMessage(_c, 0, m);
  cMsg_AHqRb72z_sendMessage(_c, 0, m);
  cMsg_lN0y6iIf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Hh8Vk9uw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_J8sYwsYq_sendMessage(_c, 0, m);
  cMsg_i8UNBy8E_sendMessage(_c, 0, m);
  cMsg_lN0y6iIf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_iCUbDmdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_J8sYwsYq_sendMessage(_c, 0, m);
  cMsg_AHqRb72z_sendMessage(_c, 0, m);
  cMsg_Rk3bCSj2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_x8RiKucA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QKG5MVMG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YayXWn2L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tM8v7Rko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QKG5MVMG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YayXWn2L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_us73g4Xp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZSefXPO6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Z7mDGayM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0K5C54Lt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZSefXPO6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Z7mDGayM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FjfIEh8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vRvc0N15_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MmvFvwX8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_adtKDczz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vRvc0N15_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MmvFvwX8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xM6mxLyA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_tM8v7Rko_sendMessage(_c, 0, m);
  cMsg_0K5C54Lt_sendMessage(_c, 0, m);
  cMsg_adtKDczz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1e1eeY5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_tM8v7Rko_sendMessage(_c, 0, m);
  cMsg_us73g4Xp_sendMessage(_c, 0, m);
  cMsg_FjfIEh8J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PVXwZcI7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_x8RiKucA_sendMessage(_c, 0, m);
  cMsg_0K5C54Lt_sendMessage(_c, 0, m);
  cMsg_FjfIEh8J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UYLrAcoz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JdbgkcMo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_u82ZUmS8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Lw7Ui9FR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JdbgkcMo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_u82ZUmS8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ca4aeRTu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_73Sh5cte_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_R54ILsfH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EgckwdyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_73Sh5cte_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_R54ILsfH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_y1sGZctq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LMbVbjlA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_P4oZZyJz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Hszho8nR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LMbVbjlA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_P4oZZyJz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gwnk2mXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_UYLrAcoz_sendMessage(_c, 0, m);
  cMsg_EgckwdyV_sendMessage(_c, 0, m);
  cMsg_Hszho8nR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UNBaLU6z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_Lw7Ui9FR_sendMessage(_c, 0, m);
  cMsg_ca4aeRTu_sendMessage(_c, 0, m);
  cMsg_Hszho8nR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rEbLSIMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_Lw7Ui9FR_sendMessage(_c, 0, m);
  cMsg_EgckwdyV_sendMessage(_c, 0, m);
  cMsg_y1sGZctq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_0qACF6Mx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_B3NA8Wsf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7r7WKNVj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cW2qfZQp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_B3NA8Wsf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7r7WKNVj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PdGUhXob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wVRwd2Nq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qtKXsjoL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mzFEnJch_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wVRwd2Nq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qtKXsjoL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_faDwkV7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_u2qKXiU5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rYrPZnku_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LhOqCUWj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_u2qKXiU5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rYrPZnku_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kV0ivrF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_cW2qfZQp_sendMessage(_c, 0, m);
  cMsg_mzFEnJch_sendMessage(_c, 0, m);
  cMsg_LhOqCUWj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HvdViUXK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_cW2qfZQp_sendMessage(_c, 0, m);
  cMsg_PdGUhXob_sendMessage(_c, 0, m);
  cMsg_faDwkV7d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cQjkowA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_0qACF6Mx_sendMessage(_c, 0, m);
  cMsg_PdGUhXob_sendMessage(_c, 0, m);
  cMsg_LhOqCUWj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CrfmZ1XQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_x8RiKucA_sendMessage(_c, 0, m);
  cMsg_us73g4Xp_sendMessage(_c, 0, m);
  cMsg_adtKDczz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_J2jx1jtQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_0qACF6Mx_sendMessage(_c, 0, m);
  cMsg_mzFEnJch_sendMessage(_c, 0, m);
  cMsg_faDwkV7d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_96oSfx34_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QAqJhNSj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Qa4cAJvv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rMUcBrVz, 0, m, &cSlice_rMUcBrVz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_VL0xJTUv_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_rMUcBrVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iHyGiwoK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iHyGiwoK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_wgexMyrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iHyGiwoK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_iHyGiwoK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ih1wvV0L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_i083PWmB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_SuK4eRiC, 0, m, &cSlice_SuK4eRiC_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Nm5LG6Mq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_SuK4eRiC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5FeYiabk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5FeYiabk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_pBUc2bq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5FeYiabk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_5FeYiabk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YOEzzOjU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Nm5LG6Mq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_o0wdI9cm, 0, m, &cSlice_o0wdI9cm_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Qa4cAJvv_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_o0wdI9cm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Q9L8OwAH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Q9L8OwAH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_vCWBhLXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Q9L8OwAH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Q9L8OwAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_i6Pv9k4w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VL0xJTUv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_U25P3KnY, 0, m, &cSlice_U25P3KnY_sendMessage);
      break;
    }
    default: {
      cSwitchcase_khPqlq7B_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_U25P3KnY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mW9r4Acu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mW9r4Acu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_NRnEHJgw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mW9r4Acu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_mW9r4Acu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eQICMYu4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_khPqlq7B_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_YPlTRjkP, 0, m, &cSlice_YPlTRjkP_sendMessage);
      break;
    }
    default: {
      cSwitchcase_F8RClUqA_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_YPlTRjkP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Vhev9EZv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Vhev9EZv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_IuMJMf3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Vhev9EZv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Vhev9EZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3dLAqCJD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_INETNFdt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_fdRM4xvV_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_fdRM4xvV_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_aBhtEcID, 1, m, &cDelay_aBhtEcID_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X8iAf6f8_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_aBhtEcID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_aBhtEcID, m);
  cMsg_BlS3Qcl2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fdRM4xvV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_aBhtEcID, 0, m, &cDelay_aBhtEcID_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_X8iAf6f8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_aBhtEcID, 0, m, &cDelay_aBhtEcID_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_ONpmbR0p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qYv6mFiJ, HV_BINOP_SUBTRACT, 0, m, &cBinop_qYv6mFiJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_LQRszp61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MbKAQhoU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_NZ9B8Lor_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MbKAQhoU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_8f1avqgT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ONpmbR0p, 0, m, &cVar_ONpmbR0p_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_3yVDvi4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CjDNvdkx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LyHOpwLK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jhRprQwY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qYv6mFiJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uoo1XYTh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_uoo1XYTh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_DFgN0o8f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DFgN0o8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_BCncDRKh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2809Enkw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nf4f6Ide_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GeYRsHgQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nf4f6Ide_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LQRszp61, 1, m, &cIf_LQRszp61_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GeYRsHgQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GIibC8UJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_cthkaOFb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NZ9B8Lor, 1, m, &cIf_NZ9B8Lor_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GIibC8UJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_LQRszp61, 0, m, &cIf_LQRszp61_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BCncDRKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NZ9B8Lor, 0, m, &cIf_NZ9B8Lor_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jhRprQwY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ONpmbR0p, 0, m, &cVar_ONpmbR0p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LyHOpwLK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qYv6mFiJ, HV_BINOP_SUBTRACT, 1, m, &cBinop_qYv6mFiJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CjDNvdkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cMsg_MbKAQhoU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_og82AA46, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_F8RClUqA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zvUFakAW, 0, m, &cSlice_zvUFakAW_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_zvUFakAW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ORF4mBbB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ORF4mBbB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ETMXhUfZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ORF4mBbB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ORF4mBbB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eFiYCYAi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hgU94Ftf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RVRUWJHD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GsaLGRiJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vdvYze1w, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_JWuRIcZn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LHoN6Nzm, 0, m, &cVar_LHoN6Nzm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QAqJhNSj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mnjDtk55, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_pPYtMkIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1lGWqdcl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_CqPSpdvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_INETNFdt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_BlS3Qcl2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_taIMuE9M, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1lGWqdcl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_taIMuE9M, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0J7GaLhx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_eCUCu7yL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eCUCu7yL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DrFMSM2m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DrFMSM2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5VbNkyxm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_p70SBIlx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wy7AVheK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_7cVLz8hg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iAIbPDhd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_wE1xsWBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gG5RyDyL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qBXvDANe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_q8Do4SS9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3ZBl5JV6_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qr1uHgyW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_X6ose1vt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_q8Do4SS9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3ZBl5JV6_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qr1uHgyW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_38reZRA2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_R8qXHQe8, 0, m, &cVar_R8qXHQe8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ozlSPrhv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_q8Do4SS9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3ZBl5JV6_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qr1uHgyW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Hzq95p0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_q8Do4SS9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3ZBl5JV6_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qr1uHgyW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GBlxfUWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_q8Do4SS9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3ZBl5JV6_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qr1uHgyW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jyxhvDqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_89xigxCj, 0, m, &cVar_89xigxCj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pMpjZ31w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_SL6sz9Mq, 0, m, &cVar_SL6sz9Mq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xaCnMqpF, 0, m, &cVar_xaCnMqpF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7BAcLdpS, 0, m, &cVar_7BAcLdpS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5fo4RIE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_38reZRA2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SQxFatgR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8CYaxN28_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_uN8bRyfc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_k4uSoH2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8CYaxN28_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_uN8bRyfc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UY4QWFmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8CYaxN28_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_uN8bRyfc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MXCTmEge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8CYaxN28_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_uN8bRyfc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_CcX9iZFH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8CYaxN28_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_uN8bRyfc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UuRLb6kK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_wdDAUY0w, 0, m, &cVar_wdDAUY0w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NBW58gJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_M9v6ODGO, 0, m, &cVar_M9v6ODGO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ny9HVUUZ, 0, m, &cVar_Ny9HVUUZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RU4YGpXb, 0, m, &cVar_RU4YGpXb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4NpKDgX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_q8Do4SS9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3ZBl5JV6_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qr1uHgyW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_je6aOhHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_D8MfxHHf_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_plvIfVL8_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_anjOgIOV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_QL1jVx2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_D8MfxHHf_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_plvIfVL8_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_anjOgIOV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_soi9EmWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4vYs3sgm, 0, m, &cVar_4vYs3sgm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wZ1omQXU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_D8MfxHHf_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_plvIfVL8_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_anjOgIOV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_t3h2a8qZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_D8MfxHHf_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_plvIfVL8_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_anjOgIOV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_O1MmdxWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_D8MfxHHf_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_plvIfVL8_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_anjOgIOV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_eLr0Enyh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_1b1izjbN, 0, m, &cVar_1b1izjbN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EIOMYN34_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_37qgh3tE, 0, m, &cVar_37qgh3tE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CXrLt3K3, 0, m, &cVar_CXrLt3K3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_S1bDL9D9, 0, m, &cVar_S1bDL9D9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_655g45ml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_soi9EmWk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qlaG7msk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_D8MfxHHf_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_plvIfVL8_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_anjOgIOV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_SXBZnlYl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_9m5TSO0S_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zrKNePD5_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_i083PWmB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_f2ZmN9zk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_9m5TSO0S_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zrKNePD5_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_i083PWmB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_n24QnWWm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ssmrCi7R, 0, m, &cVar_ssmrCi7R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JtB8O5OR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_9m5TSO0S_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zrKNePD5_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_i083PWmB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_QVqRRrpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_9m5TSO0S_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zrKNePD5_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_i083PWmB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qGH3yDOo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_9m5TSO0S_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zrKNePD5_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_i083PWmB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FZwtPYP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_EzngAcBT, 0, m, &cVar_EzngAcBT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PRxJoJt6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_rJiZbPL8, 0, m, &cVar_rJiZbPL8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xLMaQRlq, 0, m, &cVar_xLMaQRlq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_H7YYhhbd, 0, m, &cVar_H7YYhhbd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oM2AU6IH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_n24QnWWm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Gt7wVoDw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_9m5TSO0S_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zrKNePD5_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_i083PWmB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_k6rnj8q3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_p70SBIlx, 0, m, &cVar_p70SBIlx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wy7AVheK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_q8Do4SS9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3ZBl5JV6_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qr1uHgyW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_uqfmD2RZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_7cVLz8hg, 0, m, &cVar_7cVLz8hg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iAIbPDhd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_D8MfxHHf_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_plvIfVL8_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_anjOgIOV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tfEf5cV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_wE1xsWBq, 0, m, &cVar_wE1xsWBq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gG5RyDyL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_9m5TSO0S_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zrKNePD5_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_i083PWmB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cReceive_mFcz6ojY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v6NlPGKG_sendMessage(_c, 0, m);
  cMsg_6m1qqO0g_sendMessage(_c, 0, m);
  cMsg_DsQ2wkv1_sendMessage(_c, 0, m);
  cMsg_CxkKkoyD_sendMessage(_c, 0, m);
  cMsg_mYdMdTxt_sendMessage(_c, 0, m);
  cMsg_6Eyzktm7_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_z2GjQlOk, 0, m, &cVar_z2GjQlOk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kNDIs2Z0, 0, m, &cVar_kNDIs2Z0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5ekJyMZj, 0, m, &cVar_5ekJyMZj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_m5QIIEOT, 0, m, &cVar_m5QIIEOT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OQt5KIut, 0, m, &cVar_OQt5KIut_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TfvSA2ap, 0, m, &cVar_TfvSA2ap_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SvEk1LI5, 0, m, &cVar_SvEk1LI5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jPUxejQv, 0, m, &cVar_jPUxejQv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kDbbFr4f, 0, m, &cVar_kDbbFr4f_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5lC35tQS, 0, m, &cVar_5lC35tQS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GC8oryyf, 0, m, &cVar_GC8oryyf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_K8UkPzvz, 0, m, &cVar_K8UkPzvz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_43rYHGgW, 0, m, &cVar_43rYHGgW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PLm8e3DC, 0, m, &cVar_PLm8e3DC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gmf0TLna, 0, m, &cVar_gmf0TLna_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9WzftSxC, 0, m, &cVar_9WzftSxC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5jMJRe0K, 0, m, &cVar_5jMJRe0K_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EwoexLan, 0, m, &cVar_EwoexLan_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SlVLMLcm, 0, m, &cVar_SlVLMLcm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qvA2Ym9i, 0, m, &cVar_qvA2Ym9i_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BmlEsJW6, 0, m, &cVar_BmlEsJW6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PKmnfQe6, 0, m, &cVar_PKmnfQe6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6ZkPzM0h, 0, m, &cVar_6ZkPzM0h_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZQtB3Ew7, 0, m, &cVar_ZQtB3Ew7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DPTqLjM0, 0, m, &cVar_DPTqLjM0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UJL2xvOS, 0, m, &cVar_UJL2xvOS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3oXlIRtK, 0, m, &cVar_3oXlIRtK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Y2UjyjbT, 0, m, &cVar_Y2UjyjbT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_b1hWPlHw, 0, m, &cVar_b1hWPlHw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_B4txDtRf, 0, m, &cVar_B4txDtRf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ut6ezehq, 0, m, &cVar_ut6ezehq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GhguSBPK, 0, m, &cVar_GhguSBPK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Xw1NMszm, 0, m, &cVar_Xw1NMszm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mZ0IUyaN, 0, m, &cVar_mZ0IUyaN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QdjnaHYn, 0, m, &cVar_QdjnaHYn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_89Extq2M, 0, m, &cVar_89Extq2M_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sK2BnpgX, 0, m, &cVar_sK2BnpgX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_k7lxzujy, 0, m, &cVar_k7lxzujy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AqlxfQ2v, 0, m, &cVar_AqlxfQ2v_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RswpCNxH, 0, m, &cVar_RswpCNxH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Q6uauMKE, 0, m, &cVar_Q6uauMKE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GMv7EP9j, 0, m, &cVar_GMv7EP9j_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_A3iZxPgG, 0, m, &cVar_A3iZxPgG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aDptkESi, 0, m, &cVar_aDptkESi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_M68YG6YU, 0, m, &cVar_M68YG6YU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EAb2FUNH, 0, m, &cVar_EAb2FUNH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qRl5n9Au, 0, m, &cVar_qRl5n9Au_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vcGjWvE9, 0, m, &cVar_vcGjWvE9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fWPO9Zcq, 0, m, &cVar_fWPO9Zcq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CqtW1KH5, 0, m, &cVar_CqtW1KH5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xthLHeVv, 0, m, &cVar_xthLHeVv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Dty4I6eG, 0, m, &cVar_Dty4I6eG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wgexMyrp, 0, m, &cVar_wgexMyrp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pBUc2bq4, 0, m, &cVar_pBUc2bq4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vCWBhLXC, 0, m, &cVar_vCWBhLXC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NRnEHJgw, 0, m, &cVar_NRnEHJgw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IuMJMf3C, 0, m, &cVar_IuMJMf3C_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ETMXhUfZ, 0, m, &cVar_ETMXhUfZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MHIXNa7B, 0, m, &cVar_MHIXNa7B_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uZfWnhLL, 0, m, &cVar_uZfWnhLL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_c5cixGjW, 0, m, &cVar_c5cixGjW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_waIt9klw_sendMessage);
  cMsg_NBW58gJj_sendMessage(_c, 0, m);
  cMsg_UuRLb6kK_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wjDebRB9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9Pfu6ylV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_SOrkKYDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_M9v6ODGO, 0, m, &cVar_M9v6ODGO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ZZPaJLDC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ny9HVUUZ, 0, m, &cVar_Ny9HVUUZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_FmXMyqFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RU4YGpXb, 0, m, &cVar_RU4YGpXb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_O6yhNEJ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kNDIs2Z0, 0, m, &cVar_kNDIs2Z0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_z81Bmxsk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AguxaNK1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GDOmYYEu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_9QKff6Kq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1wHWUyuF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SC3parWM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CZLUEqit_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mY4Q0ujk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_yXJkOP8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Vh27m9Ve_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_w0yRB37s_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FS0pMfSI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_28xAH4Rw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_5XUASl8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LuSY2u55_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_o1K48esX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cYZ5YTCa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LU2RQbmt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_l4b60Wmj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IxAKYdhD, HV_BINOP_MULTIPLY, 0, m, &cBinop_IxAKYdhD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_zqHRtZb4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_gNcHAgj2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_kvExouQm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_de7PUpLU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_usL6Ey25_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_aCoH02hm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_tU6DoSkU_sendMessage);
  cMsg_1yadRv3p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_s6k6xeV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ANGlnnqo, HV_BINOP_MULTIPLY, 0, m, &cBinop_ANGlnnqo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_AnHqRhCF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_yD8GyV1d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_CjIYwEVm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nSDZzA8P, HV_BINOP_MULTIPLY, 1, m, &cBinop_nSDZzA8P_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_nzYfYdan_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ZEZCGYfs_sendMessage);
  cMsg_QVq7mZmC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_8zS5jx2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0QtCAJKD, HV_BINOP_MULTIPLY, 0, m, &cBinop_0QtCAJKD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_MfnvP35B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xLgO47e2_sendMessage(_c, 0, m);
  cMsg_w7SPsoHp_sendMessage(_c, 0, m);
  cMsg_oCk91E4X_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_SmcSbkwS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_9l1IvX85_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_y1C9giXp_sendMessage);
  cMsg_9RVmz77M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_kXJzIqrg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OQt5KIut, 0, m, &cVar_OQt5KIut_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_zRnzPACZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Bn6xLna5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5sjrLAHf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_PqWeU9K1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XJO3HlXv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2y5IbO9o_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ncRt3HWI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a3APkwkE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_acfqYKEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9wXbjhxY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FRXFgg90_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RhcrG3Nu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ukT2a0KG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_gUug4hQA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_b0ocfv1T_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pzNeAggx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xjNiErES_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_URkSf2tm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ZbtJdJko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_muUSatnB, HV_BINOP_MULTIPLY, 0, m, &cBinop_muUSatnB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_XoIuqr04_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_kxAHvcB4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_c7MhJmDW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Me8lj254_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_Cc3h49Br_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_7QWAjhfP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_C0XRppMc_sendMessage);
  cMsg_P5I96aAC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_kc8cyPpB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x5o92xjZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_x5o92xjZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_7XLsh0jV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_Zv7vgbZ5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_6R94sZdv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3DQVrbOV, HV_BINOP_MULTIPLY, 1, m, &cBinop_3DQVrbOV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_tX3BWVll_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_rI9y9WPR_sendMessage);
  cMsg_XzUzVdr7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_BIxIhYJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZxPdzIqD, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZxPdzIqD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_4YdrVs0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nLMrEUZ7_sendMessage(_c, 0, m);
  cMsg_guGUTZZA_sendMessage(_c, 0, m);
  cMsg_NgDAPdLE_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_klaWFjvX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_u4F1FbnW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_PwymIl0g_sendMessage);
  cMsg_SwyiXCIs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_RnBbH3zv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wdDAUY0w, 0, m, &cVar_wdDAUY0w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_l4ZwBHpe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uaOiGexE, 0, m, &cVar_uaOiGexE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_AvnYv4Ll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_89xigxCj, 0, m, &cVar_89xigxCj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_eIx9RhR4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SL6sz9Mq, 0, m, &cVar_SL6sz9Mq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_0lrPzH6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xaCnMqpF, 0, m, &cVar_xaCnMqpF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_u21uJmKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7BAcLdpS, 0, m, &cVar_7BAcLdpS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_f15D44n5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_38reZRA2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_9KOikjFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_zygpFREP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_K2LH9HzP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wf3A4o9W, 0, m, &cVar_wf3A4o9W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_fuoi1YRY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sAXos1MU, 0, m, &cVar_sAXos1MU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_0pehrk0N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_XTUG5e9q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_6nHpzl0M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3lBHkwdV_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3Nq0rEJl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fHotjAvh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_eaVLVjuJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4qIPJiXb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Fe8hk6ld_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_fRiQRLPQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C73NySOP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_bevtRcdk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ThAFaZXZ, 0, m, &cVar_ThAFaZXZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_GpMgF3hL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_R78HaHSf, 0, m, &cVar_R78HaHSf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_0j5uDFQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_6YhbVF1S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Cq3rGCJX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Z4ZQw9TF_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NTVaUmPm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VzvgExqj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_d60GcozU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CYSinyqG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_NPyVOOlZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_DOGCPpbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f5OJ2gZu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_ASarWlO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_xnA1oeSg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_1hOQenee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9vASn72u, 0, m, &cVar_9vASn72u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_8zJOMTzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_M6z8ZRie, 0, m, &cVar_M6z8ZRie_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_sXCogLd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_Mz10C3vx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_FHqYuD0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_j4S75I40_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZJj3VYNw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wyqSa4w1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_cJ62b9Q2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OkFZDZfw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7xU7xbIa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_gUv0K9QM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wbHEwG91_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_eAHCJYCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cVr9n9kR, 0, m, &cVar_cVr9n9kR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_rJkJybnt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AEroAmfE, 0, m, &cVar_AEroAmfE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_1ojaMLFz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_KrinGi96_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_IRDdowG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3tyXLC1n_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aEW0aM2q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ipFxqo0I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_uzr7DWF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PQbqtnVr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pfe3n8vu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_yJt7isjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HpNvfScr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_6ieeNXSq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Buxx3Lq9, 0, m, &cVar_Buxx3Lq9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_UQaHPA8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1b1izjbN, 0, m, &cVar_1b1izjbN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_FhVVj21u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_37qgh3tE, 0, m, &cVar_37qgh3tE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_gDzU5Mrk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CXrLt3K3, 0, m, &cVar_CXrLt3K3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_pvN6zDsV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_S1bDL9D9, 0, m, &cVar_S1bDL9D9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_2F4AdxTg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_soi9EmWk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ubvayiq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_dxSLXUU9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_hZo3JHq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fB8c7l4h, 0, m, &cVar_fB8c7l4h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_vMeMo5wP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lF8GeV1P, 0, m, &cVar_lF8GeV1P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_vruNnkpQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_Rv4Qk0S1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_HY6lASBk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_oxzOrAOz_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_I9skuXV7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1v0I1A8U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_jYwxN8sZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eRVfTt0P_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RBvyMmUs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_TCJ5bAE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Wdzl0tUu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_Ih1wvV0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hyeZcgLq, 0, m, &cVar_hyeZcgLq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_eQICMYu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_96oSfx34, 0, m, &cVar_96oSfx34_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_i6Pv9k4w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_JWuRIcZn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_YOEzzOjU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_rOAPPJhu_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pPYtMkIv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CqPSpdvP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_3dLAqCJD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2809Enkw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cthkaOFb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_eFiYCYAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0J7GaLhx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_9B1T2ND4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_m3YFGIVZ, 0, m, &cVar_m3YFGIVZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_AxAwUI06_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EzngAcBT, 0, m, &cVar_EzngAcBT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Ls2b0IYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rJiZbPL8, 0, m, &cVar_rJiZbPL8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_fjtjBakp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xLMaQRlq, 0, m, &cVar_xLMaQRlq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Gocm9jIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_H7YYhhbd, 0, m, &cVar_H7YYhhbd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_dpXGaN3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_n24QnWWm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_pqM1djyS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_p70SBIlx, 0, m, &cVar_p70SBIlx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_4pmwWUOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7cVLz8hg, 0, m, &cVar_7cVLz8hg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_YKRnJugf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wE1xsWBq, 0, m, &cVar_wE1xsWBq_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_M3NGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14, Bf15, Bf16, Bf17, Bf18, Bf19, Bf20;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_G6kJ5DnP, VOf(Bf0));
    __hv_line_f(&sLine_rWKxEhfB, VOf(Bf1));
    __hv_line_f(&sLine_b8VW2dOA, VOf(Bf2));
    __hv_line_f(&sLine_Ya9Dn5ZW, VOf(Bf3));
    __hv_line_f(&sLine_Pqzo76Lg, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_XFrOSmsz, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_XzosgNlC, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_M1I2rTgA, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_RiHHQ1Md, VOf(Bf1));
    __hv_line_f(&sLine_kqqy7VH6, VOf(Bf0));
    __hv_line_f(&sLine_hUk0yMz1, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_a9JugEwC, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_rA9zCPq8, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_KfVxMb66, VOf(Bf5));
    __hv_line_f(&sLine_BbYzWumJ, VOf(Bf1));
    __hv_line_f(&sLine_BEr3sgs7, VOf(Bf2));
    __hv_line_f(&sLine_ljfGrcXn, VOf(Bf4));
    __hv_line_f(&sLine_06FLLY0q, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_Jl43dUZw, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_7oqWfbFB, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_6ja6DLGB, VOf(Bf6));
    __hv_line_f(&sLine_Qn1vCEWR, VOf(Bf2));
    __hv_line_f(&sLine_YmJDT9yK, VOf(Bf1));
    __hv_line_f(&sLine_CmXn1URJ, VOf(Bf5));
    __hv_line_f(&sLine_02OM5bGf, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_HCaRTbpV, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_6YZNnS84, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_o5oEcyxJ, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_6P2Bccjt, VOf(Bf2));
    __hv_line_f(&sLine_ITnFN1Bt, VOf(Bf6));
    __hv_line_f(&sLine_tR03KMGo, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_LYOe2IVu, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_uNyIGWRH, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_GGl2P8q0, VOf(Bf8));
    __hv_line_f(&sLine_hfK5BTgm, VOf(Bf2));
    __hv_line_f(&sLine_Oalunc8c, VOf(Bf1));
    __hv_line_f(&sLine_g88EbpX3, VOf(Bf7));
    __hv_line_f(&sLine_fPKr2ko1, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_a35pTx21, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_MRkwWgNC, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_5EFCX5AA, VIf(Bf0));
    __hv_varwrite_f(&sVarf_Q8D1ucGp, VIf(Bf6));
    __hv_varwrite_f(&sVarf_miupiRXD, VIf(Bf4));
    __hv_varwrite_f(&sVarf_DrC8HhQl, VIf(Bf7));
    __hv_varread_f(&sVarf_Mq9bmeOE, VOf(Bf7));
    __hv_varread_f(&sVarf_YUiYeO2G, VOf(Bf4));
    __hv_varread_f(&sVarf_f6Qq7MpA, VOf(Bf6));
    __hv_varread_f(&sVarf_VpmnnU1F, VOf(Bf0));
    __hv_varread_f(&sVarf_kFgHcz6K, VOf(Bf9));
    __hv_varread_f(&sVarf_eBfmncSs, VOf(Bf1));
    __hv_line_f(&sLine_MgYClfBv, VOf(Bf2));
    __hv_line_f(&sLine_k5QcbYdf, VOf(Bf8));
    __hv_mul_f(VIf(Bf0), VIf(Bf8), VOf(Bf0));
    __hv_fma_f(VIf(Bf6), VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varwrite_f(&sVarf_f6Qq7MpA, VIf(Bf7));
    __hv_varwrite_f(&sVarf_kFgHcz6K, VIf(Bf4));
    __hv_varread_f(&sVarf_R4AvlNSG, VOf(Bf2));
    __hv_varread_f(&sVarf_6yuPbTJU, VOf(Bf9));
    __hv_varread_f(&sVarf_LjU2oEWJ, VOf(Bf1));
    __hv_varread_f(&sVarf_79Uqnye2, VOf(Bf6));
    __hv_varread_f(&sVarf_TOpbGLwh, VOf(Bf10));
    __hv_varread_f(&sVarf_0UcxhDL8, VOf(Bf11));
    __hv_varread_f(&sVarf_40hBbHiH, VOf(Bf12));
    __hv_varwrite_f(&sVarf_48VspDVH, VIf(Bf7));
    __hv_varread_f(&sVarf_Ec3TIhOB, VOf(Bf13));
    __hv_line_f(&sLine_1duFCYvx, VOf(Bf14));
    __hv_mul_f(VIf(Bf13), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_fKffY5aL, VOf(Bf15));
    __hv_line_f(&sLine_jIC9Pqu1, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_wE4vNsWz, VOf(Bf14));
    __hv_line_f(&sLine_M5W5fIjK, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_79Uqnye2, VIf(Bf17));
    __hv_varread_f(&sVarf_48VspDVH, VOf(Bf17));
    __hv_line_f(&sLine_NbQGWOIy, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_T6iqH1Dj, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_jyOmKENv, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_TOpbGLwh, VIf(Bf16));
    __hv_line_f(&sLine_6mDp8joA, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_CkaVCiCz, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_g1PHdxfQ, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_0UcxhDL8, VIf(Bf16));
    __hv_line_f(&sLine_P4DxNeie, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_JRFySmqY, VOf(Bf17));
    __hv_mul_f(VIf(Bf15), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_73ao6fc2, VOf(Bf16));
    __hv_mul_f(VIf(Bf13), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_40hBbHiH, VIf(Bf16));
    __hv_varwrite_f(&sVarf_Ec3TIhOB, VIf(Bf2));
    __hv_varwrite_f(&sVarf_fKffY5aL, VIf(Bf9));
    __hv_varwrite_f(&sVarf_wE4vNsWz, VIf(Bf1));
    sEnv_process(this, &sEnv_5qKe5h8N, VIf(Bf6), &sEnv_5qKe5h8N_sendMessage);
    sEnv_process(this, &sEnv_xxgWipqJ, VIf(Bf7), &sEnv_xxgWipqJ_sendMessage);
    __hv_line_f(&sLine_SNYQFNYb, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_zVg5tvTx, VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_DwBPjfyo, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_H9OJQ2uV, VOf(Bf6));
    __hv_line_f(&sLine_VL1XDnDV, VOf(Bf1));
    __hv_var_k_f(VOf(Bf9), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_R4AvlNSG, VIf(Bf9));
    __hv_varwrite_f(&sVarf_H9OJQ2uV, VIf(Bf10));
    __hv_varwrite_f(&sVarf_bUZrL0dY, VIf(Bf11));
    __hv_varwrite_f(&sVarf_hxrERQye, VIf(Bf12));
    __hv_varread_f(&sVarf_hxrERQye, VOf(Bf12));
    __hv_line_f(&sLine_DufrcJW8, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf11), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf9));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf12), VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_LjU2oEWJ, VIf(Bf10));
    __hv_varread_f(&sVarf_bUZrL0dY, VOf(Bf10));
    __hv_line_f(&sLine_FZaJMQYo, VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf9));
    __hv_sub_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_neg_f(VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_6yuPbTJU, VIf(Bf10));
    __hv_varwrite_f(&sVarf_VpmnnU1F, VIf(Bf7));
    __hv_varread_f(&sVarf_21iT8sdT, VOf(Bf7));
    __hv_varread_f(&sVarf_1ot7MoZK, VOf(Bf10));
    __hv_varread_f(&sVarf_2PNZFZg5, VOf(Bf9));
    __hv_varread_f(&sVarf_dLxraHRx, VOf(Bf11));
    __hv_varread_f(&sVarf_ystYRzdd, VOf(Bf6));
    __hv_varread_f(&sVarf_YzXeD19K, VOf(Bf12));
    __hv_varread_f(&sVarf_qPxdR0wV, VOf(Bf1));
    __hv_varwrite_f(&sVarf_yW081x8v, VIf(Bf4));
    __hv_varread_f(&sVarf_BP4Dgys3, VOf(Bf2));
    __hv_line_f(&sLine_jDRStYAR, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_voph3RId, VOf(Bf17));
    __hv_line_f(&sLine_LlIvTlov, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_varread_f(&sVarf_aGVkLjwM, VOf(Bf16));
    __hv_line_f(&sLine_r8lpIm0g, VOf(Bf15));
    __hv_mul_f(VIf(Bf16), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_dLxraHRx, VIf(Bf15));
    __hv_varread_f(&sVarf_yW081x8v, VOf(Bf15));
    __hv_line_f(&sLine_pKleR778, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_61CQDJRQ, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_nMoDIXtv, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_ystYRzdd, VIf(Bf13));
    __hv_line_f(&sLine_yU6rar4v, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_Ve6czca2, VOf(Bf18));
    __hv_mul_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_xkO4WGPp, VOf(Bf13));
    __hv_mul_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_YzXeD19K, VIf(Bf13));
    __hv_line_f(&sLine_e5AhCPL1, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_lIAr0GaR, VOf(Bf15));
    __hv_mul_f(VIf(Bf17), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_line_f(&sLine_Y0q5Nles, VOf(Bf13));
    __hv_mul_f(VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_qPxdR0wV, VIf(Bf13));
    __hv_varwrite_f(&sVarf_BP4Dgys3, VIf(Bf7));
    __hv_varwrite_f(&sVarf_voph3RId, VIf(Bf10));
    __hv_varwrite_f(&sVarf_aGVkLjwM, VIf(Bf9));
    sEnv_process(this, &sEnv_RzaS4zhU, VIf(Bf11), &sEnv_RzaS4zhU_sendMessage);
    sEnv_process(this, &sEnv_dqvPljUk, VIf(Bf4), &sEnv_dqvPljUk_sendMessage);
    __hv_line_f(&sLine_ohrFgE5d, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_Bi8R9FFN, VOf(Bf11));
    __hv_mul_f(VIf(Bf4), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_7BNmHqdj, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_6GTswFQP, VOf(Bf11));
    __hv_line_f(&sLine_JJiGPZGw, VOf(Bf9));
    __hv_var_k_f(VOf(Bf10), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_floor_f(VIf(Bf9), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_div_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_21iT8sdT, VIf(Bf10));
    __hv_varwrite_f(&sVarf_6GTswFQP, VIf(Bf6));
    __hv_varwrite_f(&sVarf_nOS89Tl4, VIf(Bf12));
    __hv_varwrite_f(&sVarf_xbqf4jLx, VIf(Bf1));
    __hv_varread_f(&sVarf_xbqf4jLx, VOf(Bf1));
    __hv_line_f(&sLine_vKrXbYc9, VOf(Bf12));
    __hv_mul_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf12), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf12), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf12), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_2PNZFZg5, VIf(Bf6));
    __hv_varread_f(&sVarf_nOS89Tl4, VOf(Bf6));
    __hv_line_f(&sLine_cgDhbUkZ, VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf10));
    __hv_sub_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_abs_f(VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf12), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_1ot7MoZK, VIf(Bf6));
    __hv_varwrite_f(&sVarf_eBfmncSs, VIf(Bf4));
    __hv_varwrite_f(&sVarf_JEA2j0g7, VIf(Bf0));
    __hv_varread_f(&sVarf_5EFCX5AA, VOf(Bf0));
    __hv_varread_f(&sVarf_Q8D1ucGp, VOf(Bf4));
    __hv_varread_f(&sVarf_w7nhLI5I, VOf(Bf6));
    __hv_varread_f(&sVarf_Phhd5oMH, VOf(Bf10));
    __hv_varread_f(&sVarf_V4xYawvO, VOf(Bf12));
    __hv_varread_f(&sVarf_gdbzAEJW, VOf(Bf11));
    __hv_line_f(&sLine_f5jL3IbU, VOf(Bf1));
    __hv_line_f(&sLine_EpIjTFRv, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf10));
    __hv_fma_f(VIf(Bf6), VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_w7nhLI5I, VIf(Bf0));
    __hv_varwrite_f(&sVarf_V4xYawvO, VIf(Bf4));
    __hv_varread_f(&sVarf_xkJxL5Bb, VOf(Bf1));
    __hv_varread_f(&sVarf_Jx7YOPRd, VOf(Bf12));
    __hv_varread_f(&sVarf_gG4eQjnC, VOf(Bf11));
    __hv_varread_f(&sVarf_20H6qoPw, VOf(Bf6));
    __hv_varread_f(&sVarf_dawSvtgN, VOf(Bf7));
    __hv_varread_f(&sVarf_Rb0ziSsZ, VOf(Bf13));
    __hv_varread_f(&sVarf_ho7IVEcR, VOf(Bf15));
    __hv_varwrite_f(&sVarf_9ayv7ARl, VIf(Bf0));
    __hv_varread_f(&sVarf_sgPLyfGq, VOf(Bf2));
    __hv_line_f(&sLine_xy9GuJlN, VOf(Bf17));
    __hv_mul_f(VIf(Bf2), VIf(Bf17), VOf(Bf17));
    __hv_varread_f(&sVarf_lJ4Zp2HV, VOf(Bf18));
    __hv_line_f(&sLine_lCQXAjsh, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_zlO9z2Ll, VOf(Bf17));
    __hv_line_f(&sLine_uB1UgHEo, VOf(Bf14));
    __hv_mul_f(VIf(Bf17), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_varwrite_f(&sVarf_20H6qoPw, VIf(Bf14));
    __hv_varread_f(&sVarf_9ayv7ARl, VOf(Bf14));
    __hv_line_f(&sLine_B4NZkZei, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_kJfc9N4s, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_RN25Zkbz, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_dawSvtgN, VIf(Bf16));
    __hv_line_f(&sLine_F60gITTo, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_BGvyY5H4, VOf(Bf19));
    __hv_mul_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_2WIlVDv2, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_Rb0ziSsZ, VIf(Bf16));
    __hv_line_f(&sLine_8qCq5oOW, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_hTFqpdxE, VOf(Bf14));
    __hv_mul_f(VIf(Bf18), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_line_f(&sLine_q8eu8BwN, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_ho7IVEcR, VIf(Bf16));
    __hv_varwrite_f(&sVarf_sgPLyfGq, VIf(Bf1));
    __hv_varwrite_f(&sVarf_lJ4Zp2HV, VIf(Bf12));
    __hv_varwrite_f(&sVarf_zlO9z2Ll, VIf(Bf11));
    sEnv_process(this, &sEnv_L5B6lpDQ, VIf(Bf6), &sEnv_L5B6lpDQ_sendMessage);
    sEnv_process(this, &sEnv_YIhbZgr6, VIf(Bf0), &sEnv_YIhbZgr6_sendMessage);
    __hv_line_f(&sLine_y9XjP1JQ, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_v6RFhU6r, VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_qRiFl8KR, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_n8cX84MZ, VOf(Bf6));
    __hv_line_f(&sLine_UhINNUs7, VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_xkJxL5Bb, VIf(Bf12));
    __hv_varwrite_f(&sVarf_n8cX84MZ, VIf(Bf7));
    __hv_varwrite_f(&sVarf_0CYnwvKA, VIf(Bf13));
    __hv_varwrite_f(&sVarf_fM88vnz2, VIf(Bf15));
    __hv_varread_f(&sVarf_fM88vnz2, VOf(Bf15));
    __hv_line_f(&sLine_E7uvkJFq, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf13), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf15), VIf(Bf7), VOf(Bf12));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf15), VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_gG4eQjnC, VIf(Bf7));
    __hv_varread_f(&sVarf_0CYnwvKA, VOf(Bf7));
    __hv_line_f(&sLine_m7WYll2C, VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf7), VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf12));
    __hv_sub_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_abs_f(VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf13), VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_neg_f(VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_Jx7YOPRd, VIf(Bf7));
    __hv_varwrite_f(&sVarf_Phhd5oMH, VIf(Bf0));
    __hv_varread_f(&sVarf_hRPUUGmX, VOf(Bf0));
    __hv_varread_f(&sVarf_LdYTNF1D, VOf(Bf7));
    __hv_varread_f(&sVarf_EMlsGK1c, VOf(Bf12));
    __hv_varread_f(&sVarf_IvSoZWb9, VOf(Bf13));
    __hv_varread_f(&sVarf_Mtmtgu6E, VOf(Bf6));
    __hv_varread_f(&sVarf_ZUWF2rUx, VOf(Bf15));
    __hv_varread_f(&sVarf_hfsggIGd, VOf(Bf11));
    __hv_varwrite_f(&sVarf_VHPswbjZ, VIf(Bf4));
    __hv_varread_f(&sVarf_W66CDLQP, VOf(Bf1));
    __hv_line_f(&sLine_mwSs0Ge4, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_fcRJlSIH, VOf(Bf14));
    __hv_line_f(&sLine_j8U4XpLX, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_2zrugvNQ, VOf(Bf16));
    __hv_line_f(&sLine_kR7Mcgkk, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_varwrite_f(&sVarf_IvSoZWb9, VIf(Bf18));
    __hv_varread_f(&sVarf_VHPswbjZ, VOf(Bf18));
    __hv_line_f(&sLine_50TJhMQ1, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_2VjIK8O9, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_UEIBAxyN, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_Mtmtgu6E, VIf(Bf2));
    __hv_line_f(&sLine_mttfoG52, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_Z3DQkpzP, VOf(Bf19));
    __hv_mul_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_4daaTl5n, VOf(Bf2));
    __hv_mul_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_ZUWF2rUx, VIf(Bf2));
    __hv_line_f(&sLine_ufOR8jSe, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_J5uyPvYh, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_0glMcTB4, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_hfsggIGd, VIf(Bf2));
    __hv_varwrite_f(&sVarf_W66CDLQP, VIf(Bf0));
    __hv_varwrite_f(&sVarf_fcRJlSIH, VIf(Bf7));
    __hv_varwrite_f(&sVarf_2zrugvNQ, VIf(Bf12));
    sEnv_process(this, &sEnv_rnRfn47V, VIf(Bf13), &sEnv_rnRfn47V_sendMessage);
    sEnv_process(this, &sEnv_wyvist55, VIf(Bf4), &sEnv_wyvist55_sendMessage);
    __hv_line_f(&sLine_9HEtgyT2, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_DYD3oFkr, VOf(Bf13));
    __hv_mul_f(VIf(Bf4), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_XlN8478S, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_3iwkJS9M, VOf(Bf13));
    __hv_line_f(&sLine_0cTdnOr6, VOf(Bf12));
    __hv_var_k_f(VOf(Bf7), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf13), VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_div_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_hRPUUGmX, VIf(Bf7));
    __hv_varwrite_f(&sVarf_3iwkJS9M, VIf(Bf6));
    __hv_varwrite_f(&sVarf_fAW78hc9, VIf(Bf15));
    __hv_varwrite_f(&sVarf_icyr69Qd, VIf(Bf11));
    __hv_varread_f(&sVarf_icyr69Qd, VOf(Bf11));
    __hv_line_f(&sLine_ZCxOQ1Fz, VOf(Bf15));
    __hv_mul_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf11), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf15), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf15), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_mul_f(VIf(Bf15), VIf(Bf15), VOf(Bf11));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf11), VIf(Bf6), VOf(Bf7));
    __hv_var_k_f(VOf(Bf13), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf11), VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf15), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_EMlsGK1c, VIf(Bf6));
    __hv_varread_f(&sVarf_fAW78hc9, VOf(Bf6));
    __hv_line_f(&sLine_zmiK1Gvb, VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf7));
    __hv_sub_f(VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_abs_f(VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf15), VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_LdYTNF1D, VIf(Bf6));
    __hv_varwrite_f(&sVarf_gdbzAEJW, VIf(Bf4));
    __hv_varwrite_f(&sVarf_MDOIVzEU, VIf(Bf10));
    __hv_varread_f(&sVarf_miupiRXD, VOf(Bf10));
    __hv_varread_f(&sVarf_DrC8HhQl, VOf(Bf4));
    __hv_varread_f(&sVarf_b4BBPgiu, VOf(Bf6));
    __hv_varread_f(&sVarf_BfvyCdPP, VOf(Bf7));
    __hv_varread_f(&sVarf_ZrXZSjRR, VOf(Bf15));
    __hv_varread_f(&sVarf_71FzrhTo, VOf(Bf13));
    __hv_line_f(&sLine_eJA8JcFk, VOf(Bf11));
    __hv_line_f(&sLine_9AC0HQLq, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf11), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf15), VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_b4BBPgiu, VIf(Bf10));
    __hv_varwrite_f(&sVarf_ZrXZSjRR, VIf(Bf4));
    __hv_varread_f(&sVarf_cDVgJMWS, VOf(Bf11));
    __hv_varread_f(&sVarf_VxY1zPOK, VOf(Bf15));
    __hv_varread_f(&sVarf_ZFtDQOoL, VOf(Bf13));
    __hv_varread_f(&sVarf_k0qHz87i, VOf(Bf6));
    __hv_varread_f(&sVarf_tFs6lBX2, VOf(Bf0));
    __hv_varread_f(&sVarf_CQS1aAV9, VOf(Bf2));
    __hv_varread_f(&sVarf_VKDmcKpi, VOf(Bf18));
    __hv_varwrite_f(&sVarf_6rQApx13, VIf(Bf10));
    __hv_varread_f(&sVarf_zpg7Tb79, VOf(Bf1));
    __hv_line_f(&sLine_wGKFAbvM, VOf(Bf14));
    __hv_mul_f(VIf(Bf1), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_Z7EK7iqV, VOf(Bf19));
    __hv_line_f(&sLine_ZMFtYear, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_83ZZlnLH, VOf(Bf14));
    __hv_line_f(&sLine_9PbNWfXs, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_k0qHz87i, VIf(Bf17));
    __hv_varread_f(&sVarf_6rQApx13, VOf(Bf17));
    __hv_line_f(&sLine_TadTAmQx, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_zsVU29qC, VOf(Bf20));
    __hv_mul_f(VIf(Bf14), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_ZjU2F2Oq, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_tFs6lBX2, VIf(Bf16));
    __hv_line_f(&sLine_uh8mTyiv, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_8LEcWOj7, VOf(Bf20));
    __hv_mul_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_CQAyyN9W, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_CQS1aAV9, VIf(Bf16));
    __hv_line_f(&sLine_4lAFjgeE, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_jlrC4lBc, VOf(Bf17));
    __hv_mul_f(VIf(Bf19), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_avkEH5I6, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_VKDmcKpi, VIf(Bf16));
    __hv_varwrite_f(&sVarf_zpg7Tb79, VIf(Bf11));
    __hv_varwrite_f(&sVarf_Z7EK7iqV, VIf(Bf15));
    __hv_varwrite_f(&sVarf_83ZZlnLH, VIf(Bf13));
    sEnv_process(this, &sEnv_MkNYtrzu, VIf(Bf6), &sEnv_MkNYtrzu_sendMessage);
    sEnv_process(this, &sEnv_ccdQtJRP, VIf(Bf10), &sEnv_ccdQtJRP_sendMessage);
    __hv_line_f(&sLine_y8vhNhW8, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_W7qaelao, VOf(Bf6));
    __hv_mul_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_kQHOZqfc, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_HqUE5cUo, VOf(Bf6));
    __hv_line_f(&sLine_9pYR8xkk, VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_cDVgJMWS, VIf(Bf15));
    __hv_varwrite_f(&sVarf_HqUE5cUo, VIf(Bf0));
    __hv_varwrite_f(&sVarf_BhIQcjQ1, VIf(Bf2));
    __hv_varwrite_f(&sVarf_VK5UHsud, VIf(Bf18));
    __hv_varread_f(&sVarf_VK5UHsud, VOf(Bf18));
    __hv_line_f(&sLine_3G0VnOCE, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf18), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf2), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf18), VIf(Bf0), VOf(Bf15));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf18), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_ZFtDQOoL, VIf(Bf0));
    __hv_varread_f(&sVarf_BhIQcjQ1, VOf(Bf0));
    __hv_line_f(&sLine_0o76B904, VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf0), VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf15));
    __hv_sub_f(VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_VxY1zPOK, VIf(Bf0));
    __hv_varwrite_f(&sVarf_BfvyCdPP, VIf(Bf10));
    __hv_varread_f(&sVarf_Vvy9vpOY, VOf(Bf10));
    __hv_varread_f(&sVarf_wSp2FIZS, VOf(Bf0));
    __hv_varread_f(&sVarf_TOE65W5e, VOf(Bf15));
    __hv_varread_f(&sVarf_Rykha20k, VOf(Bf2));
    __hv_varread_f(&sVarf_lZXEiFs5, VOf(Bf6));
    __hv_varread_f(&sVarf_GbdDfjnv, VOf(Bf18));
    __hv_varread_f(&sVarf_L7wLPwHs, VOf(Bf13));
    __hv_varwrite_f(&sVarf_Bhf2Qulj, VIf(Bf4));
    __hv_varread_f(&sVarf_FRODmhLf, VOf(Bf11));
    __hv_line_f(&sLine_mgDLNC5N, VOf(Bf16));
    __hv_mul_f(VIf(Bf11), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_TLGtazcF, VOf(Bf17));
    __hv_line_f(&sLine_UqVYeDfp, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_YN4ywUSd, VOf(Bf16));
    __hv_line_f(&sLine_auDZnzx9, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_varwrite_f(&sVarf_Rykha20k, VIf(Bf19));
    __hv_varread_f(&sVarf_Bhf2Qulj, VOf(Bf19));
    __hv_line_f(&sLine_Vc1TQR6O, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_2nNyH92V, VOf(Bf20));
    __hv_mul_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_EtUrVCZB, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_lZXEiFs5, VIf(Bf1));
    __hv_line_f(&sLine_oVb1uorp, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_zAbd9Zup, VOf(Bf20));
    __hv_mul_f(VIf(Bf11), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_z0RMZ0hW, VOf(Bf1));
    __hv_mul_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_GbdDfjnv, VIf(Bf1));
    __hv_line_f(&sLine_2WuHKoFb, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_L8ddu7d1, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_7P6gwSX8, VOf(Bf1));
    __hv_mul_f(VIf(Bf11), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_L7wLPwHs, VIf(Bf1));
    __hv_varwrite_f(&sVarf_FRODmhLf, VIf(Bf10));
    __hv_varwrite_f(&sVarf_TLGtazcF, VIf(Bf0));
    __hv_varwrite_f(&sVarf_YN4ywUSd, VIf(Bf15));
    sEnv_process(this, &sEnv_8f1avqgT, VIf(Bf2), &sEnv_8f1avqgT_sendMessage);
    sEnv_process(this, &sEnv_3yVDvi4X, VIf(Bf4), &sEnv_3yVDvi4X_sendMessage);
    __hv_line_f(&sLine_og82AA46, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_taIMuE9M, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_5VbNkyxm, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_J4jMcuaJ, VOf(Bf2));
    __hv_line_f(&sLine_vdvYze1w, VOf(Bf15));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf2), VIf(Bf0), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_div_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_Vvy9vpOY, VIf(Bf0));
    __hv_varwrite_f(&sVarf_J4jMcuaJ, VIf(Bf6));
    __hv_varwrite_f(&sVarf_UKKVvJkl, VIf(Bf18));
    __hv_varwrite_f(&sVarf_xq5f0HOu, VIf(Bf13));
    __hv_varread_f(&sVarf_xq5f0HOu, VOf(Bf13));
    __hv_line_f(&sLine_mnjDtk55, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf13), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf18), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_mul_f(VIf(Bf18), VIf(Bf18), VOf(Bf13));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf13), VIf(Bf6), VOf(Bf0));
    __hv_var_k_f(VOf(Bf2), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf13), VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf18), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_TOE65W5e, VIf(Bf6));
    __hv_varread_f(&sVarf_UKKVvJkl, VOf(Bf6));
    __hv_line_f(&sLine_RVRUWJHD, VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_floor_f(VIf(Bf18), VOf(Bf0));
    __hv_sub_f(VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_abs_f(VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf18), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_wSp2FIZS, VIf(Bf6));
    __hv_varwrite_f(&sVarf_71FzrhTo, VIf(Bf4));
    __hv_varwrite_f(&sVarf_aP2zsKNU, VIf(Bf7));
    __hv_varwrite_f(&sVarf_pxadBFVJ, VIf(Bf8));
    __hv_varwrite_f(&sVarf_kodbm7jG, VIf(Bf9));
    __hv_varwrite_f(&sVarf_tfighzuD, VIf(Bf12));
    __hv_varwrite_f(&sVarf_Mq9bmeOE, VIf(Bf3));
    __hv_varwrite_f(&sVarf_YUiYeO2G, VIf(Bf5));
    __hv_varread_f(&sVarf_JEA2j0g7, VOf(Bf5));
    __hv_varread_f(&sVarf_MDOIVzEU, VOf(Bf3));
    __hv_varread_f(&sVarf_aP2zsKNU, VOf(Bf12));
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf5), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf12), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_pxadBFVJ, VOf(Bf12));
    __hv_varread_f(&sVarf_kodbm7jG, VOf(Bf5));
    __hv_varread_f(&sVarf_tfighzuD, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_M3NGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_M3NGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
